@@ -1,6 +1,6 @@
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -23,9 +23,11 @@ __author__  = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
 
 
+import os
 import posixpath
 from copy import copy
 import logging
+import transaction
 
 from Products.ATContentTypes.config import HAS_LINGUA_PLONE
 if HAS_LINGUA_PLONE:
@@ -55,7 +57,6 @@ from webdav.NullResource import NullResource
 from zExceptions import MethodNotAllowed
 from zExceptions import NotFound
 from ZODB.POSException import ConflictError
-from Products.CMFPlone import transaction
 
 from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ModifyPortalContent
@@ -449,13 +450,8 @@ class ATCTFileContent(ATCTContent):
             raise ResourceLockedError, "File is locked via WebDAV"
 
         self.setTitle(title)
-        ##self.setContentType(content_type)
-        ##if precondition: self.precondition=str(precondition)
-        ##elif self.precondition: del self.precondition
         if filedata is not None:
             self.update_data(filedata, content_type, len(filedata))
-        ##else:
-        ##    self.ZCacheable_invalidate()
         if REQUEST:
             message="Saved changes."
             return self.manage_main(self,REQUEST,manage_tabs_message=message)
@@ -490,7 +486,7 @@ class ATCTFileContent(ATCTContent):
                 # got a clean file name - rename it
                 # apply subtransaction. w/o a subtransaction renaming
                 # fails when the type is created using portal_factory
-                transaction.commit(1)
+                transaction.savepoint(optimistic=True)
                 self.setId(clean_filename)
 
     security.declareProtected(View, 'post_validate')
@@ -502,6 +498,9 @@ class ATCTFileContent(ATCTContent):
         f_name = field.getName()
         upload = REQUEST.form.get('%s_file' % f_name, None)
         filename = getattr(upload, 'filename', None)
+        if isinstance(filename, basestring):
+            filename = os.path.basename(filename)
+            filename = filename.split("\\")[-1]
         clean_filename = self._cleanupFilename(filename)
         used_id = (id and not self._isIDAutoGenerated(id)) and id or clean_filename
 
@@ -597,9 +596,6 @@ class ATCTFolderMixin(ConstrainTypesMixin, ATCTMixin):
 
     security       = ClassSecurityInfo()
 
-    # copy from PloneFolder's
-    security.declareProtected(Permissions.copy_or_move, 'manage_copyObjects')
-
     def __browser_default__(self, request):
         """ Set default so we can return whatever we want instead
         of index_html """
