@@ -1,7 +1,7 @@
 """Migration tools for ATContentTypes
 
 Migration system for the migration from CMFDefault/Event types to archetypes
-based CMFPloneTypes (http://sf.net/projects/collective/).
+based CMFPloneTypes (http://plone.org/products/atcontenttypes/).
 
 Copyright (c) 2004-2005, Christian Heimes <tiran@cheimes.de> and contributors
 All rights reserved.
@@ -243,7 +243,7 @@ class BaseMigrator:
             if getattr(aq_base(self.new), id, _marker) is not _marker:
                 continue
             try:
-                self.new.manage_addProperty(id, value, typ)
+                self.new._setProperty(id, value, typ)
             except ConflictError:
                 raise
             except:
