@@ -1,7 +1,7 @@
 # -*- coding: latin1 -*-
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@ ZopeTestCase.installProduct('SiteAccess')
 PloneTestCase.setupPloneSite()
 
 import os
+import transaction
 
 from Interface.Verify import verifyObject
 from Products.CMFCore.permissions import View
@@ -42,7 +43,7 @@ from Products.Archetypes.atapi import *
 from Products.Archetypes.interfaces.layer import ILayerContainer
 from Products.Archetypes.interfaces.referenceable import IReferenceable
 from Products.Archetypes.interfaces.templatemixin import ITemplateMixin
-from Products.CMFDynamicViewFTI.interfaces import ISelectableBrowserDefault
+from Products.CMFDynamicViewFTI.interface import ISelectableBrowserDefault
 from Products.Archetypes.tests.atsitetestcase import ATSiteTestCase
 from Products.Archetypes.tests.test_baseschema import BaseSchemaTest
 from Products.ATContentTypes.config import HAS_LINGUA_PLONE
@@ -56,7 +57,10 @@ from Products.ATContentTypes.tests.utils import DummySessionDataManager
 from Products.ATReferenceBrowserWidget.ATReferenceBrowserWidget import ReferenceBrowserWidget
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.interfaces.Translatable import ITranslatable
-from Products.CMFPlone import transaction
+
+# Z3 imports
+from Products.ATContentTypes.interface import IATContentType as Z3IATContentType
+from zope.interface.verify import verifyObject as Z3verifyObject
 
 test_home = os.path.dirname(__file__)
 
@@ -144,6 +148,10 @@ class ATCTTypeTestCase(ATCTSiteTestCase):
         self.failUnless(IATContentType.isImplementedBy(self._ATCT))
         self.failUnless(verifyObject(IATContentType, self._ATCT))
 
+    def test_doesImplementZ3ATCT(self):
+        iface = Z3IATContentType
+        self.failUnless(Z3verifyObject(iface, self._ATCT))
+
     def test_doesImplementAT(self):
         self.failUnless(IBaseContent.isImplementedBy(self._ATCT))
         self.failUnless(IReferenceable.isImplementedBy(self._ATCT))
@@ -162,7 +170,7 @@ class ATCTTypeTestCase(ATCTSiteTestCase):
 
     def test_implements_ISelectableBrowserDefault(self):
         iface = ISelectableBrowserDefault
-        self.failUnless(iface.isImplementedBy(self._ATCT))
+        self.failUnless(iface.providedBy(self._ATCT))
         self.failUnless(verifyObject(iface, self._ATCT))
 
     def compareDC(self, first, second=None, **kwargs):
