@@ -1,6 +1,6 @@
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ if __name__ == '__main__':
 from Testing import ZopeTestCase # side effect import. leave it here.
 from Products.ATContentTypes.tests import atcttestcase, atctftestcase
 
-from Products.CMFPlone import transaction
+import transaction
 from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ModifyPortalContent
 from Products.Archetypes.interfaces.layer import ILayerContainer
@@ -48,7 +48,12 @@ from DateTime import DateTime
 from Products.ATContentTypes.interfaces import ICalendarSupport
 from Products.ATContentTypes.interfaces import IATEvent
 from Interface.Verify import verifyObject
-from Products.CMFPlone import transaction
+
+# z3 imports
+from Products.ATContentTypes.interface import ICalendarSupport as Z3ICalendarSupport
+from Products.ATContentTypes.interface import IATEvent as Z3IATEvent
+from zope.interface.verify import verifyObject as Z3verifyObject
+
 
 LOCATION = 'my location'
 EV_TYPE  = 'Meeting'
@@ -104,11 +109,19 @@ class TestSiteATEvent(atcttestcase.ATCTTypeTestCase):
         self.failUnless(ICalendarSupport.isImplementedBy(self._ATCT))
         self.failUnless(verifyObject(ICalendarSupport, self._ATCT))
 
+    def test_doesImplementZ3CalendarSupport(self):
+        iface = Z3ICalendarSupport
+        self.failUnless(Z3verifyObject(iface, self._ATCT))
+
     def test_implementsATEvent(self):
         iface = IATEvent
         self.failUnless(iface.isImplementedBy(self._ATCT))
         self.failUnless(verifyObject(iface, self._ATCT))
 
+    def test_implementsZ3ATEvent(self):
+        iface = Z3IATEvent
+        self.failUnless(Z3verifyObject(iface, self._ATCT))
+
     def test_edit(self):
         old = self._cmf
         new = self._ATCT
@@ -162,10 +175,10 @@ class TestSiteATEvent(atcttestcase.ATCTTypeTestCase):
         ev_type = old.Subject()
 
         # migrated (needs subtransaction to work)
-        transaction.commit(1)
+        transaction.savepoint(optimistic=True)
         m = EventMigrator(old)
         m(unittest=1)
-        
+
         self.failUnless(id in self.folder.objectIds(), self.folder.objectIds())
         migrated = getattr(self.folder, id)
 
@@ -205,11 +218,11 @@ class TestSiteATEvent(atcttestcase.ATCTTypeTestCase):
         day29 = DateTime('2004-12-29 0:00:00')
         day30 = DateTime('2004-12-30 0:00:00')
         day31 = DateTime('2004-12-31 0:00:00')
-        
+
         e1.edit(startDate = day29, endDate=day30, title='event')
         e2.edit(startDate = day29, endDate=day30, title='event')
         self.failUnlessEqual(cmp(e1, e2), 0)
-    
+
         # start date
         e1.edit(startDate = day29, endDate=day30, title='event')
         e2.edit(startDate = day30, endDate=day31, title='event')
@@ -219,17 +232,50 @@ class TestSiteATEvent(atcttestcase.ATCTTypeTestCase):
         e1.edit(startDate = day29, endDate=day30, title='event')
         e2.edit(startDate = day29, endDate=day31, title='event')
         self.failUnlessEqual(cmp(e1, e2), -1)  # e1 < e2
-    
+
         # title
         e1.edit(startDate = day29, endDate=day30, title='event')
         e2.edit(startDate = day29, endDate=day30, title='evenz')
         self.failUnlessEqual(cmp(e1, e2), -1)  # e1 < e2
 
+    def test_ical(self):
+        event = self._ATCT
+        event.setStartDate(DateTime('2001/01/01 12:00:00 GMT+1'))
+        event.setEndDate(DateTime('2001/01/01 14:00:00 GMT+1'))
+        event.setTitle('cool event')
+        ical = event.getICal()
+        lines = ical.split('\n')
+        self.assertEqual(lines[0], "BEGIN:VEVENT")
+        self.assertEqual(lines[5], "SUMMARY:%s"%event.Title())
+        # times should be converted to UTC
+        self.assertEqual(lines[6], "DTSTART:20010101T110000Z")
+        self.assertEqual(lines[7], "DTEND:20010101T130000Z")
+
+    def test_vcal(self):
+        event = self._ATCT
+        event.setStartDate(DateTime('2001/01/01 12:00:00 GMT+1'))
+        event.setEndDate(DateTime('2001/01/01 14:00:00 GMT+1'))
+        event.setTitle('cool event')
+        vcal = event.getVCal()
+        lines = vcal.split('\n')
+        self.assertEqual(lines[0], "BEGIN:VEVENT")
+        self.assertEqual(lines[7], "SUMMARY:%s"%event.Title())
+        # times should be converted to UTC
+        self.assertEqual(lines[1], "DTSTART:20010101T110000Z")
+        self.assertEqual(lines[2], "DTEND:20010101T130000Z")
+
     def test_get_size(self):
         atct = self._ATCT
         editATCT(atct)
         self.failUnlessEqual(atct.get_size(), len(TEXT))
 
+    def test_set_subject_sets_eventtype(self):
+        atct = self._ATCT
+        atct.setSubject(['a','b','c'])
+        self.failUnless('a' in atct.getEventType())
+        self.failUnless('b' in atct.getEventType())
+        self.failUnless('c' in atct.getEventType())
+
 tests.append(TestSiteATEvent)
 
 class TestATEventFields(atcttestcase.ATCTFieldTestCase):
@@ -283,11 +329,9 @@ class TestATEventFields(atcttestcase.ATCTFieldTestCase):
         dummy = self._dummy
         field = dummy.getField('eventType')
         self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnless(field.required == 1, 'Value is %s' % field.required)
+        self.failUnless(field.required == 0, 'Value is %s' % field.required)
         self.failUnless(field.default == (), 'Value is %s' % str(str(field.default)))
         self.failUnless(field.searchable == 1, 'Value is %s' % field.searchable)
-        self.failUnless(field.vocabulary == 'getEventTypes',
-                        'Value is %s' % str(field.vocabulary))
         self.failUnless(field.enforceVocabulary == 0,
                         'Value is %s' % field.enforceVocabulary)
         self.failUnless(field.multiValued == 0,
@@ -311,9 +355,9 @@ class TestATEventFields(atcttestcase.ATCTFieldTestCase):
         self.failUnless(field.getLayerImpl('storage') == AttributeStorage(),
                         'Value is %s' % field.getLayerImpl('storage'))
         self.failUnless(ILayerContainer.isImplementedBy(field))
-        self.failUnless(field.validators == (),
-                        'Value is %s' % str(field.validators))
-        self.failUnless(isinstance(field.widget, MultiSelectionWidget),
+        self.failUnless(field.validators == EmptyValidator,
+                        'Value is %s' % repr(field.validators))
+        self.failUnless(isinstance(field.widget, KeywordWidget),
                         'Value is %s' % id(field.widget))
 
 
@@ -667,7 +711,7 @@ class TestATEventFields(atcttestcase.ATCTFieldTestCase):
 tests.append(TestATEventFields)
 
 class TestATEventFunctional(atctftestcase.ATCTIntegrationTestCase):
-    
+
     portal_type = 'Event'
     views = ('event_view', 'vcs_view', 'ics_view', )
 
