@@ -1,6 +1,6 @@
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -30,11 +30,12 @@ from Testing import ZopeTestCase # side effect import. leave it here.
 from Products.ATContentTypes.tests import atcttestcase, atctftestcase
 from Products.ATContentTypes.tests.utils import dcEdit
 
-from Products.CMFPlone import transaction
+import transaction
 from Products.CMFCore.permissions import View
 from Products.Archetypes.interfaces.layer import ILayerContainer
 from Products.Archetypes.public import *
 
+from Products.Archetypes.Field import BooleanField
 from Products.ATContentTypes.content.topic import ATTopic
 from Products.ATContentTypes.content.topic import ChangeTopics
 from Products.ATContentTypes.content.folder import ATFolder
@@ -45,10 +46,13 @@ from Products.ATContentTypes.migration.atctmigrator import CRIT_MAP, REV_CRIT_MA
 from Products.ATContentTypes.interfaces import IATTopic
 from Interface.Verify import verifyObject
 from OFS.IOrderSupport import IOrderedContainer as IZopeOrderedContainer
-from Products.CMFPlone import transaction
 
 from Products.CMFPlone.PloneBatch import Batch
 
+# z3 imports
+from Products.ATContentTypes.interface import IATTopic as Z3IATTopic
+from zope.interface.verify import verifyObject as Z3verifyObject
+
 
 ACQUIRE  = True
 LIMIT    = False
@@ -181,6 +185,10 @@ class TestSiteATTopic(atcttestcase.ATCTTypeTestCase):
         self.failUnless(iface.isImplementedBy(self._ATCT))
         self.failUnless(verifyObject(iface, self._ATCT))
 
+    def test_Z3implementsATTopic(self):
+        iface = Z3IATTopic
+        self.failUnless(Z3verifyObject(iface, self._ATCT))
+
     def test_isNotOrdered(self):
         iface = IZopeOrderedContainer
         self.failIf(iface.isImplementedBy(self._ATCT))
@@ -296,7 +304,7 @@ class TestSiteATTopic(atcttestcase.ATCTTypeTestCase):
         old_query = convert_old_catalog_query(old.buildQuery())
 
         # migrated (needs subtransaction to work)
-        transaction.commit(1)
+        transaction.savepoint(optimistic=True)
         m = TopicMigrator(old)
         m(unittest=1)
 
@@ -410,6 +418,20 @@ class TestSiteATTopic(atcttestcase.ATCTTypeTestCase):
     def test_schema_marshall(self):
         pass
 
+    def test_sort_criterion_does_not_affect_available_fields(self):
+        topic = self._ATCT
+        # set a sort criterion
+        topic.setSortCriterion('created', False)
+        # It should still be available for other criteria
+        self.failUnless([i for i in topic.listAvailableFields()
+                         if i[0] == 'created'])
+        # Add a normal criteria for the same field
+        crit = topic.addCriterion('created', 'ATFriendlyDateCriteria')
+        # It should no longer be available
+        self.failIf([i for i in topic.listAvailableFields()
+                     if i[0] == 'created'])
+
+
 tests.append(TestSiteATTopic)
 
 class TestATTopicFields(atcttestcase.ATCTFieldTestCase):
@@ -421,12 +443,13 @@ class TestATTopicFields(atcttestcase.ATCTFieldTestCase):
     def test_acquireCriteriaField(self):
         dummy = self._dummy
         field = dummy.getField('acquireCriteria')
+        field_vocab = BooleanField._properties.get('vocabulary', ())
 
         self.failUnless(ILayerContainer.isImplementedBy(field))
         self.failUnless(field.required == 0, 'Value is %s' % field.required)
         self.failUnless(field.default == False, 'Value is %s' % str(field.default))
         self.failUnless(field.searchable == 0, 'Value is %s' % field.searchable)
-        self.failUnless(field.vocabulary == (),
+        self.failUnless(field.vocabulary == field_vocab,
                         'Value is %s' % str(field.vocabulary))
         self.failUnless(field.enforceVocabulary == 0,
                         'Value is %s' % field.enforceVocabulary)
@@ -456,17 +479,19 @@ class TestATTopicFields(atcttestcase.ATCTFieldTestCase):
         vocab = field.Vocabulary(dummy)
         self.failUnless(isinstance(vocab, DisplayList),
                         'Value is %s' % type(vocab))
-        self.failUnless(tuple(vocab) == (), 'Value is %s' % str(tuple(vocab)))
+        self.failUnless(tuple(vocab) == tuple([x[0] for x in field_vocab]),
+                        'Value is %s' % str(tuple(vocab)))
 
     def test_limitNumberField(self):
         dummy = self._dummy
         field = dummy.getField('limitNumber')
+        field_vocab = BooleanField._properties.get('vocabulary', ())
 
         self.failUnless(ILayerContainer.isImplementedBy(field))
         self.failUnless(field.required == 0, 'Value is %s' % field.required)
         self.failUnless(field.default == False, 'Value is %s' % str(field.default))
         self.failUnless(field.searchable == 0, 'Value is %s' % field.searchable)
-        self.failUnless(field.vocabulary == (),
+        self.failUnless(field.vocabulary == field_vocab,
                         'Value is %s' % str(field.vocabulary))
         self.failUnless(field.enforceVocabulary == 0,
                         'Value is %s' % field.enforceVocabulary)
@@ -496,7 +521,8 @@ class TestATTopicFields(atcttestcase.ATCTFieldTestCase):
         vocab = field.Vocabulary(dummy)
         self.failUnless(isinstance(vocab, DisplayList),
                         'Value is %s' % type(vocab))
-        self.failUnless(tuple(vocab) == (), 'Value is %s' % str(tuple(vocab)))
+        self.failUnless(tuple(vocab) == tuple([x[0] for x in field_vocab]),
+                        'Value is %s' % str(tuple(vocab)))
 
     def test_itemCountField(self):
         dummy = self._dummy
