@@ -8,7 +8,6 @@ from DateTime import DateTime
 from StringIO import StringIO
 from debug import deprecated
 
-from Products.Archetypes import transaction
 from Products.Archetypes.interfaces.base import IBaseObject
 from Products.Archetypes.interfaces.referenceable import IReferenceable
 from Products.Archetypes.interfaces.metadata import IExtensibleMetadata
@@ -26,7 +25,7 @@ from Products.Archetypes.utils import DisplayList
 from Products.Archetypes.utils import mapply
 from Products.Archetypes.Renderer import renderer
 
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore import permissions
 from Products.CMFCore.ActionProviderBase import ActionProviderBase
 from Products.CMFCore.TypesTool import FactoryTypeInformation
 from Products.CMFCore.utils import UniqueObject, getToolByName
@@ -44,7 +43,7 @@ from OFS.Folder import Folder
 from Products.ZCatalog.IZCatalog import IZCatalog
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from ZODB.POSException import ConflictError
-
+import transaction
 
 class BoundPageTemplateFile(PageTemplateFile):
 
@@ -105,27 +104,27 @@ base_factory_type_information = (
                      { 'id': 'view',
                        'name': 'View',
                        'action': 'string:${object_url}/base_view',
-                       'permissions': (CMFCorePermissions.View,),
+                       'permissions': (permissions.View,),
                        },
 
                      { 'id': 'edit',
                        'name': 'Edit',
                        'action': 'string:${object_url}/base_edit',
-                       'permissions': (CMFCorePermissions.ModifyPortalContent,),
+                       'permissions': (permissions.ModifyPortalContent,),
                        },
 
                      { 'id': 'metadata',
                        'name': 'Properties',
                        'action': 'string:${object_url}/base_metadata',
-                       'permissions': (CMFCorePermissions.ModifyPortalContent,),
+                       'permissions': (permissions.ModifyPortalContent,),
                        },
 
                      { 'id': 'references',
                        'name': 'References',
                        'action': 'string:${object_url}/reference_graph',
                        'condition': 'object/archetype_tool/has_graphviz',
-                       'permissions': (CMFCorePermissions.ModifyPortalContent,
-                                      CMFCorePermissions.ReviewPortalContent,),
+                       'permissions': (permissions.ModifyPortalContent,
+                                       permissions.ReviewPortalContent,),
                        'visible' : True,
                        },
 
@@ -133,7 +132,7 @@ base_factory_type_information = (
                        'name': 'Folder Listing',
                        'action': 'string:${folder_url}/folder_listing',
                        'condition': 'object/isPrincipiaFolderish',
-                       'permissions': (CMFCorePermissions.View,),
+                       'permissions': (permissions.View,),
                        'category': 'folder',
                        'visible' : False,
                        },
@@ -188,16 +187,6 @@ def fixActionsForType(portal_type, typesTool):
                     else:
                         new.append(action)
 
-            # the code was moved to modify_fti()
-            ## Update Aliases
-            #if cmfver[:7] >= 'CMF-1.4' or cmfver == 'Unreleased':
-            #    if (hasattr(portal_type, 'aliases') and
-            #        hasattr(typeInfo, 'setMethodAliases')):
-            #        typeInfo.setMethodAliases(portal_type.aliases)
-            #    else:
-            #        # Custom views might need to reguess the aliases
-            #        if hasattr(typeInfo, '_guessMethodAliases'):
-            #            typeInfo._guessMethodAliases()
             typeInfo._actions = tuple(new)
             typeInfo._p_changed = True
 
@@ -531,25 +520,25 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         ) + SQLStorageConfig.manage_options
         )
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_uids')
     manage_uids = PageTemplateFile('viewContents', _www)
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_templateForm')
     manage_templateForm = PageTemplateFile('manageTemplates',_www)
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_debugForm')
     manage_debugForm = PageTemplateFile('generateDebug', _www)
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_updateSchemaForm')
     manage_updateSchemaForm = PageTemplateFile('updateSchemaForm', _www)
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_migrationForm')
     manage_migrationForm = PageTemplateFile('migrationForm', _www)
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_dumpSchemaForm')
     manage_dumpSchemaForm = PageTemplateFile('schema', _www)
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_catalogs')
     manage_catalogs = PageTemplateFile('manage_catalogs', _www)
 
@@ -564,7 +553,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         # DM (avoid persistency bug): "_types" now maps known schemas to signatures
         self._types = {}
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_dumpSchema')
     def manage_dumpSchema(self, REQUEST=None):
         """XML Dump Schema of passed in class.
@@ -588,7 +577,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
     # We keep two lists, all register templates and their
     # names/titles and the mapping of type to template bindings both
     # are persistent
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'registerTemplate')
     def registerTemplate(self, template, name=None):
         # Lookup the template by name
@@ -602,7 +591,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         self._registeredTemplates[template] = name
 
 
-    security.declareProtected(CMFCorePermissions.View, 'lookupTemplates')
+    security.declareProtected(permissions.View, 'lookupTemplates')
     def lookupTemplates(self, instance_or_portaltype=None):
         """Lookup templates by giving an instance or a portal_type.
 
@@ -625,19 +614,19 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
 
         return DisplayList(results).sortedByValue()
 
-    security.declareProtected(CMFCorePermissions.View, 'listTemplates')
+    security.declareProtected(permissions.View, 'listTemplates')
     def listTemplates(self):
         """Lists all the templates.
         """
         return DisplayList(self._registeredTemplates.items()).sortedByValue()
 
-    security.declareProtected(CMFCorePermissions.ManagePortal, 'bindTemplate')
+    security.declareProtected(permissions.ManagePortal, 'bindTemplate')
     def bindTemplate(self, portal_type, templateList):
         """Creates binding between a type and its associated views.
         """
         self._templates[portal_type] = templateList
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_templates')
     def manage_templates(self, REQUEST=None):
         """Sets all the template/type mappings.
@@ -656,7 +645,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
 
         return REQUEST.RESPONSE.redirect(self.absolute_url() + '/manage_templateForm')
     
-    security.declareProtected(CMFCorePermissions.View, 'typeImplementsInterfaces')
+    security.declareProtected(permissions.View, 'typeImplementsInterfaces')
     def typeImplementsInterfaces(self, type, interfaces):
         """Checks if an type uses one of the given interfaces.
         """
@@ -668,19 +657,19 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
                 return True
         return False
     
-    security.declareProtected(CMFCorePermissions.View, 'isTemplateEnabled')
+    security.declareProtected(permissions.View, 'isTemplateEnabled')
     def isTemplateEnabled(self, type):
         """Checks if an type uses ITemplateMixin.
         """
         return self.typeImplementsInterfaces(type, [ITemplateMixin])
         
-    security.declareProtected(CMFCorePermissions.View, 'listTemplateEnabledPortalTypes')
+    security.declareProtected(permissions.View, 'listTemplateEnabledPortalTypes')
     def listTemplateEnabledPortalTypes(self):
         """Return a list of portal_types with ITemplateMixin
         """
         return self.listPortalTypesWithInterfaces([ITemplateMixin])
         
-    security.declareProtected(CMFCorePermissions.View, 'listPortalTypesWithInterfaces')
+    security.declareProtected(permissions.View, 'listPortalTypesWithInterfaces')
     def listPortalTypesWithInterfaces(self, ifaces):
         """Returns a list of ftis of which the types implement one of
         the given interfaces.  Only returns AT types.
@@ -708,8 +697,8 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         return value
 
     # Type/Schema Management
-    security.declareProtected(CMFCorePermissions.View, 'listRegisteredTypes')
-    def listRegisteredTypes(self, inProject=False):
+    security.declareProtected(permissions.View, 'listRegisteredTypes')
+    def listRegisteredTypes(self, inProject=False, portalTypes=False):
         """Return the list of sorted types.
         """
 
@@ -730,19 +719,22 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
             # portal_type can change (as it does after ATCT-migration), so we
             # need to check against the content_meta_type of each type-info
             tt = getToolByName(self, 'portal_types')
-            meta_types = tt.listContentTypes(self, by_metatype=True)
-            values = [v for v in values if v['meta_type'] in meta_types]
+            types = tt.listContentTypes(self, by_metatype=not portalTypes)
+	    if portalTypes:
+                values = [v for v in values if v['portal_type'] in types]
+            else:
+                values = [v for v in values if v['meta_type'] in types]
 
         return values
 
-    security.declareProtected(CMFCorePermissions.View, 'getTypeSpec')
+    security.declareProtected(permissions.View, 'getTypeSpec')
     def getTypeSpec(self, package, type):
         t = self.lookupType(package, type)
         module = t['klass'].__module__
         klass = t['name']
         return '%s.%s' % (module, klass)
 
-    security.declareProtected(CMFCorePermissions.View, 'listTypes')
+    security.declareProtected(permissions.View, 'listTypes')
     def listTypes(self, package=None, type=None):
         """Just the class.
         """
@@ -751,7 +743,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         else:
             return [getType(type, package)['klass']]
 
-    security.declareProtected(CMFCorePermissions.View, 'lookupType')
+    security.declareProtected(permissions.View, 'lookupType')
     def lookupType(self, package, type):
         types = self.listRegisteredTypes()
         for t in types:
@@ -767,12 +759,12 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         return None
 
     # XXX unusable because nothing is writing to _schemas
-    #security.declareProtected(CMFCorePermissions.View,
+    #security.declareProtected(permissions.View,
     #                          'getSchema')
     #def getSchema(self, sid):
     #    return self._schemas[sid]
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_installType')
     def manage_installType(self, typeName, package=None,
                            uninstall=None, REQUEST=None):
@@ -781,7 +773,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         typesTool = getToolByName(self, 'portal_types')
         try:
             typesTool._delObject(typeName)
-        except ConflictError:
+        except (ConflictError, KeyboardInterrupt):
             raise
         except: # XXX bare exception
             pass
@@ -914,7 +906,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
                 log('no object for brain: %s:%s' % (b,b.getURL()))
 
 
-    security.declareProtected(CMFCorePermissions.View, 'enum')
+    security.declareProtected(permissions.View, 'enum')
     def enum(self, callback, *args, **kwargs):
         catalog = getToolByName(self, UID_CATALOG)
         keys = catalog.uniqueValuesFor('UID')
@@ -926,7 +918,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
                 log('No object for %s' % uid)
 
 
-    security.declareProtected(CMFCorePermissions.View, 'Content')
+    security.declareProtected(permissions.View, 'Content')
     def Content(self):
         """Return a list of all the content ids.
         """
@@ -937,7 +929,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
 
 
     ## Management Forms
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_doGenerate')
     def manage_doGenerate(self, sids=(), REQUEST=None):
         """(Re)generate types.
@@ -953,7 +945,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
             return REQUEST.RESPONSE.redirect(self.absolute_url() +
                                              '/manage_workspace')
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_inspect')
     def manage_inspect(self, UID, REQUEST=None):
         """Dump some things about an object hook in the debugger for now.
@@ -964,7 +956,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         return REQUEST.RESPONSE.redirect(self.absolute_url() +
                                          '/manage_uids')
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_reindex')
     def manage_reindex(self, REQUEST=None):
         """Assign UIDs to all basecontent objects.
@@ -978,7 +970,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         return REQUEST.RESPONSE.redirect(self.absolute_url() +
                                          '/manage_uids')
 
-    security.declareProtected(CMFCorePermissions.ManagePortal, 'index')
+    security.declareProtected(permissions.ManagePortal, 'index')
     index = manage_reindex
 
     def _listAllTypes(self):
@@ -987,7 +979,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         allTypes = _types.copy(); allTypes.update(self._types)
         return allTypes.keys()
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'getChangedSchema')
     def getChangedSchema(self):
         """Returns a list of tuples indicating which schema have changed.
@@ -1019,7 +1011,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         return list
 
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_updateSchema')
     def manage_updateSchema(self, REQUEST=None, update_all=None):
         """Make sure all objects' schema are up to date.
@@ -1078,7 +1070,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         if not o._isSchemaCurrent():
             self._updateObject(o, path)
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_updateSchema')
     def manage_migrate(self, REQUEST=None):
         """Run Extensions.migrations.migrate.
@@ -1089,14 +1081,14 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         return out
 
     # Catalog management
-    security.declareProtected(CMFCorePermissions.View,
+    security.declareProtected(permissions.View,
                               'listCatalogs')
     def listCatalogs(self):
         """Show the catalog mapping.
         """
         return self.catalog_map
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'manage_updateCatalogs')
     def manage_updateCatalogs(self, REQUEST=None):
         """Set the catalog map for meta_type to include the list
@@ -1112,38 +1104,38 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
         return REQUEST.RESPONSE.redirect(self.absolute_url() +
                                          '/manage_catalogs')
 
-    security.declareProtected(CMFCorePermissions.ManagePortal,
+    security.declareProtected(permissions.ManagePortal,
                               'setCatalogsByType')
-    def setCatalogsByType(self, meta_type, catalogList):
+    def setCatalogsByType(self, portal_type, catalogList):
         """ associate catalogList with meta_type. (unfortunally not portal_type).
         
             catalogList is a list of strings with the ids of the catalogs.
             Each catalog is has to be a tool, means unique in site root.
         """
-        self.catalog_map[meta_type] = catalogList
+        self.catalog_map[portal_type] = catalogList
 
 
-    security.declareProtected(CMFCorePermissions.View, 'getCatalogsByType')
-    def getCatalogsByType(self, meta_type):
+    security.declareProtected(permissions.View, 'getCatalogsByType')
+    def getCatalogsByType(self, portal_type):
         """Return the catalog objects assoicated with a given type.
         """
         catalogs = []
         catalog_map = getattr(self, 'catalog_map', None)
         if catalog_map is not None:
-            names = self.catalog_map.get(meta_type, ['portal_catalog'])
+            names = self.catalog_map.get(portal_type, ['portal_catalog'])
         else:
             names = ['portal_catalog']
         for name in names:
             try:
                 catalogs.append(getToolByName(self, name))
-            except ConflictError:
+            except (ConflictError, KeyboardInterrupt):
                 raise
             except Exception, E:
                 log('No tool', name, E)
                 pass
         return catalogs
 
-    security.declareProtected(CMFCorePermissions.View, 'getCatalogsInSite')
+    security.declareProtected(permissions.View, 'getCatalogsInSite')
     def getCatalogsInSite(self):
         """Return a list of ids for objects implementing ZCatalog.
         """
@@ -1161,7 +1153,7 @@ class ArchetypeTool(UniqueObject, ActionProviderBase, \
 
         return res
 
-    security.declareProtected(CMFCorePermissions.View, 'visibleLookup')
+    security.declareProtected(permissions.View, 'visibleLookup')
     def visibleLookup(self, field, vis_key, vis_value='visible'):
         """Checks the value of a specific key in the field widget's
         'visible' dictionary.
