@@ -1,7 +1,6 @@
 import sys
 from Globals import InitializeClass
 
-from Products.Archetypes import transaction
 from Products.Archetypes.debug import log
 from Products.Archetypes.debug import log_exc
 from Products.Archetypes.debug import _default_logger
@@ -21,8 +20,8 @@ from Products.Archetypes.Storage import AttributeStorage
 from Products.Archetypes.Widget import IdWidget
 from Products.Archetypes.Widget import StringWidget
 from Products.Archetypes.Marshall import RFC822Marshaller
-from Products.Archetypes.interfaces.base import IBaseObject
-from Products.Archetypes.interfaces.base import IBaseUnit
+from Products.Archetypes.interfaces.base import IBaseObject as z2IBaseObject
+from Products.Archetypes.interfaces.base import IBaseUnit as z2IBaseUnit
 from Products.Archetypes.interfaces.field import IFileField
 from Products.Archetypes.config import ATTRIBUTE_SECURITY
 from Products.Archetypes.config import RENAME_AFTER_CREATION_ATTEMPTS
@@ -31,19 +30,22 @@ from Products.Archetypes.ArchetypeTool import _guessPackage
 
 from AccessControl import ClassSecurityInfo
 from AccessControl import Unauthorized
+from AccessControl.Permissions import copy_or_move as permission_copy_or_move
 from Acquisition import Implicit
 from Acquisition import aq_base
 from Acquisition import aq_acquire
 from Acquisition import aq_inner
 from Acquisition import aq_parent
+from Acquisition import ImplicitAcquisitionWrapper
 from Acquisition import ExplicitAcquisitionWrapper
 from Acquisition import Explicit
 
 from ComputedAttribute import ComputedAttribute
 from OFS.ObjectManager import ObjectManager
 from ZODB.POSException import ConflictError
+import transaction
 
-from Products.CMFCore  import CMFCorePermissions
+from Products.CMFCore import permissions
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.utils import _checkPermission as checkPerm
 
@@ -53,6 +55,12 @@ from types import TupleType, ListType, UnicodeType
 from ZPublisher import xmlrpc
 from webdav.NullResource import NullResource
 
+from Products.Archetypes.interfaces import IBaseObject
+from zope.interface import implements, Interface
+from zope import event
+from zope.app.event import objectevent
+from zope.component import queryMultiAdapter
+
 _marker = []
 
 class AttributeValidator(Implicit):
@@ -97,6 +105,7 @@ content_type = Schema((
         required=0, # Still actually required, but the widget will
                     # supply the missing value on non-submits
         mode='rw',
+        permission=permission_copy_or_move,
         accessor='getId',
         mutator='setId',
         default=None,
@@ -148,12 +157,14 @@ class BaseObject(Referenceable):
     typeDescription = ''
     _at_rename_after_creation = False # rename object according to title?
 
-    __implements__ = (IBaseObject, ) + Referenceable.__implements__
+    __implements__ = (z2IBaseObject, ) + Referenceable.__implements__
+
+    implements(IBaseObject)
 
     def __init__(self, oid, **kwargs):
         self.id = oid
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'initializeArchetype')
     def initializeArchetype(self, **kwargs):
         """Called by the generated addXXX factory in types tool.
@@ -166,7 +177,7 @@ class BaseObject(Referenceable):
                 kwargs['_initializing_'] = True
                 self.edit(**kwargs)
             self._signature = self.Schema().signature()
-        except ConflictError:
+        except (ConflictError, KeyboardInterrupt):
             raise
         except:
             log_exc()
@@ -198,7 +209,7 @@ class BaseObject(Referenceable):
     def cleanupLayers(self, item=None, container=None):
         self.Schema().cleanupLayers(self, item, container)
 
-    security.declareProtected(CMFCorePermissions.View, 'title_or_id')
+    security.declareProtected(permissions.View, 'title_or_id')
     def title_or_id(self):
         """Returns the title if it is not blank and the id otherwise.
         """
@@ -208,13 +219,13 @@ class BaseObject(Referenceable):
 
         return self.getId()
 
-    security.declareProtected(CMFCorePermissions.View, 'getId')
+    security.declareProtected(permissions.View, 'getId')
     def getId(self):
         """Gets the object id.
         """
         return self.id
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'setId')
+    security.declareProtected(permissions.ModifyPortalContent, 'setId')
     def setId(self, value):
         """Sets the object id.
         """
@@ -226,7 +237,7 @@ class BaseObject(Referenceable):
                 parent.manage_renameObject(self.id, value)
             self._setId(value)
 
-    security.declareProtected(CMFCorePermissions.View, 'Type')
+    security.declareProtected(permissions.View, 'Type')
     def Type(self):
         """Dublin Core element - Object type.
 
@@ -240,13 +251,13 @@ class BaseObject(Referenceable):
                 return ti.Title()
         return self.meta_type
 
-    security.declareProtected(CMFCorePermissions.View, 'getField')
+    security.declareProtected(permissions.View, 'getField')
     def getField(self, key, wrapped=False):
         """Returns a field object.
         """
         return self.Schema().get(key)
 
-    security.declareProtected(CMFCorePermissions.View, 'getWrappedField')
+    security.declareProtected(permissions.View, 'getWrappedField')
     def getWrappedField(self, key):
         """Gets a field by id which is explicitly wrapped.
 
@@ -254,20 +265,21 @@ class BaseObject(Referenceable):
         """
         return ExplicitAcquisitionWrapper(self.getField(key), self)
 
-    security.declareProtected(CMFCorePermissions.View, 'getDefault')
+    security.declareProtected(permissions.View, 'getDefault')
     def getDefault(self, field):
         """Return the default value of a field.
         """
         field = self.getField(field)
         return field.getDefault(self)
 
-    security.declareProtected(CMFCorePermissions.View, 'isBinary')
+    security.declareProtected(permissions.View, 'isBinary')
     def isBinary(self, key):
         """Return wether a field contains binary data.
         """
-        element = getattr(self, key, None)
-        if element and shasattr(element, 'isBinary'):
-            return element.isBinary()
+        field = self.getField(key)
+        if IFileField.isImplementedBy(field):
+            value = field.getBaseUnit(self)
+            return value.isBinary()
         mimetype = self.getContentType(key)
         if mimetype and shasattr(mimetype, 'binary'):
             return mimetype.binary
@@ -275,14 +287,14 @@ class BaseObject(Referenceable):
             return 0
         return 1
 
-    security.declareProtected(CMFCorePermissions.View, 'isTransformable')
+    security.declareProtected(permissions.View, 'isTransformable')
     def isTransformable(self, name):
         """Returns wether a field is transformable.
         """
         field = self.getField(name)
         return isinstance(field, TextField) or not self.isBinary(name)
 
-    security.declareProtected(CMFCorePermissions.View, 'widget')
+    security.declareProtected(permissions.View, 'widget')
     def widget(self, field_name, mode="view", field=None, **kwargs):
         """Returns the rendered widget.
         """
@@ -292,7 +304,7 @@ class BaseObject(Referenceable):
         return renderer.render(field_name, mode, widget, self, field=field,
                                **kwargs)
 
-    security.declareProtected(CMFCorePermissions.View, 'getFilename')
+    security.declareProtected(permissions.View, 'getFilename')
     def getFilename(self, key=None):
         """Returns the filename from a field.
         """
@@ -308,7 +320,7 @@ class BaseObject(Referenceable):
 
         return value
 
-    security.declareProtected(CMFCorePermissions.View, 'getContentType')
+    security.declareProtected(permissions.View, 'getContentType')
     def getContentType(self, key=None):
         """Returns the content type from a field.
         """
@@ -325,15 +337,16 @@ class BaseObject(Referenceable):
         return value
 
     # Backward compatibility
-    security.declareProtected(CMFCorePermissions.View, 'content_type')
+    # Note: ComputedAttribute should never be protected by a security 
+    # declaration! See http://dev.plone.org/archetypes/ticket/712
     content_type = ComputedAttribute(getContentType, 1)
 
     # XXX Where's get_content_type comes from??? There's no trace at both
     # Zope and CMF. It should be removed ASAP!
-    security.declareProtected(CMFCorePermissions.View, 'get_content_type')
+    security.declareProtected(permissions.View, 'get_content_type')
     get_content_type = getContentType
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'setContentType')
     def setContentType(self, value, key=None):
         """Sets the content type of a field.
@@ -346,7 +359,7 @@ class BaseObject(Referenceable):
         if field and IFileField.isImplementedBy(field):
             field.setContentType(self, value)
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'setFilename')
     def setFilename(self, value, key=None):
         """Sets the filename of a field.
@@ -359,7 +372,7 @@ class BaseObject(Referenceable):
         if field and IFileField.isImplementedBy(field):
             field.setFilename(self, value)
 
-    security.declareProtected(CMFCorePermissions.View, 'getPrimaryField')
+    security.declareProtected(permissions.View, 'getPrimaryField')
     def getPrimaryField(self):
         """The primary field is some object that responds to
         PUT/manage_FTPget events.
@@ -369,7 +382,7 @@ class BaseObject(Referenceable):
             return fields[0]
         return None
 
-    security.declareProtected(CMFCorePermissions.View, 'get_portal_metadata')
+    security.declareProtected(permissions.View, 'get_portal_metadata')
     def get_portal_metadata(self, field):
         """Returns the portal_metadata for a field.
         """
@@ -378,7 +391,9 @@ class BaseObject(Referenceable):
         try:
             spec = pmt.getElementSpec(field.accessor)
             policy = spec.getPolicy(self.portal_type)
-        except ConflictError:
+
+
+        except (ConflictError, KeyboardInterrupt):
             raise
         except:
             log_exc()
@@ -390,7 +405,7 @@ class BaseObject(Referenceable):
         return DisplayList(map(lambda x: (x,x), policy.allowedVocabulary())), \
                policy.enforceVocabulary()
 
-    security.declareProtected(CMFCorePermissions.View, 'Vocabulary')
+    security.declareProtected(permissions.View, 'Vocabulary')
     def Vocabulary(self, key):
         """Returns the vocabulary for a specified field.
         """
@@ -443,7 +458,7 @@ class BaseObject(Referenceable):
         """
         self.Schema().setDefaults(self)
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'update')
+    security.declareProtected(permissions.ModifyPortalContent, 'update')
     def update(self, **kwargs):
         """Changes the values of the field and reindex the object.
         """
@@ -456,10 +471,10 @@ class BaseObject(Referenceable):
             # Avoid double indexing during initialization.
             self.reindexObject()
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'edit')
+    security.declareProtected(permissions.ModifyPortalContent, 'edit')
     edit = update
 
-    security.declareProtected(CMFCorePermissions.View,
+    security.declareProtected(permissions.View,
                               'validate_field')
     def validate_field(self, name, value, errors):
         """Field's validate hook.
@@ -482,15 +497,15 @@ class BaseObject(Referenceable):
 
     ## Pre/post validate hooks that will need to write errors
     ## into the errors dict directly using errors[fieldname] = ""
-    security.declareProtected(CMFCorePermissions.View, 'pre_validate')
+    security.declareProtected(permissions.View, 'pre_validate')
     def pre_validate(self, REQUEST=None, errors=None):
         pass
 
-    security.declareProtected(CMFCorePermissions.View, 'post_validate')
+    security.declareProtected(permissions.View, 'post_validate')
     def post_validate(self, REQUEST=None, errors=None):
         pass
 
-    security.declareProtected(CMFCorePermissions.View, 'validate')
+    security.declareProtected(permissions.View, 'validate')
     def validate(self, REQUEST=None, errors=None, data=None, metadata=None):
         """Validates the form data from the request.
         """
@@ -504,7 +519,7 @@ class BaseObject(Referenceable):
         self.post_validate(REQUEST, errors)
         return errors
 
-    security.declareProtected(CMFCorePermissions.View, 'SearchableText')
+    security.declareProtected(permissions.View, 'SearchableText')
     def SearchableText(self):
         """All fields marked as 'searchable' are concatenated together
         here for indexing purpose.
@@ -522,7 +537,9 @@ class BaseObject(Referenceable):
                 # handle the mimetype argument
                 try:
                     datum =  method()
-                except ConflictError:
+
+
+                except (ConflictError, KeyboardInterrupt):
                     raise
                 except:
                     continue
@@ -549,7 +566,7 @@ class BaseObject(Referenceable):
         data = ' '.join(data)
         return data
 
-    security.declareProtected(CMFCorePermissions.View, 'getCharset')
+    security.declareProtected(permissions.View, 'getCharset')
     def getCharset(self):
         """Returns the site default charset, or utf-8.
         """
@@ -560,7 +577,7 @@ class BaseObject(Referenceable):
                 return site_properties.getProperty('default_charset')
         return 'utf-8'
 
-    security.declareProtected(CMFCorePermissions.View, 'get_size')
+    security.declareProtected(permissions.View, 'get_size')
     def get_size(self):
         """Used for FTP and apparently the ZMI now too.
         """
@@ -621,7 +638,7 @@ class BaseObject(Referenceable):
 
         self.reindexObject()
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'processForm')
     def processForm(self, data=1, metadata=0, REQUEST=None, values=None):
         """Processes the schema looking for data in the form.
@@ -639,6 +656,8 @@ class BaseObject(Referenceable):
         else:
             self.at_post_edit_script()
 
+        event.notify(objectevent.ObjectModifiedEvent(self))
+
     # This method is only called once after object creation.
     security.declarePrivate('at_post_create_script')
     def at_post_create_script(self):
@@ -649,7 +668,7 @@ class BaseObject(Referenceable):
     def at_post_edit_script(self):
         pass
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'markCreationFlag')
     def markCreationFlag(self):
         """Sets flag on the instance to indicate that the object hasn't been
@@ -669,7 +688,7 @@ class BaseObject(Referenceable):
             if meth in ('GET', 'POST'):
                 self._at_creation_flag = True
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'unmarkCreationFlag')
     def unmarkCreationFlag(self):
         """Removes the creation flag.
@@ -677,7 +696,7 @@ class BaseObject(Referenceable):
         if shasattr(aq_inner(self), '_at_creation_flag'):
             self._at_creation_flag = False
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'checkCreationFlag')
     def checkCreationFlag(self):
         """Returns True if the object has been fully saved, False otherwise.
@@ -744,16 +763,20 @@ class BaseObject(Referenceable):
         RENAME_AFTER_CREATION_ATTEMPTS, set in config.py. If no id can be
         found, return None.
         """
-        parent = aq_parent(aq_inner(self))
-        parent_ids = parent.objectIds()
+        check_id = getattr(self, 'check_id', None)
+        if check_id is None:
+            parent = aq_parent(aq_inner(self))
+            parent_ids = parent.objectIds()
+            check_id = lambda id, required: id in parent_ids
 
-        if id not in parent_ids:
+        invalid_id = check_id(id, required=1)
+        if not invalid_id:
             return id
 
         idx = 1
         while idx <= RENAME_AFTER_CREATION_ATTEMPTS:
             new_id = "%s-%d" % (id, idx)
-            if new_id not in parent_ids:
+            if not check_id(new_id, required=1):
                 return new_id
             idx += 1
 
@@ -774,12 +797,19 @@ class BaseObject(Referenceable):
             return script(id)
         return False
 
-    security.declareProtected(CMFCorePermissions.View, 'Schemata')
+    security.declareProtected(permissions.View, 'Schemata')
     def Schemata(self):
         """Returns the Schemata for the Object.
         """
         return getSchemata(self)
 
+    def Schema(self):
+        """Return a (wrapped) schema instance for
+        this object instance.
+        """
+        schema = self.schema
+        return ImplicitAcquisitionWrapper(schema, self)
+
     security.declarePrivate('_isSchemaCurrent')
     def _isSchemaCurrent(self):
         """Determines whether the current object's schema is up to date."""
@@ -874,7 +904,9 @@ class BaseObject(Referenceable):
             try:
                 if IFileField.isImplementedBy(field):
                     return field.getBaseUnit(self)
-            except ConflictError:
+
+
+            except (ConflictError, KeyboardInterrupt):
                 raise
             except:
                 pass
@@ -884,7 +916,9 @@ class BaseObject(Referenceable):
                 editAccessor = field.getEditAccessor(self)
                 if editAccessor:
                     return editAccessor()
-            except ConflictError:
+
+
+            except (ConflictError, KeyboardInterrupt):
                 raise
             except:
                 pass
@@ -894,7 +928,9 @@ class BaseObject(Referenceable):
                 accessor = field.getAccessor(self)
                 if accessor:
                     return accessor()
-            except ConflictError:
+
+
+            except (ConflictError, KeyboardInterrupt):
                 raise
             except:
                 pass
@@ -909,7 +945,9 @@ class BaseObject(Referenceable):
             # Because of this line value = value.replace(',','.')
             try:
                 return self[field.getName()]
-            except ConflictError:
+
+
+            except (ConflictError, KeyboardInterrupt):
                 raise
             except:
                 pass
@@ -923,7 +961,9 @@ class BaseObject(Referenceable):
                 editAccessor = new_field.getEditAccessor(self)
                 if editAccessor:
                     return editAccessor()
-            except ConflictError:
+
+
+            except (ConflictError, KeyboardInterrupt):
                 raise
             except:
                 pass
@@ -933,7 +973,9 @@ class BaseObject(Referenceable):
                 accessor = new_field.getAccessor(self)
                 if accessor:
                     return accessor()
-            except ConflictError:
+
+
+            except (ConflictError, KeyboardInterrupt):
                 raise
             except:
                 pass
@@ -941,7 +983,9 @@ class BaseObject(Referenceable):
             # Still no luck -- try to get the value directly using the new name
             try:
                 return self[new_field.getName()]
-            except ConflictError:
+
+
+            except (ConflictError, KeyboardInterrupt):
                 raise
             except:
                 pass
@@ -969,7 +1013,9 @@ class BaseObject(Referenceable):
                     args = [value,]
                     mapply(mutator, *args, **kw)
                     return
-                except ConflictError:
+
+
+                except (ConflictError, KeyboardInterrupt):
                     raise
                 except:
                     log_exc()
@@ -980,7 +1026,7 @@ class BaseObject(Referenceable):
                 return
         raise ValueError, 'name = %s, value = %s' % (name, value)
 
-    security.declareProtected(CMFCorePermissions.View, 'isTemporary')
+    security.declareProtected(permissions.View, 'isTemporary')
     def isTemporary(self):
         """Checks to see if we are created as temporary object by
         portal factory.
@@ -989,7 +1035,7 @@ class BaseObject(Referenceable):
         return shasattr(parent, 'meta_type') and \
                parent.meta_type == 'TempFolder'
 
-    security.declareProtected(CMFCorePermissions.View,
+    security.declareProtected(permissions.View,
                               'getFolderWhenPortalFactory')
     def getFolderWhenPortalFactory(self):
         """Returns the folder where this object was created temporarily.
@@ -1020,7 +1066,7 @@ class BaseObject(Referenceable):
     # Those objects are specific to a session.
     #
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'addSubObjects')
     def addSubObjects(self, objects, REQUEST=None):
         """Adds a dictionary of objects to a volatile attribute.
@@ -1033,7 +1079,7 @@ class BaseObject(Referenceable):
             for name, obj in objects.items():
                 storage[name] = aq_base(obj)
 
-    security.declareProtected(CMFCorePermissions.View, 'getSubObject')
+    security.declareProtected(permissions.View, 'getSubObject')
     def getSubObject(self, name, REQUEST, RESPONSE=None):
         """Gets a dictionary of objects from a volatile attribute.
         """
@@ -1072,19 +1118,30 @@ class BaseObject(Referenceable):
             if shasattr(self, name):
                 target = getattr(self, name)
         else:
-            # We are allowed to acquire
-            target = getattr(self, name, None)
+            if shasattr(self, name): # attributes of self come first
+                target = getattr(self, name)
+            else: # then views
+                target = queryMultiAdapter((self, REQUEST), Interface, name)
+                if target is not None:
+                    # We don't return the view, we raise an
+                    # AttributeError instead (below)
+                    target = None
+                else: # then acquired attributes
+                    target = getattr(self, name, None)
+
         if target is not None:
             return target
-        if (method in ('PUT', 'MKCOL') and not
-            isinstance(RESPONSE, xmlrpc.Response)):
+        elif (method not in ('GET', 'POST') and not
+              isinstance(RESPONSE, xmlrpc.Response) and
+              REQUEST.maybe_webdav_client):
             return NullResource(self, name, REQUEST).__of__(self)
-
-        # Nothing has been found. Raise an AttributeError and be done with it.
-        raise AttributeError(name)
+        else:
+            # Raising AttributeError will look up views for us
+            raise AttributeError(name)
 
 InitializeClass(BaseObject)
 
+
 class Wrapper(Explicit):
     """Wrapper object for access to sub objects."""
     __allow_access_to_unprotected_subobjects__ = 1
