@@ -9,7 +9,7 @@ from Products.Archetypes.interfaces.storage import IStorage
 from Products.Archetypes.interfaces.schema import ISchema, ISchemata, \
      IManagedSchema
 from Products.Archetypes.utils import OrderedDict, mapply, shasattr
-from Products.Archetypes.debug import log, warn, deprecated
+from Products.Archetypes.debug import log, warn
 from Products.Archetypes.exceptions import SchemaException
 from Products.Archetypes.exceptions import ReferenceException
 
@@ -17,7 +17,7 @@ from AccessControl import ClassSecurityInfo
 from Acquisition import aq_base, Explicit
 from ExtensionClass import Base
 from Globals import InitializeClass
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore import permissions
 
 __docformat__ = 'reStructuredText'
 _marker = []
@@ -64,7 +64,7 @@ class Schemata(Base):
             for field in fields:
                 self.addField(field)
 
-    security.declareProtected(CMFCorePermissions.View, 'getName')
+    security.declareProtected(permissions.View, 'getName')
     def getName(self):
         """Returns the Schemata's name."""
         return self.__name__
@@ -84,7 +84,7 @@ class Schemata(Base):
         return c
 
 
-    security.declareProtected(CMFCorePermissions.View, 'copy')
+    security.declareProtected(permissions.View, 'copy')
     def copy(self):
         """Returns a deep copy of this Schemata.
         """
@@ -94,16 +94,16 @@ class Schemata(Base):
         return c
 
 
-    security.declareProtected(CMFCorePermissions.View, 'fields')
+    security.declareProtected(permissions.View, 'fields')
     def fields(self):
         """Returns a list of my fields in order of their indices."""
         return [self._fields[name] for name in self._names]
 
 
-    security.declareProtected(CMFCorePermissions.View, 'values')
+    security.declareProtected(permissions.View, 'values')
     values = fields
 
-    security.declareProtected(CMFCorePermissions.View, 'editableFields')
+    security.declareProtected(permissions.View, 'editableFields')
     def editableFields(self, instance, visible_only=False):
         """Returns a list of editable fields for the given instance
         """
@@ -111,18 +111,18 @@ class Schemata(Base):
         for field in self.fields():
             if field.writeable(instance, debug=False) and    \
                    (not visible_only or
-                    field.widget.isVisible(instance, 'edit')!='invisible'):
+                    field.widget.isVisible(instance, 'edit')):
                 ret.append(field)
         return ret
 
-    security.declareProtected(CMFCorePermissions.View, 'viewableFields')
+    security.declareProtected(permissions.View, 'viewableFields')
     def viewableFields(self, instance):
         """Returns a list of viewable fields for the given instance
         """
         return [field for field in self.fields()
                 if field.checkPermission('view', instance)]
 
-    security.declareProtected(CMFCorePermissions.View, 'widgets')
+    security.declareProtected(permissions.View, 'widgets')
     def widgets(self):
         """Returns a dictionary that contains a widget for
         each field, using the field name as key."""
@@ -132,7 +132,7 @@ class Schemata(Base):
             widgets[f.getName()] = f.widget
         return widgets
 
-    security.declareProtected(CMFCorePermissions.View,
+    security.declareProtected(permissions.View,
                               'filterFields')
     def filterFields(self, *predicates, **values):
         """Returns a subset of self.fields(), containing only fields that
@@ -175,7 +175,7 @@ class Schemata(Base):
         assert name == field.getName()
         self.addField(field)
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'addField')
     def addField(self, field):
         """Adds a given field to my dictionary of fields."""
@@ -206,10 +206,9 @@ class Schemata(Base):
             res = self._checkPropertyDupe(field, pname)
             if res is not False:
                 res, value = res
-                deprecated(
-                    "Adding '%s' with property '%s' set "
-                    "to %s but '%s' has the same value. Re-using the property " 
-                    "above on different named fields is not allowed anymore." %
+                raise SchemaException(
+                    "Tried to add '%s' with property '%s' set "
+                    "to %s but '%s' has the same value." %
                     (name, pname, repr(value), res.getName())
                     )
         # Do not allowed unqualified references
@@ -233,29 +232,29 @@ class Schemata(Base):
     def __getitem__(self, name):
         return self._fields[name]
 
-    security.declareProtected(CMFCorePermissions.View, 'get')
+    security.declareProtected(permissions.View, 'get')
     def get(self, name, default=None):
         return self._fields.get(name, default)
 
-    security.declareProtected(CMFCorePermissions.View, 'has_key')
+    security.declareProtected(permissions.View, 'has_key')
     def has_key(self, name):
         return self._fields.has_key(name)
 
     __contains__ = has_key
 
-    security.declareProtected(CMFCorePermissions.View, 'keys')
+    security.declareProtected(permissions.View, 'keys')
     def keys(self):
         return self._names
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'delField')
     delField = __delitem__
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'updateField')
     updateField = addField
 
-    security.declareProtected(CMFCorePermissions.View, 'searchable')
+    security.declareProtected(permissions.View, 'searchable')
     def searchable(self):
         """Returns a list containing names of all searchable fields."""
 
@@ -312,7 +311,7 @@ class SchemaLayerContainer(DefaultLayerContainer):
             self.registerLayer('marshall', marshall)
 
     # ILayerRuntime
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'initializeLayers')
     def initializeLayers(self, instance, item=None, container=None):
         # scan each field looking for registered layers optionally
@@ -343,7 +342,7 @@ class SchemaLayerContainer(DefaultLayerContainer):
                     initializedLayers.append((layer, obj))
 
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'cleanupLayers')
     def cleanupLayers(self, instance, item=None, container=None):
         # scan each field looking for registered layers optionally
@@ -385,7 +384,7 @@ class SchemaLayerContainer(DefaultLayerContainer):
             c.registerLayer(k, v)
         return c
 
-    security.declareProtected(CMFCorePermissions.View, 'copy')
+    security.declareProtected(permissions.View, 'copy')
     def copy(self):
         c = SchemaLayerContainer()
         layers = {}
@@ -449,7 +448,7 @@ class BasicSchema(Schemata):
         c._props.update(self._props)
         return c
 
-    security.declareProtected(CMFCorePermissions.View, 'copy')
+    security.declareProtected(permissions.View, 'copy')
     def copy(self):
         """Returns a deep copy of this Schema.
         """
@@ -461,12 +460,12 @@ class BasicSchema(Schemata):
         c._props.update(self._props)
         return c
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'edit')
+    security.declareProtected(permissions.ModifyPortalContent, 'edit')
     def edit(self, instance, name, value):
         if self.allow(name):
             instance[name] = value
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'setDefaults')
     def setDefaults(self, instance):
         """Only call during object initialization. Sets fields to
@@ -492,7 +491,7 @@ class BasicSchema(Schemata):
                 kw['mimetype'] = field.default_content_type
             mapply(mutator, *args, **kw)
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'updateAll')
     def updateAll(self, instance, **kwargs):
         """This method mutates fields in the given instance.
@@ -522,11 +521,11 @@ class BasicSchema(Schemata):
             method = field.getMutator(instance)
             method(kwargs[name])
 
-    security.declareProtected(CMFCorePermissions.View, 'allow')
+    security.declareProtected(permissions.View, 'allow')
     def allow(self, name):
         return self.has_key(name)
 
-    security.declareProtected(CMFCorePermissions.View, 'validate')
+    security.declareProtected(permissions.View, 'validate')
     def validate(self, instance=None, REQUEST=None,
                  errors=None, data=None, metadata=None):
         """Validate the state of the entire object.
@@ -593,7 +592,7 @@ class BasicSchema(Schemata):
     # determining whether a schema has changed in the auto update
     # function.  Right now it's pretty crude.
     # XXX FIXME!
-    security.declareProtected(CMFCorePermissions.View,
+    security.declareProtected(permissions.View,
                               'toString')
     def toString(self):
         s = '%s: {' % self.__class__.__name__
@@ -602,13 +601,13 @@ class BasicSchema(Schemata):
         s = s + '}'
         return s
 
-    security.declareProtected(CMFCorePermissions.View,
+    security.declareProtected(permissions.View,
                               'signature')
     def signature(self):
         from md5 import md5
         return md5(self.toString()).digest()
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'changeSchemataForField')
     def changeSchemataForField(self, fieldname, schemataname):
         """ change the schemata for a field """
@@ -617,7 +616,7 @@ class BasicSchema(Schemata):
         field.schemata = schemataname
         self.addField(field)
 
-    security.declareProtected(CMFCorePermissions.View, 'getSchemataNames')
+    security.declareProtected(permissions.View, 'getSchemataNames')
     def getSchemataNames(self):
         """Return list of schemata names in order of appearing"""
         lst = []
@@ -626,14 +625,14 @@ class BasicSchema(Schemata):
                 lst.append(f.schemata)
         return lst
 
-    security.declareProtected(CMFCorePermissions.View, 'getSchemataFields')
+    security.declareProtected(permissions.View, 'getSchemataFields')
     def getSchemataFields(self, name):
         """Return list of fields belong to schema 'name'
         in order of appearing
         """
         return [f for f in self.fields() if f.schemata == name]
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'replaceField')
     def replaceField(self, name, field):
         if IField.isImplementedBy(field):
@@ -681,7 +680,7 @@ class Schema(BasicSchema, SchemaLayerContainer):
             c.registerLayer(k, v)
         return c
 
-    security.declareProtected(CMFCorePermissions.View, 'copy')
+    security.declareProtected(permissions.View, 'copy')
     def copy(self, factory=None):
         """Returns a deep copy of this Schema.
         """
@@ -698,17 +697,17 @@ class Schema(BasicSchema, SchemaLayerContainer):
             c.registerLayer(k, v)
         return c
 
-    security.declareProtected(CMFCorePermissions.View, 'wrapped')
+    security.declareProtected(permissions.View, 'wrapped')
     def wrapped(self, parent):
         schema = self.copy(factory=WrappedSchema)
         return schema.__of__(parent)
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'moveField')
     def moveField(self, name, direction=None, pos=None, after=None, before=None):
         """Move a field
 
-        >>> from Products.Archetypes.public import StringField as SF
+        >>> from Products.Archetypes.atapi import StringField as SF
         >>> schema = Schema((SF('a'), SF('b'), SF('c'),))
 
         >>> schema.keys()
@@ -888,7 +887,7 @@ class ManagedSchema(Schema):
 
     __implements__ = IManagedSchema, Schema.__implements__
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'delSchemata')
     def delSchemata(self, name):
         """Remove all fields belonging to schemata 'name'"""
@@ -896,7 +895,7 @@ class ManagedSchema(Schema):
             if f.schemata == name:
                 self.delField(f.getName())
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'addSchemata')
     def addSchemata(self, name):
         """Create a new schema by adding a new field with schemata 'name' """
@@ -906,7 +905,7 @@ class ManagedSchema(Schema):
             raise ValueError, "Schemata '%s' already exists" % name
         self.addField(StringField('%s_default' % name, schemata=name))
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'moveSchemata')
     def moveSchemata(self, name, direction):
         """Move a schemata to left (direction=-1) or to right
@@ -953,7 +952,7 @@ class MetadataSchema(Schema):
     security = ClassSecurityInfo()
     security.setDefaultAccess('allow')
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent,
+    security.declareProtected(permissions.ModifyPortalContent,
                               'addField')
     def addField(self, field):
         """Strictly enforce the contract that metadata is stored w/o
