@@ -40,7 +40,7 @@ from Products.Archetypes.tests.test_classgen import Dummy
 from Products.Archetypes.atapi import *
 from Products.Archetypes.config import PKG_NAME, LANGUAGE_DEFAULT
 from Products.Archetypes.interfaces.layer import ILayerContainer
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore import permissions
 from Products.Archetypes.ExtensibleMetadata import FLOOR_DATE
 from Products.Archetypes.ExtensibleMetadata import CEILING_DATE
 from Products.validation import ValidationChain
@@ -82,9 +82,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.isMetadata == 0)
         self.failUnless(field.accessor == 'getId')
         self.failUnless(field.mutator == 'setId')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'veVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'string')
@@ -111,9 +111,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.isMetadata == 0)
         self.failUnless(field.accessor == 'Title')
         self.failUnless(field.mutator == 'setTitle')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'veVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'string')
@@ -144,9 +144,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.accessor == 'isDiscussable')
         self.failUnless(field.mutator == 'allowDiscussion')
         self.failUnless(field.edit_accessor == 'editIsDiscussable')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'mVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'string')
@@ -175,9 +175,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.isMetadata == 1)
         self.failUnless(field.accessor == 'Subject')
         self.failUnless(field.mutator == 'setSubject')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'mVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'lines')
@@ -204,9 +204,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.isMetadata == 1)
         self.failUnless(field.accessor == 'Description')
         self.failUnless(field.mutator == 'setDescription')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'mVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'text')
@@ -233,9 +233,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.isMetadata == 1)
         self.failUnless(field.accessor == 'Contributors')
         self.failUnless(field.mutator == 'setContributors')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'mVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'lines')
@@ -262,9 +262,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.multiValued == 0)
         self.failUnless(field.isMetadata == 1)
         self.failUnless(field.mutator == 'setEffectiveDate')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'mVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'datetime')
@@ -291,9 +291,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.multiValued == 0)
         self.failUnless(field.isMetadata == 1)
         self.failUnless(field.mutator == 'setExpirationDate')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'mVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'datetime')
@@ -321,9 +321,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.isMetadata == 1)
         self.failUnless(field.accessor == 'Language')
         self.failUnless(field.mutator == 'setLanguage')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'mVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'string')
@@ -350,9 +350,9 @@ class BaseSchemaTest(ATSiteTestCase):
         self.failUnless(field.isMetadata == 1)
         self.failUnless(field.accessor == 'Rights')
         self.failUnless(field.mutator == 'setRights')
-        self.failUnless(field.read_permission == CMFCorePermissions.View)
+        self.failUnless(field.read_permission == permissions.View)
         self.failUnless(field.write_permission ==
-                        CMFCorePermissions.ModifyPortalContent)
+                        permissions.ModifyPortalContent)
         self.failUnless(field.generateMode == 'mVc')
         self.failUnless(field.force == '')
         self.failUnless(field.type == 'text')
