@@ -12,13 +12,14 @@
 ##############################################################################
 """ Views of filesystem directories as folders.
 
-$Id: DirectoryView.py 40138 2005-11-15 17:47:37Z jens $
+$Id: DirectoryView.py 68524 2006-06-08 16:54:49Z efge $
 """
 
 import re
 from os import path, listdir, stat
 from sys import exc_info
 from sys import platform
+import logging
 from warnings import warn
 
 from AccessControl import ClassSecurityInfo
@@ -31,10 +32,11 @@ from Globals import package_home
 from Globals import Persistent
 from OFS.Folder import Folder
 from OFS.ObjectManager import bad_id
-from zLOG import LOG, ERROR
+from zope.interface import implements
 
 from FSMetadata import FSMetadata
 from FSObject import BadFile
+from interfaces import IDirectoryView
 from permissions import AccessContentsInformation
 from permissions import ManagePortal
 from utils import _dtmldir
@@ -43,6 +45,9 @@ from utils import minimalpath
 from utils import normalize
 
 
+logger = logging.getLogger('CMFCore.DirectoryView')
+
+
 def expandpath(p):
     """ utils.expandpath() wrapper for backwards compatibility.
     """
@@ -150,10 +155,7 @@ class DirectoryInformation:
                     path.walk(self._filepath, self._walker, filelist)
                     filelist.sort()
             except:
-                LOG('DirectoryView',
-                    ERROR,
-                    'Error checking for directory modification',
-                    error=exc_info())
+                logger.exception("Error checking for directory modification")
 
             if mtime != self._v_last_read or filelist != self._v_last_filelist:
                 self._v_last_read = mtime
@@ -175,10 +177,7 @@ class DirectoryInformation:
                 self.data, self.objects = self.prepareContents(registry,
                     register_subdirs=changed)
             except:
-                LOG('DirectoryView',
-                    ERROR,
-                    'Error during prepareContents:',
-                    error=exc_info())
+                logger.exception("Error during prepareContents")
                 self.data = {}
                 self.objects = ()
 
@@ -247,12 +246,11 @@ class DirectoryInformation:
                         import traceback
                         typ, val, tb = exc_info()
                         try:
+                            logger.exception("prepareContents")
+
                             exc_lines = traceback.format_exception( typ,
                                                                     val,
                                                                     tb )
-                            LOG( 'DirectoryView', ERROR,
-                                 '\n'.join(exc_lines) )
-
                             ob = BadFile( name,
                                           entry_minimal_fp,
                                           exc_str='\r\n'.join(exc_lines),
@@ -268,20 +266,14 @@ class DirectoryInformation:
                             try:
                                 ob.manage_permission(name,roles,acquire)
                             except ValueError:
-                                LOG('DirectoryView',
-                                    ERROR,
-                                    'Error setting permissions',
-                                    error=exc_info())
+                                logger.exception("Error setting permissions")
 
                     # only DTML Methods and Python Scripts can have proxy roles
                     if hasattr(ob, '_proxy_roles'):
                         try:
                             ob._proxy_roles = tuple(metadata.getProxyRoles())
                         except:
-                            LOG('DirectoryView',
-                                ERROR,
-                                'Error setting proxy role',
-                                error=exc_info())
+                            logger.exception("Error setting proxy role")
 
                     ob_id = ob.getId()
                     data[ob_id] = ob
@@ -394,11 +386,14 @@ def listFolderHierarchy(ob, path, rval, adding_meta_type=None):
 class DirectoryView (Persistent):
     """ Directory views mount filesystem directories.
     """
+
+    implements(IDirectoryView)
+
     meta_type = 'Filesystem Directory View'
     _dirpath = None
     _objects = ()
 
-    def __init__(self, id, dirpath, fullname=None):
+    def __init__(self, id, dirpath='', fullname=None):
         self.id = id
         self._dirpath = dirpath
 
@@ -418,7 +413,7 @@ class DirectoryView (Persistent):
             if info is not None:
                 # update the directory view with a corrected path
                 self._dirpath = dirpath
-            else:
+            elif self._dirpath:
                 warn('DirectoryView %s refers to a non-existing path %s'
                      % (self.id, dirpath), UserWarning)
         if info is None:
@@ -440,6 +435,8 @@ class DirectoryViewSurrogate (Folder):
     """ Folderish DirectoryView.
     """
 
+    implements(IDirectoryView)
+
     meta_type = 'Filesystem Directory View'
     all_meta_types = ()
     _isDirectoryView = 1
