@@ -12,7 +12,7 @@
 ##############################################################################
 """ Basic textual content object, supporting HTML, STX and plain text.
 
-$Id: Document.py 37043 2005-06-14 16:39:34Z tiran $
+$Id: Document.py 70021 2006-09-07 10:16:08Z jens $
 """
 
 from AccessControl import ClassSecurityInfo
@@ -31,12 +31,17 @@ except ImportError:
 from Products.CMFCore.PortalContent import PortalContent
 from Products.CMFCore.utils import contributorsplitter
 from Products.CMFCore.utils import keywordsplitter
+from zope.interface import implements
 
+from Products.GenericSetup.interfaces import IDAVAware
 from DublinCore import DefaultDublinCoreImpl
 from exceptions import EditingConflict
 from exceptions import ResourceLockedError
-from interfaces.Document import IDocument
-from interfaces.Document import IMutableDocument
+from interfaces.Document import IDocument as z2IDocument
+from interfaces.Document import IMutableDocument as z2IMutableDocument
+from interfaces import IDocument
+from interfaces import IMutableDocument
+
 from permissions import ModifyPortalContent
 from permissions import View
 from utils import _dtmldir
@@ -90,7 +95,8 @@ def addDocument(self, id, title='', description='', text_format='',
 class Document(PortalContent, DefaultDublinCoreImpl):
     """ A Document - Handles both StructuredText and HTML """
 
-    __implements__ = (IDocument, IMutableDocument,
+    implements(IDocument, IMutableDocument, IDAVAware)
+    __implements__ = (z2IDocument, z2IMutableDocument,
                       PortalContent.__implements__,
                       DefaultDublinCoreImpl.__implements__)
 
