@@ -12,32 +12,25 @@
 ##############################################################################
 """ CMFDefault setup handlers.
 
-$Id: setuphandlers.py 39123 2005-10-14 03:50:12Z tseaver $
+$Id: setuphandlers.py 40391 2005-11-28 16:21:21Z yuppie $
 """
 
-from Products.CMFCore.utils import getToolByName
-
 from exceptions import BadRequest
-from Portal import PortalGenerator
 
 
 def importVarious(context):
-    """ Import various settings from PortalGenerator.
+    """ Import various settings.
 
     This provisional handler will be removed again as soon as full handlers
     are implemented for these steps.
     """
     site = context.getSite()
 
-    # add custom skin folder
-    stool = getToolByName(site, 'portal_skins')
     try:
-        stool.manage_addProduct['OFSP'].manage_addFolder(id='custom')
+        site.manage_addPortalFolder('Members')
     except BadRequest:
         return 'Various settings: Nothing to import.'
+    site.Members.manage_addProduct['OFSP'].manage_addDTMLMethod('index_html',
+                                        'Member list', '<dtml-return roster>')
 
-    gen = PortalGenerator()
-    gen.setupUserFolder(site)
-    gen.setupMembersFolder(site)
-
-    return 'Various settings from PortalGenerator imported.'
+    return 'Various settings imported.'
