@@ -1,7 +1,5 @@
-form_action_types = {}
-
 from __future__ import nested_scopes
-import os, string
+import os
 from AccessControl import ClassSecurityInfo
 import Globals
 from OFS.ObjectManager import bad_id
@@ -10,19 +8,15 @@ from ZPublisher.Publish import call_object, missing_name, dont_publish_class
 from ZPublisher.mapply import mapply
 from Products.CMFFormController import GLOBALS as fc_globals
 from Products.CMFCore.utils import getToolByName, UniqueObject, SimpleItemWithProperties
-# BBB CMF < 1.5
-try:
-    from Products.CMFCore.permissions import ManagePortal
-except ImportError:
-    from Products.CMFCore.CMFCorePermissions import ManagePortal
+from Products.CMFCore.permissions import ManagePortal
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from Products.CMFFormController.ControllerState import ControllerState
 from FormAction import FormActionType, FormActionKey, FormAction, FormActionContainer
 from FormValidator import FormValidatorKey, FormValidator, FormValidatorContainer
 from ValidationError import ValidationError
-from globalVars import ANY_CONTEXT, ANY_BUTTON
 
 _marker = []
+form_action_types = {}
 
 def registerFormAction(id, factory, description=''):
     form_action_types[id] = FormActionType(id, factory, description)
@@ -142,14 +136,14 @@ class FormController(UniqueObject, SimpleItemWithProperties):
 
 
     security.declareProtected(ManagePortal, 'listFormValidators')
-    def listFormValidators(self, override, **kwargs):
+    def listFormValidators(self, override=None, **kwargs):
         """Return a list of existing validators.  Validators can be filtered by
            specifying required attributes via kwargs"""
         return self.validators.getFiltered(**kwargs)
 
 
     security.declareProtected(ManagePortal, 'listFormActions')
-    def listFormActions(self, override, **kwargs):
+    def listFormActions(self, override=None, **kwargs):
         """Return a list of existing actions.  Actions can be filtered by
            specifying required attributes via kwargs"""
         return self.actions.getFiltered(**kwargs)
@@ -275,7 +269,7 @@ class FormController(UniqueObject, SimpleItemWithProperties):
         return REQUEST.RESPONSE.redirect(self.absolute_url()+'/manage_formActionsForm')
 
 
-    security.declarePrivate('_delFormAction')
+    security.declarePrivate('_delFormActions')
     def _delFormActions(self, container, REQUEST):
         for k in REQUEST.form.keys():
             if k.startswith('del_id_'):
@@ -437,7 +431,6 @@ class FormController(UniqueObject, SimpleItemWithProperties):
 
         def fn(obj, dict):
             dict[obj.getId()] = 0
-            print str(dict)
         meta_types = ['Controller Page Template', 'Controller Page Template (File)', 'Filesystem Controller Page Template', 'Controller Python Script', 'Filesystem Controller Python Script']
         portal = getToolByName(self, 'portal_url').getPortalObject()
         catalog = getToolByName(self, 'portal_catalog')
