@@ -1,10 +1,11 @@
+import logging
 import sys
 import traceback
-from zLOG import LOG, INFO, WARNING
 
+logger = logging.getLogger('CMFFormController')
 
-def log(summary='', text='', log_level=INFO):
-    LOG('Plone Debug', log_level, summary, text)
+def log(summary='', text='', log_level=logging.INFO):
+    logger.log(log_level, '%s \n%s' % (summary, text))
 
 # Enable scripts to get the string value of an exception
 # even if the thrown exception is a string and not a
@@ -14,7 +15,7 @@ def exceptionString():
                             # (otherwise will generate a circular reference)
     if s[0] == None:
         return None
-    if type(s[0]) == type(''):
+    if isinstance(s[0], basestring):
         return s[0]
     return str(s[1])
 
@@ -24,4 +25,4 @@ def logException():
     """Dump an exception to the log"""
     log(summary=str(exceptionString()),
         text='\n'.join(traceback.format_exception(*sys.exc_info())),
-        log_level=WARNING)
+        log_level=logging.WARNING)
