@@ -6,6 +6,8 @@ import time
 import urllib
 
 from Products.CMFCore.CatalogTool import CatalogTool as BaseTool
+from Products.CMFCore.CatalogTool import IndexableObjectWrapper
+
 from Products.CMFCore.permissions import ManagePortal
 from Products.CMFCore.permissions import AccessInactivePortalContent
 from Products.CMFPlone import ToolNames
@@ -21,11 +23,15 @@ from Products.CMFCore.utils import _getAuthenticatedUser
 from Products.CMFCore.utils import _checkPermission
 from Products.CMFCore.CatalogTool import _mergedLocalRoles
 from Products.CMFCore.interfaces.portal_catalog \
-        import IndexableObjectWrapper as IIndexableObjectWrapper
+        import IndexableObjectWrapper as z2IIndexableObjectWrapper
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
-from Products.CMFPlone.interfaces.NonStructuralFolder import INonStructuralFolder
+from Products.CMFPlone.interfaces import INonStructuralFolder
+from Products.CMFPlone.interfaces.NonStructuralFolder import \
+     INonStructuralFolder as z2INonStructuralFolder
 from Products.CMFPlone.utils import base_hasattr
 from Products.CMFPlone.utils import safe_callable
+from Products.CMFPlone.utils import safe_unicode
+from Products.CMFPlone.utils import log_deprecated
 from OFS.IOrderSupport import IOrderedContainer
 from ZODB.POSException import ConflictError
 
@@ -35,6 +41,8 @@ from AccessControl.Permissions import manage_zcatalog_entries as ManageZCatalogE
 from AccessControl.Permissions import search_zcatalog as SearchZCatalog
 from AccessControl.PermissionRole import rolesForPermissionOn
 
+from zope.interface import implements
+
 _marker = object()
 
 
@@ -57,7 +65,7 @@ _eioRegistry = ExtensibleIndexableObjectRegistry()
 registerIndexableAttribute = _eioRegistry.register
 
 
-class ExtensibleIndexableObjectWrapper(object):
+class ExtensibleIndexableObjectWrapper(IndexableObjectWrapper):
     """Extensible wrapper for object indexing.
 
     vars - additional vars as a dict, used for workflow vars like review_state
@@ -67,11 +75,10 @@ class ExtensibleIndexableObjectWrapper(object):
     **kwargs - additional keyword arguments
     """
 
-    __implements__ = IIndexableObjectWrapper
+    __implements__ = z2IIndexableObjectWrapper
 
     def __init__(self, vars, obj, portal, registry = _eioRegistry, **kwargs):
-        self._vars = vars
-        self._obj = obj
+        super(ExtensibleIndexableObjectWrapper, self).__init__(vars, obj)
         self._portal = portal
         self._registry = registry
         self._kwargs = kwargs
@@ -80,8 +87,8 @@ class ExtensibleIndexableObjectWrapper(object):
         return vars, obj, kwargs
 
     def __getattr__(self, name):
-        vars = self._vars
-        obj = self._obj
+        vars = self._IndexableObjectWrapper__vars
+        obj = self._IndexableObjectWrapper__ob
         kwargs = self._kwargs
         registry = self._registry
 
@@ -89,9 +96,11 @@ class ExtensibleIndexableObjectWrapper(object):
 
         if registry.has_key(name):
             return registry[name](obj, portal=self._portal, vars=vars, **kwargs)
-        if vars.has_key(name):
-            return vars[name]
-        return getattr(obj, name)
+        return super(ExtensibleIndexableObjectWrapper, self).__getattr__(name)
+    
+    def allowedRolesAndUsers(self):
+        # Disable CMFCore version of this method; use registry hook instead
+        return self.__getattr__('allowedRolesAndUsers')
 
 
 def allowedRolesAndUsers(obj, portal, **kwargs):
@@ -125,14 +134,13 @@ num_sort_regex = re.compile('\d+')
 
 def sortable_title(obj, portal, **kwargs):
     """ Helper method for to provide FieldIndex for Title.
-    
+
     >>> from Products.CMFPlone.CatalogTool import sortable_title
 
     >>> self.folder.setTitle('Plone42 _foo')
     >>> sortable_title(self.folder, self.portal)
     'plone00000042 _foo'
     """
-    def_charset = portal.plone_utils.getSiteEncoding()
     title = getattr(obj, 'Title', None)
     if title is not None:
         if safe_callable(title):
@@ -142,17 +150,7 @@ def sortable_title(obj, portal, **kwargs):
             # Replace numbers with zero filled numbers
             sortabletitle = num_sort_regex.sub(zero_fill, sortabletitle)
             # Truncate to prevent bloat
-            for charset in [def_charset, 'latin-1', 'utf-8']:
-                try:
-                    sortabletitle = unicode(sortabletitle, charset)[:30]
-                    sortabletitle = sortabletitle.encode(def_charset or 'utf-8')
-                    break
-                except UnicodeError:
-                    pass
-                except TypeError:
-                    # If we get a TypeError if we already have a unicode string
-                    sortabletitle = sortabletitle[:30]
-                    break
+            sortabletitle = safe_unicode(sortabletitle)[:30].encode('utf-8')
             return sortabletitle
     return ''
 
@@ -225,19 +223,54 @@ def is_folderish(obj, **kwargs):
     """Should this item be treated as a folder?
 
     Checks isPrincipiaFolderish, as well as the INonStructuralFolder
-    interface.
+    interfaces.
 
-    >>> from Products.CMFPlone.CatalogTool import is_folderish
+      >>> from Products.CMFPlone.CatalogTool import is_folderish
+      >>> from Products.CMFPlone.interfaces import INonStructuralFolder
+      >>> from Products.CMFPlone.interfaces.NonStructuralFolder import INonStructuralFolder as z2INonStructuralFolder
+      >>> from zope.interface import directlyProvidedBy, directlyProvides
+
+    A Folder is folderish generally::
+      >>> is_folderish(self.folder)
+      True
+
+    But if we make it an INonStructuralFolder it is not::
+      >>> base_implements = directlyProvidedBy(self.folder)
+      >>> directlyProvides(self.folder, INonStructuralFolder, directlyProvidedBy(self.folder))
+      >>> is_folderish(self.folder)
+      False
+      
+    Now we revert our interface change and apply the z2 no-folderish interface::
+      >>> directlyProvides(self.folder, base_implements)
+      >>> is_folderish(self.folder)
+      True
+      >>> z2base_implements = self.folder.__implements__
+      >>> self.folder.__implements__ = z2base_implements + (z2INonStructuralFolder,)
+      >>> is_folderish(self.folder)
+      False
+
+    We again revert the interface change and check to make sure that
+    PrincipiaFolderish is respected::
+      >>> self.folder.__implements__ = z2base_implements
+      >>> is_folderish(self.folder)
+      True
+      >>> self.folder.isPrincipiaFolderish = False
+      >>> is_folderish(self.folder)
+      False
 
-    >>> is_folderish(self.folder)
-    True
     """
     # If the object explicitly states it doesn't want to be treated as a
     # structural folder, don't argue with it.
-    if INonStructuralFolder.isImplementedBy(obj):
+    folderish = bool(getattr(aq_base(obj), 'isPrincipiaFolderish', False))
+    if not folderish:
+        return False
+    elif INonStructuralFolder.providedBy(obj):
+        return False
+    elif z2INonStructuralFolder.isImplementedBy(obj):
+        # BBB: for z2 interface compat
         return False
     else:
-        return bool(getattr(aq_base(obj), 'isPrincipiaFolderish', False))
+        return folderish
 
 registerIndexableAttribute('is_folderish', is_folderish)
 
@@ -274,64 +307,9 @@ class CatalogTool(PloneBaseTool, BaseTool):
 
     def __init__(self):
         ZCatalog.__init__(self, self.getId())
+        log_deprecated("CatalogTool._initIndexes is deprecated, please use a GenericSetup profile instead.")
         self._initIndexes()
 
-    security.declarePublic('enumerateIndexes')
-    def enumerateIndexes(self):
-
-        idxs = ( ('Subject', 'KeywordIndex')
-               , ('Creator', 'FieldIndex')
-               , ('Date', 'DateIndex')
-               , ('Type', 'FieldIndex')
-               , ('created', 'DateIndex')
-               , ('effective', 'DateIndex')
-               , ('expires', 'DateIndex')
-               , ('modified', 'DateIndex')
-               , ('allowedRolesAndUsers', 'KeywordIndex')
-               , ('review_state', 'FieldIndex')
-               , ('in_reply_to', 'FieldIndex')
-               , ('meta_type', 'FieldIndex')
-               , ('id', 'FieldIndex')
-               , ('getId', 'FieldIndex')
-               , ('path', 'ExtendedPathIndex')
-               , ('portal_type', 'FieldIndex')
-               , ('getObjPositionInParent', 'FieldIndex')
-               , ('is_folderish', 'FieldIndex')
-               , ('is_default_page', 'FieldIndex')
-               )
-        return tuple([(n, t, None) for n, t in idxs])
-
-    security.declarePublic('enumerateColumns')
-    def enumerateColumns(self):
-        """Return a sequence of schema names to be cached.
-
-        Creator is deprecated and may go away, use listCreators!
-        """
-        return ( 'Subject'
-               , 'Title'
-               , 'Description'
-               , 'Type'
-               , 'review_state'
-               , 'Creator'
-               , 'listCreators'
-               , 'Date'
-               , 'getIcon'
-               , 'created'
-               , 'effective'
-               , 'expires'
-               , 'modified'
-               , 'CreationDate'
-               , 'EffectiveDate'
-               , 'ExpirationDate'
-               , 'ModificationDate'
-               , 'getId'
-               , 'portal_type'
-               # plone metadata
-               , 'id', # BBB to be removed in Plone 2.5
-               'getObjSize',
-               'exclude_from_nav',
-               )
-
     def _removeIndex(self, index):
         """Safe removal of an index.
         """
@@ -340,58 +318,6 @@ class CatalogTool(PloneBaseTool, BaseTool):
         except:
             pass
 
-    def manage_afterAdd(self, item, container):
-        self._createTextIndexes(item, container)
-
-    def _createTextIndexes(self, item, container):
-        """In addition to the standard indexes we need to create
-           'SearchableText', 'Title' and 'Description' as ZCTextIndex instance.
-        """
-
-        class args:
-            def __init__(self, **kw):
-                self.__dict__.update(kw)
-            def keys(self):
-                return self.__dict__.keys()
-
-        # This if-clause still looks somewhat scary
-        if item is self and not hasattr(aq_base(self), 'plone_lexicon'):
-
-            # We need to remove the indexes to keep the tests working...baaah
-            for idx in ('SearchableText', 'Title', 'Description'):
-                self._removeIndex(idx)
-
-            self.manage_addProduct['ZCTextIndex'].manage_addLexicon(
-                'plone_lexicon',
-                elements=[
-                    args(group='Case Normalizer', name='Case Normalizer'),
-                    args(group='Stop Words', name=" Don't remove stop words"),
-                    args(group='Word Splitter', name="Unicode Whitespace splitter"),
-                ]
-                )
-
-            extra = args(doc_attr='SearchableText',
-                         lexicon_id='plone_lexicon',
-                         index_type='Okapi BM25 Rank')
-            self.manage_addIndex('SearchableText', 'ZCTextIndex', extra=extra)
-
-            extra = args(doc_attr='Description',
-                         lexicon_id='plone_lexicon',
-                         index_type='Okapi BM25 Rank')
-            self.manage_addIndex('Description', 'ZCTextIndex', extra=extra)
-
-            extra = args(doc_attr='Title',
-                         lexicon_id='plone_lexicon',
-                         index_type='Okapi BM25 Rank')
-            self.manage_addIndex('Title', 'ZCTextIndex', extra=extra)
-
-    security.declareProtected(ManagePortal, 'migrateIndexes')
-    def migrateIndexes(self):
-        """Recreate all indexes.
-        """
-        self._initIndexes()
-        self._createTextIndexes()
-
     def _listAllowedRolesAndUsers(self, user):
         """Makes sure the list includes the user's groups.
         """
@@ -427,17 +353,8 @@ class CatalogTool(PloneBaseTool, BaseTool):
             vars = {}
         portal = aq_parent(aq_inner(self))
         w = ExtensibleIndexableObjectWrapper(vars, object, portal=portal)
-        try:
-            # pghandler argument got added in Zope 2.8
-            ZCatalog.catalog_object(self, w, uid, idxs,
-                                    update_metadata, pghandler=pghandler)
-        except TypeError:
-            try:
-                # update_metadata argument got added somewhere into
-                # the Zope 2.6 line (?)
-                ZCatalog.catalog_object(self, w, uid, idxs, update_metadata)
-            except TypeError:
-                ZCatalog.catalog_object(self, w, uid, idxs)
+        ZCatalog.catalog_object(self, w, uid, idxs,
+                                update_metadata, pghandler=pghandler)
 
     security.declareProtected(SearchZCatalog, 'searchResults')
     def searchResults(self, REQUEST=None, **kw):
@@ -447,7 +364,7 @@ class CatalogTool(PloneBaseTool, BaseTool):
         This version uses the 'effectiveRange' DateRangeIndex.
 
         It also accepts a keyword argument show_inactive to disable
-        effectiveRange checking entirely even for those withot portal
+        effectiveRange checking entirely even for those without portal
         wide AccessInactivePortalContent permission.
         """
         kw = kw.copy()
@@ -458,10 +375,6 @@ class CatalogTool(PloneBaseTool, BaseTool):
 
         if not show_inactive and not _checkPermission(AccessInactivePortalContent, self):
             kw['effectiveRange'] = DateTime()
-            if kw.has_key('effective'):
-                del kw['effective']
-            if kw.has_key('expires'):
-                del kw['expires']
 
         return ZCatalog.searchResults(self, REQUEST, **kw)
 
