@@ -4,13 +4,13 @@ from AccessControl import Owned, ClassSecurityInfo, getSecurityManager
 from AccessControl.Permission import Permission
 from Acquisition import aq_parent, aq_base, aq_inner, aq_get
 from OFS.SimpleItem import SimpleItem
-from StructuredText.StructuredText import HTML
 from ZPublisher.Publish import call_object, missing_name, dont_publish_class
 from ZPublisher.mapply import mapply
 from Products.CMFPlone import cmfplone_globals
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from Products.CMFCore.permissions import ManagePortal
 from Products.CMFCore.utils import UniqueObject, getToolByName
+from StructuredText.StructuredText import HTML
 from Products.CMFPlone.PloneFolder import PloneFolder as TempFolderBase
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
 from Products.CMFPlone.utils import base_hasattr
@@ -167,7 +167,7 @@ class TempFolder(TempFolderBase):
             return (aq_base(obj).__of__(temp_folder)).__of__(intended_parent)
 
     # ignore rename requests since they don't do anything
-    def manage_renameObject(self, id1, id2):
+    def manage_renameObject(self, id, new_id, REQUEST=None):
         pass
 
 
@@ -254,7 +254,8 @@ class FactoryTool(PloneBaseTool, UniqueObject, SimpleItem):
             folder.invokeFactory(id=id, type_name=type_name)
             obj = getattr(folder, id)
 
-            # give ownership to currently authenticated member if not anonymous  XXX is this necessary?
+            # give ownership to currently authenticated member if not anonymous
+            # TODO is this necessary?
             membership_tool = getToolByName(self, 'portal_membership')
             if not membership_tool.isAnonymousUser():
                 member = membership_tool.getAuthenticatedMember()
