@@ -1,3 +1,7 @@
+from warnings import warn
+warn('FolderWorkflow is deprecated and will be removed in Plone 3.0. '
+     'Please use a GenericSetup profile instead.', DeprecationWarning)
+
 from Products.CMFCore.WorkflowTool import addWorkflowFactory
 from Products.DCWorkflow.DCWorkflow import DCWorkflowDefinition
 from Products.CMFCore.permissions import AccessContentsInformation, \
@@ -37,7 +41,7 @@ def setupPrivateFolderWorkflow(wf):
     setupFolderWorkflow(wf)
     wf.states.visible.permission_roles[View] = ('Member', 'Reviewer', 'Manager')
     wf.states.published.permission_roles[ListFolderContents] = ('Authenticated', 'Manager')
-    wf.states.published.permission_roles[permissions.View] = ('Member', 'Reviewer', 'Manager')
+    wf.states.published.permission_roles[View] = ('Member', 'Reviewer', 'Manager')
     wf.states.setInitialState(id='private')
 
     wf.states.addState('public')
@@ -66,7 +70,3 @@ def createPrivateFolderWorkflow(id):
     ob.setProperties(title='Private Folder Workflow [Plone]')
     return ob
 
-# Will go into PloneWorkflows product
-#addWorkflowFactory( createPrivateFolderWorkflow,
-#                    id='private_folder_workflow',
-#                    title='Private Folder Workflow [Plone]' )
