@@ -9,6 +9,7 @@ from AccessControl import ClassSecurityInfo
 from Acquisition import aq_base
 from Products.BTreeFolder2.BTreeFolder2 import BTreeFolder2
 from Products.CMFCore.utils import getToolByName
+from Products.CMFPlone.utils import log_deprecated
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
 from Products.CMFCore.permissions import SetOwnProperties, ManagePortal
 from ZODB.POSException import ConflictError
@@ -19,7 +20,7 @@ class MemberDataTool(PloneBaseTool, BaseTool):
     meta_type = ToolNames.MemberDataTool
     security = ClassSecurityInfo()
     toolicon = 'skins/plone_images/user.gif'
-    
+
     __implements__ = (PloneBaseTool.__implements__, BaseTool.__implements__, )
 
 
@@ -111,7 +112,7 @@ class MemberDataTool(PloneBaseTool, BaseTool):
             count += 1
 
         return count
-                
+
 
     security.declarePrivate( 'searchMemberDataContents' )
     def searchMemberDataContents( self, search_param, search_term ):
@@ -122,7 +123,7 @@ class MemberDataTool(PloneBaseTool, BaseTool):
         res = []
 
         search_term = search_term.strip().lower()
-        
+
         if search_param == 'username':
             search_param = 'id'
 
@@ -147,7 +148,7 @@ class MemberDataTool(PloneBaseTool, BaseTool):
 
     security.declarePublic( 'searchFulltextForMembers' )
     def searchFulltextForMembers(self, s):
-        """search for members which do have string 's' in name, email or full name (if defined) 
+        """search for members which do have string 's' in name, email or full name (if defined)
 
         this is mainly used for the localrole form
         """
@@ -184,6 +185,7 @@ class MemberData(BaseData):
     _is_new_kind = 1
 
     def __init__(self, *args, **kw):
+        log_deprecated("The CMFPlone.MemberData class will be removed in Plone 3.0")
         BaseData.__init__(self, *args, **kw)
 
     security.declareProtected(SetOwnProperties, 'setProperties')
@@ -192,6 +194,7 @@ class MemberData(BaseData):
         Accepts either keyword arguments or a mapping for the "properties"
         argument.
         '''
+        log_deprecated("The CMFPlone.MemberData class will be removed in Plone 3.0")
         if properties is None:
             properties = kw
         membership = getToolByName(self, 'portal_membership')
@@ -209,6 +212,7 @@ class MemberData(BaseData):
 
     security.declarePublic('getProperty')
     def getProperty(self, id, default=_marker):
+        log_deprecated("The CMFPlone.MemberData class will be removed in Plone 3.0")
         tool = self.getTool()
         base = aq_base( self )
 
@@ -246,13 +250,14 @@ class MemberData(BaseData):
 
         # Otherwise return the tool value
         return tool_value
-        
+
 
     security.declarePrivate('setMemberProperties')
     def setMemberProperties(self, mapping, force_local = 0):
         '''Sets the properties of the member.
         If force_local is true, values will not be stored in the underlying user folder
         '''
+        log_deprecated("The CMFPlone.MemberData class will be removed in Plone 3.0")
         # Sets the properties given in the MemberDataTool.
         tool = self.getTool()
         for id in tool.propertyIds():
@@ -268,7 +273,7 @@ class MemberData(BaseData):
                     try:
                         if force_local:
                             raise RuntimeError, "Force storing in the MemberData object"
-                            
+
                         # If it works, add a marker to retreive the data from the user object
                         self.setProperty(id, value)             # This is GRUF's method
                         setattr(self, "%s_USER" % id, 1)
@@ -278,7 +283,7 @@ class MemberData(BaseData):
                         # It didn't work... use the regular way, then - and remove the marker
                         setattr(self, id, value)
                         setattr(self, "%s_USER" % id, 0)        # Remove the marker
-                    
+
         # Hopefully we can later make notifyModified() implicit.
         self.notifyModified()
 
