@@ -3,7 +3,6 @@ from cStringIO import StringIO
 from DateTime import DateTime
 from Products.CMFCore.utils import getToolByName, _checkPermission
 from Products.CMFDefault.MembershipTool import MembershipTool as BaseTool
-from Products.CMFPlone import transaction
 from Products.CMFPlone import ToolNames
 from Products.CMFPlone.utils import scale_image
 from Products.CMFPlone.utils import _createObjectByType
@@ -21,19 +20,10 @@ from Products.CMFCore.permissions import SetOwnPassword
 from Products.CMFCore.permissions import View
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
 from Products.CMFPlone.log import log
+from Products.CMFPlone.utils import postonly
 
 default_portrait = 'defaultUser.gif'
 
-DEFAULT_MEMBER_CONTENT = """\
-Default page for %s
-
-  This is the default document created for you when
-  you joined this community.
-
-  To change the content just click the 'edit'
-  tab above.
-"""
-
 _marker = object()
 
 class MembershipTool(PloneBaseTool, BaseTool):
@@ -98,9 +88,10 @@ class MembershipTool(PloneBaseTool, BaseTool):
 
         memberinfo = { 'fullname'    : member.getProperty('fullname'),
                        'description' : member.getProperty('description'),
-                       'location' : member.getProperty('location'),
-                       'language' : member.getProperty('language'),
-                       'home_page' : member.getProperty('home_page'),
+                       'location'    : member.getProperty('location'),
+                       'language'    : member.getProperty('language'),
+                       'home_page'   : member.getProperty('home_page'),
+                       'username'    : member.getUserName(),
                      }
 
         return memberinfo
@@ -119,7 +110,7 @@ class MembershipTool(PloneBaseTool, BaseTool):
         if type(portrait) == type(''):
             portrait = None
         if portrait is not None:
-            if verifyPermission and not _checkPermission(View, portrait):
+            if verifyPermission and not _checkPermission('View', portrait):
                 # Don't return the portrait if the user can't get to it
                 portrait = None
         if portrait is None:
@@ -128,7 +119,7 @@ class MembershipTool(PloneBaseTool, BaseTool):
 
         return portrait
 
-    security.declareProtected(SetOwnProperties, 'deletePersonalPortrait')
+    security.declareProtected(SetOwnProperties, 'deletePersonalPortrait') 
     def deletePersonalPortrait(self, member_id = None):
         """
         deletes the Portrait of member_id
@@ -193,12 +184,6 @@ class MembershipTool(PloneBaseTool, BaseTool):
             membertool   = getToolByName(self, 'portal_memberdata')
             membertool._setPortrait(portrait, member_id)
 
-
-##     security.declarePrivate('wrapUser')
-##     def wrapUser(self, u):
-##         self.createMemberarea(u.getId())
-##         return BaseTool.wrapUser(self, u)
-
     security.declarePublic('createMemberarea')
     def createMemberarea(self, member_id=None, minimal=1):
         """
@@ -245,8 +230,6 @@ class MembershipTool(PloneBaseTool, BaseTool):
 
         ## translate the default content
 
-        # get some translation interfaces
-
         translation_service = getToolByName(self, 'translation_service', _marker)
         if translation_service is _marker:
             # test environ, some other aberent sitch
@@ -256,7 +239,7 @@ class MembershipTool(PloneBaseTool, BaseTool):
         encode = translation_service.encode
 
         # convert the member_id to unicode type
-        umember_id = translation_service.asunicodetype(member_id, errors='replace')
+        umember_id = translation_service.asunicodetype(user.getUserName(), errors='replace')
 
         member_folder_title = utranslate(
             'plone', 'title_member_folder',
@@ -499,7 +482,6 @@ class MembershipTool(PloneBaseTool, BaseTool):
     security.declareProtected(SetOwnPassword, 'testCurrentPassword')
     def testCurrentPassword(self, password):
         """ test to see if password is current """
-        portal=getToolByName(self, 'portal_url').getPortalObject()
         REQUEST=getattr(self, 'REQUEST', {})
         userid=self.getAuthenticatedMember().getUserId()
         acl_users = self._findUsersAclHome(userid)
@@ -522,7 +504,7 @@ class MembershipTool(PloneBaseTool, BaseTool):
             return None
 
     security.declareProtected(SetOwnPassword, 'setPassword')
-    def setPassword(self, password, domains=None):
+    def setPassword(self, password, domains=None, REQUEST=None):
         '''Allows the authenticated member to set his/her own password.
         '''
         registration = getToolByName(self, 'portal_registration', None)
@@ -549,6 +531,7 @@ class MembershipTool(PloneBaseTool, BaseTool):
             self.credentialsChanged(password)
         else:
             raise BadRequest, 'Not logged in.'
+    setPassword = postonly(setPassword)
 
     security.declareProtected(View, 'getCandidateLocalRoles')
     def getCandidateLocalRoles(self, obj):
@@ -583,10 +566,10 @@ class MembershipTool(PloneBaseTool, BaseTool):
         if not self.isAnonymousUser():
             member = self.getAuthenticatedMember()
             login_time = member.getProperty('login_time', '2000/01/01')
-            if  str(login_time) == '2000/01/01':
+            if str(login_time) == '2000/01/01':
                 login_time = self.ZopeTime()
-            member.setProperties(login_time=login_time,
-                                 last_login_time=self.ZopeTime())
+            member.setProperties(login_time=self.ZopeTime(),
+                                 last_login_time=login_time)
 
     security.declareProtected(ManagePortal, 'getBadMembers')
     def getBadMembers(self):
@@ -597,6 +580,7 @@ class MembershipTool(PloneBaseTool, BaseTool):
         if portraits is None:
             return []
         bad_member_ids = []
+        import transaction
         TXN_THRESHOLD = 50
         counter = 1
         for member_id in tuple(portraits.objectIds()):
