@@ -14,10 +14,9 @@ from OFS.ObjectManager import REPLACEABLE
 from DocumentTemplate.sequence import sort
 from webdav.NullResource import NullResource
 from webdav.WriteLockInterface import WriteLockInterface
+from webdav.interfaces import IWriteLock
 
 from Products.CMFCore.utils import getToolByName
-from Products.CMFCore.utils import getActionContext
-from Products.CMFCore.utils import _verifyActionPermissions
 from Products.CMFCore.CMFCatalogAware import CMFCatalogAware
 from Products.CMFCore.PortalFolder import PortalFolderBase
 from Products.CMFCore.permissions import AccessContentsInformation, \
@@ -25,6 +24,11 @@ from Products.CMFCore.permissions import AccessContentsInformation, \
                     ManageProperties, ModifyPortalContent, View
 from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
 
+from Products.CMFPlone import PloneMessageFactory as _
+
+from zope.interface import implements
+from zope.app.container.contained import notifyContainerModified
+
 # ATM it's safer to define our own
 from interfaces.OrderedContainer import IOrderedContainer
 
@@ -49,8 +53,8 @@ class ReplaceableWrapper:
 factory_type_information = {
     'id': 'Folder',
     'meta_type': 'Plone Folder',
-    'description': ("Plone folders can define custom 'view' actions, or will "
-                    "behave like directory " "listings without one defined."),
+    'description': (_(u"Plone folders can define custom 'view' actions, or will "
+                    "behave like directory listings without one defined.")),
     'icon': 'folder_icon.gif',
     'product': 'CMFPlone',
     'factory': 'addPloneFolder',
@@ -59,28 +63,28 @@ factory_type_information = {
     'actions': (
         {
             'id': 'view',
-            'name': 'View',
+            'name': _(u'View'),
             'action': 'string:${folder_url}/',
             'permissions': (View,),
             'category': 'folder',
         },
         {
             'id': 'local_roles',
-            'name': 'Local Roles',
+            'name': _(u'Local Roles'),
             'action': 'string:${folder_url}/folder_localrole_form',
             'permissions': (ManageProperties,),
             'category': 'folder',
         },
         {
             'id': 'edit',
-            'name': 'Edit',
+            'name': _(u'Edit'),
             'action': 'string:${folder_url}/folder_edit_form',
             'permissions': (ModifyPortalContent,),
             'category': 'folder',
         },
         {
             'id': 'folderlisting',
-            'name': 'Folder Listing',
+            'name': _(u'Folder Listing'),
             'action': 'string:${folder_url}/folder_listing',
             'permissions': (View,),
             'category': 'folder',
@@ -126,7 +130,8 @@ class OrderedContainer(Folder):
     # the 2.7 specific class OFS.OrderedContainer.OrderedContainer
 
     security.declareProtected(ModifyPortalContent, 'moveObjectsByDelta')
-    def moveObjectsByDelta(self, ids, delta, subset_ids=None):
+    def moveObjectsByDelta(self, ids, delta, subset_ids=None,
+                           suppress_events=False):
         """Move specified sub-objects by delta."""
         if type(ids) is StringType:
             ids = (ids,)
@@ -172,6 +177,10 @@ class OrderedContainer(Folder):
                         raise ValueError('The object with the id "%s" does '
                                          'not exist.' % subset_ids[pos])
             self._objects = tuple(objects)
+
+        if not suppress_events:
+            notifyContainerModified(self)
+
         return counter
 
     security.declarePrivate('getCMFObjectsSubsetIds')
@@ -221,10 +230,11 @@ class OrderedContainer(Folder):
             RESPONSE.redirect('manage_workspace')
 
     security.declareProtected(ModifyPortalContent, 'moveObjectToPosition')
-    def moveObjectToPosition(self, id, position):
+    def moveObjectToPosition(self, id, position, suppress_events=False):
         """Move specified object to absolute position."""
         delta = position - self.getObjectPosition(id)
-        return self.moveObjectsByDelta(id, delta)
+        return self.moveObjectsByDelta(id, delta,
+                                       suppress_events=suppress_events)
 
     security.declareProtected(ModifyPortalContent, 'orderObjects')
     def orderObjects(self, key, reverse=None):
@@ -258,6 +268,8 @@ class BasePloneFolder(CMFCatalogAware, PortalFolderBase, DefaultDublinCoreImpl):
     __implements__ = DefaultDublinCoreImpl.__implements__ + \
                      (PortalFolderBase.__implements__,WriteLockInterface)
 
+    implements(IWriteLock)
+
     manage_options = Folder.manage_options + \
                      CMFCatalogAware.manage_options
 
@@ -278,11 +290,18 @@ class BasePloneFolder(CMFCatalogAware, PortalFolderBase, DefaultDublinCoreImpl):
 
     def __call__(self):
         """Invokes the default view."""
-        view = _getViewFor(self, 'view', 'folderlisting')
-        if getattr(aq_base(view), 'isDocTemp', 0):
-            return view(*(self, self.REQUEST))
+        ti = self.getTypeInfo()
+        method_id = ti and ti.queryMethodId('(Default)', context=self)
+        if method_id:
+            method = getattr(self, method_id)
+            # XXX view is not defined!
+            if getattr(aq_base(view), 'isDocTemp', 0):
+                return method(self, self.REQUEST, self.REQUEST['RESPONSE'])
+            else:
+                return method()
         else:
-            return view()
+            raise NotFound( 'Cannot find default view for "%s"' %
+                            '/'.join( self.getPhysicalPath() ) )
 
     security.declareProtected(Permissions.view, 'view')
     view = __call__
@@ -315,7 +334,7 @@ class BasePloneFolder(CMFCatalogAware, PortalFolderBase, DefaultDublinCoreImpl):
         if REQUEST is not None:
             # TODO HARDCODED FIXME!
             return self.folder_contents(self, REQUEST,
-                                        portal_status_message='Folder added.')
+                                        portal_status_message=_(u'Folder added.'))
 
     manage_addFolder = manage_addPloneFolder
     manage_renameObject = PortalFolderBase.manage_renameObject
@@ -415,47 +434,3 @@ def addPloneFolder(self, id, title='', description='', REQUEST=None):
     self._setObject(id, sf)
     if REQUEST is not None:
         REQUEST['RESPONSE'].redirect(sf.absolute_url() + '/manage_main')
-
-#
-# Helper function that can figure out what 'view' action to return
-#
-
-def _getViewFor(obj, view='view', default=None):
-
-    ti = obj.getTypeInfo()
-    context = getActionContext(obj)
-    if ti is not None:
-        actions = ti.listActions()
-        for action in actions:
-            _action = action.getAction(context)
-            if _action.get('id', None) == default:
-                default=action
-            if _action.get('id', None) == view:
-                target=_action['url']
-                if target.startswith('/'):
-                    target = target[1:]
-                if _verifyActionPermissions(obj, action) and target!='':
-                    __traceback_info__ = (ti.getId(), target)
-                    computed_action = obj.restrictedTraverse(target)
-                    if computed_action is not None:
-                        return computed_action
-
-        if default is not None:
-            _action = default.getAction(context)
-            if _verifyActionPermissions(obj, default):
-                target=_action['url']
-                if target.startswith('/'):
-                    target = target[1:]
-                __traceback_info__ = (ti.getId(), target)
-                return obj.restrictedTraverse(target)
-
-        # "view" action is not present or not allowed.
-        # Find something that's allowed.
-        #for action in actions:
-        #    if _verifyActionPermissions(obj, action)  and action.get('action','')!='':
-        #        return obj.restrictedTraverse(action['action'])
-        raise Unauthorized, ('No accessible views available for %s' %
-                               '/'.join(obj.getPhysicalPath()))
-    else:
-        raise NotFound, ('Cannot find default view for "%s"' %
-                            '/'.join(obj.getPhysicalPath()))
