@@ -3,14 +3,11 @@ import sys
 from types import UnicodeType, StringType
 import urlparse
 
-from Products.CMFPlone.utils import safe_callable
-from Products.CMFPlone.utils import safe_hasattr
-from Products.CMFPlone.utils import base_hasattr
 from Products.CMFPlone.utils import log
 from Products.CMFPlone.utils import log_exc
-from Products.CMFPlone import transaction
+import transaction
+from Products.CMFPlone import utils
 
-from AccessControl import getSecurityManager
 from Acquisition import aq_base, aq_inner, aq_parent
 
 from ComputedAttribute import ComputedAttribute
@@ -25,11 +22,13 @@ from Products.CMFCore.interfaces.Discussions import Discussable
 from Products.CMFCore.WorkflowCore import WorkflowException
 from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
 from Products.CMFPlone.interfaces.Translatable import ITranslatable
-from Products.CMFPlone.interfaces.NonStructuralFolder import INonStructuralFolder
+from Products.CMFPlone.interfaces import INonStructuralFolder
 from Products.CMFPlone import ToolNames
 from Products.CMFPlone.utils import transaction_note
-from Products.CMFPlone.interfaces.BrowserDefault import IBrowserDefault
-from Products.CMFPlone.interfaces.BrowserDefault import IDynamicViewTypeInformation
+from Products.CMFPlone.utils import base_hasattr
+from Products.CMFPlone.utils import safe_hasattr
+from Products.CMFPlone.utils import postonly
+from Products.CMFPlone.interfaces import IBrowserDefault
 
 from OFS.SimpleItem import SimpleItem
 from OFS.ObjectManager import bad_id
@@ -39,18 +38,15 @@ from ZODB.POSException import ConflictError
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
 from DateTime import DateTime
 DateTime.SyntaxError
-from Products.CMFPlone.UnicodeNormalizer import normalizeUnicode
 from Products.CMFPlone.PloneFolder import ReplaceableWrapper
-from Products.CMFPlone.browser.navtree import buildFolderTree
-from Products.CMFPlone.browser.navtree import NavtreeQueryBuilder, SitemapQueryBuilder
-from Products.CMFPlone.browser.navtree import DefaultNavtreeStrategy, SitemapNavtreeStrategy
-    
+
+from Products.statusmessages.interfaces import IStatusMessage
 
 AllowSendto = 'Allow sendto'
 permissions.setDefaultRoles(AllowSendto,
                                    ('Anonymous', 'Manager',))
 
-_marker = ()
+_marker = utils._marker
 _icons = {}
 
 CEILING_DATE = DefaultDublinCoreImpl._DefaultDublinCoreImpl__CEILING_DATE
@@ -59,11 +55,6 @@ FLOOR_DATE = DefaultDublinCoreImpl._DefaultDublinCoreImpl__FLOOR_DATE
 from Products.SecureMailHost.SecureMailHost import EMAIL_RE
 from Products.SecureMailHost.SecureMailHost import EMAIL_CUTOFF_RE
 BAD_CHARS = re.compile(r'[^a-zA-Z0-9-_~,.$\(\)# ]').findall
-# Define and compile static regexes
-FILENAME_REGEX = re.compile(r"^(.+)\.(\w{,4})$")
-NON_WORD_REGEX = re.compile(r"[\W\-]+")
-DANGEROUS_CHARS_REGEX = re.compile(r"[?&/:\\#]+")
-EXTRA_DASHES_REGEX = re.compile(r"(^\-+)|(\-+$)")
 
 
 # XXX Remove this when we don't depend on python2.1 any longer,
@@ -93,6 +84,7 @@ METADATA_DCNAME = {
     'Rights'           : 'DC.rights',
     }
 
+
 class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     """Various utility methods."""
 
@@ -118,19 +110,13 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     security.declarePublic('getSiteEncoding')
     def getSiteEncoding(self):
         """ Get the default_charset or fallback to utf8.
-        
+
         >>> ptool = self.portal.plone_utils
-        
+
         >>> ptool.getSiteEncoding()
         'utf-8'
         """
-        pprop = getToolByName(self, 'portal_properties')
-        default = 'utf-8'
-        try:
-            charset = pprop.site_properties.getProperty('default_charset', default)
-        except AttributeError:
-            charset = default
-        return charset
+        return utils.getSiteEncoding(self)
 
     security.declarePublic('portal_utf8')
     def portal_utf8(self, str, errors='strict'):
@@ -143,12 +129,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         >>> ptool.portal_utf8(sitetext) == text.encode('utf-8')
         True
         """
-        charset = self.getSiteEncoding()
-        if charset.lower() in ('utf-8', 'utf8'):
-            unicode(str, 'utf-8', errors)
-            return str
-        else:
-            return unicode(str, charset, errors).encode('utf-8', errors)
+        return utils.portal_utf8(self, str, errors)
 
     security.declarePublic('utf8_portal')
     def utf8_portal(self, str, errors='strict'):
@@ -161,13 +142,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         >>> ptool.utf8_portal(utf8text) == text.encode(ptool.getSiteEncoding())
         True
         """
-        charset = self.getSiteEncoding()
-        if charset.lower() in ('utf-8', 'utf8'):
-            # Test
-            unicode(str, 'utf-8', errors)
-            return str
-        else:
-            return unicode(str, 'utf-8', errors).encode(charset, errors)
+        return utils.utf8_portal(self, str, errors)
 
     security.declarePrivate('getMailHost')
     def getMailHost(self):
@@ -355,7 +330,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     def availableMIMETypes(self):
         """Returns a map of mimetypes.
 
-        Requires mimetype registry from Archetypes 1.3.
+        Requires mimetype registry from Archetypes >= 1.3.
         """
         mtr = getToolByName(self, 'mimetypes_registry')
         return mtr.list_mimetypes()
@@ -456,23 +431,17 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     def setCurrentSkin(self, skin_name):
         """Sets the current skin."""
         portal = getToolByName(self, 'portal_url').getPortalObject()
-        portal._v_skindata = (self.REQUEST, self.getSkinByName(skin_name), {})
+        portal.changeSkin(skin_name)
 
     security.declareProtected(ManagePortal,
                               'changeOwnershipOf')
-    def changeOwnershipOf(self, object, owner, recursive=0):
+    def changeOwnershipOf(self, object, userid, recursive=0, REQUEST=None):
         """Changes the ownership of an object."""
         membership = getToolByName(self, 'portal_membership')
-        if membership.getMemberById(owner) is None:
-            raise KeyError, 'Only users in this site can be made owners.'
         acl_users = getattr(self, 'acl_users')
-        user = acl_users.getUserById(owner)
-        if user is not None:
-            user = user.__of__(acl_users)
-        else:
-            user = getSecurityManager().getUser()
-
-        catalog_tool = getToolByName(self, 'portal_catalog')
+        user = acl_users.getUserById(userid)
+        if user is None:
+            raise KeyError, 'Only retrievable users in this site can be made owners.'
         object.changeOwnership(user, recursive)
 
         def fixOwnerRole(object, user_id):
@@ -491,16 +460,20 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
             object.manage_setLocalRoles(user_id, roles)
 
         fixOwnerRole(object, user.getId())
-        catalog_tool.reindexObject(object)
+        if base_hasattr(object, 'reindexObject'):
+            object.reindexObject()
 
         if recursive:
+            catalog_tool = getToolByName(self, 'portal_catalog')
             purl = getToolByName(self, 'portal_url')
             _path = purl.getRelativeContentURL(object)
             subobjects = [b.getObject() for b in \
                          catalog_tool(path={'query':_path,'level':1})]
             for obj in subobjects:
                 fixOwnerRole(obj, user.getId())
-                catalog_tool.reindexObject(obj)
+                if base_hasattr(obj, 'reindexObject'):
+                    obj.reindexObject()
+    changeOwnershipOf = postonly(changeOwnershipOf)
 
     security.declarePublic('urlparse')
     def urlparse(self, url):
@@ -546,175 +519,64 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     # Provide a way of dumping an exception to the log even if we
     # catch it and otherwise ignore it
     def logException(self):
-        """Dumps most recent exception to the log."""
+        """Dumps most recent exception to the log.
+        """
         log_exc()
 
     security.declarePublic('createSitemap')
-    def createSitemap(self, context):
-        """Returns a sitemap navtree structure."""
-        return self.createNavTree(context, sitemap=1)
+    def createSitemap(self, context, request=None):
+        """Returns a sitemap navtree structure.
+        """
+        if request is None:
+            request = self.REQUEST
+        return utils.createSiteMap(context, request)
 
-    # XXX: REMOVE
     def _addToNavTreeResult(self, result, data):
-        """Adds a piece of content to the result tree."""
-        path = data['path']
-        parentpath = '/'.join(path.split('/')[:-1])
-        # Tell parent about self
-        if result.has_key(parentpath):
-            result[parentpath]['children'].append(data)
-        else:
-            result[parentpath] = {'children':[data]}
-        # If we have processed a child already, make sure we register it
-        # as a child
-        if result.has_key(path):
-            data['children'] = result[path]['children']
-        result[path] = data
+        """Adds a piece of content to the result tree.
+        """
+        return utils.addToNavTreeResult(result, data)
 
     security.declareProtected(AccessContentsInformation, 'typesToList')
     def typesToList(self):
-        ntp = getToolByName(self, 'portal_properties').navtree_properties
-        ttool = getToolByName(self, 'portal_types')
-        bl = ntp.getProperty('metaTypesNotToList', ())
-        bl_dict = {}
-        for t in bl:
-            bl_dict[t] = 1
-        all_types = ttool.listContentTypes()
-        wl = [t for t in all_types if not bl_dict.has_key(t)]
-        return wl
+        return utils.typesToList(self)
 
-    # XXX: This method has been refactored to use buildFolderTree, but 
-    # uses a node decorator factory and sitemap logic to retain API 
-    # compatability with 2.1.0. Sitemap and navtree creation should possibly
-    # be separated better, and the node decorator should be dropped in favour
-    # of having the portlet code use node['item'] directly.
     security.declarePublic('createNavTree')
-    def createNavTree(self, context, sitemap=None):
-        """Returns a structure that can be used by navigation_tree_slot."""
-        
-        if context == self:
-            sitemap = True
-        
-        if sitemap: 
-            queryBuilder = SitemapQueryBuilder(context)
-            strategy = SitemapNavtreeStrategy(context)
-        else:
-            queryBuilder = NavtreeQueryBuilder(context)
-            strategy = DefaultNavtreeStrategy(context)
-        
-        return self.buildFolderTree(context, query=queryBuilder(), strategy=strategy)
-
-
-    security.declarePublic('buildFolderTree')
-    def buildFolderTree(self, context, query, strategy):
-        """Return a data structure representing a folder tree structure, using
-        a specific navtree strategy."""
-        return buildFolderTree(context, obj=context, query=query, strategy=strategy)
-
+    def createNavTree(self, context, sitemap=None, request=None):
+        """Returns a structure that can be used by navigation_tree_slot.
+        """
+        if request is None:
+            request = self.REQUEST
+        return utils.createNavTree(context, request)
 
     security.declarePublic('createTopLevelTabs')
-    def createTopLevelTabs(self, actions=None, category='portal_tabs'):
-        """Returns a structure for the top level tabs."""
-        ct = getToolByName(self, 'portal_catalog')
-        ntp = getToolByName(self, 'portal_properties').navtree_properties
-        stp = getToolByName(self, 'portal_properties').site_properties
-        view_action_types = stp.getProperty('typesUseViewActionInListings', ())
+    def createTopLevelTabs(self, actions=None, context=None, request=None,
+                           category='portal_tabs'):
+        """Returns a structure for the top level tabs.
+        """
 
-        # Build result dict
-        result = []
-        # first the actions
-        if actions is not None:
-            trans = getToolByName(self, 'translation_service', None)
-            if trans is not None:
-                utranslate = trans.utranslate
-                for action_info in actions.get(category, []):
-                    data = action_info.copy()
-                    data['name'] = utranslate('plone',
-                                              data['name'],
-                                              context=self,
-                                              default=data['name'])
-                    result.append(data)
+        if context is None:
+            context = self
 
-        # check whether we only want actions
-        if stp.getProperty('disable_folder_sections', True):
-            return result
+        if request is None and hasattr(context, 'REQUEST'):
+            request = context.REQUEST
+        
+        # XXX This method needs to eventually go away
 
-        custom_query = getattr(self, 'getCustomNavQuery', None)
-        if custom_query is not None and safe_callable(custom_query):
-            query = custom_query()
-        else:
-            query = {}
+        utils.log_deprecated("plone_utils.createTopLevelTabs is deprecated and "
+                             "will be removed in plone 3.5, please use the "
+                             "topLevelTabs method of the INavigationTabs view "
+                             "instead.")
 
-        portal_path = getToolByName(self, 'portal_url').getPortalPath()
-        query['path'] = {'query':portal_path, 'navtree':1}
-
-        query['portal_type'] = self.typesToList()
-
-        if ntp.getProperty('sortAttribute', False):
-            query['sort_on'] = ntp.sortAttribute
-
-        if (ntp.getProperty('sortAttribute', False) and
-            ntp.getProperty('sortOrder', False)):
-            query['sort_order'] = ntp.sortOrder
-
-        if ntp.getProperty('enable_wf_state_filtering', False):
-            query['review_state'] = ntp.wf_states_to_show
-
-        query['is_default_page'] = False
-        query['is_folderish'] = True
-
-        # Get ids not to list and make a dict to make the search fast
-        ids_not_to_list = ntp.getProperty('idsNotToList', ())
-        excluded_ids = {}
-        for exc_id in ids_not_to_list:
-            excluded_ids[exc_id]=1
-
-        rawresult = ct(**query)
-
-        # now add the content to results
-        for item in rawresult:
-            no_display = (
-                excluded_ids.has_key(item.getId) or
-                not not getattr(item, 'exclude_from_nav', True))
-            if not no_display:
-                item_url = (item.portal_type in view_action_types and
-                         item.getURL() + '/view') or item.getURL()
-                data = {'name': self.pretty_title_or_id(item),
-                        'id':item.getId, 'url': item_url, 'description':item.Description}
-                result.append(data)
-        return result
+        return utils.createTopLevelTabs(context, request, actions=actions,
+                                        category=category)
 
     security.declarePublic('createBreadCrumbs')
-    def createBreadCrumbs(self, context):
-        """Returns a structure for the portal breadcumbs."""
-        ct = getToolByName(self, 'portal_catalog')
-        stp = getToolByName(self, 'portal_properties').site_properties
-        view_action_types = stp.getProperty('typesUseViewActionInListings', ())
-        query = {}
-
-        # Check to see if the current page is a folder default view, if so
-        # get breadcrumbs from the parent folder
-        if self.isDefaultPage(context):
-            currentPath = '/'.join(context.aq_inner.aq_parent.getPhysicalPath())
-        else:
-            currentPath = '/'.join(context.getPhysicalPath())
-        query['path'] = {'query':currentPath, 'navtree':1, 'depth': 0}
-
-        rawresult = ct(**query)
-
-        # Sort items on path length
-        dec_result = [(len(r.getPath()),r) for r in rawresult]
-        dec_result.sort(lambda x, y: cmp(x[0], y[0]))
-
-        # Build result dict
-        result = []
-        for r_tuple in dec_result:
-            item = r_tuple[1]
-            item_url = (item.portal_type in view_action_types and
-                         item.getURL() + '/view') or item.getURL()
-            data = {'Title': self.pretty_title_or_id(item),
-                    'absolute_url': item_url}
-            result.append(data)
-        return result
+    def createBreadCrumbs(self, context, request=None):
+        """Returns a structure for the portal breadcumbs.
+        """
+        if request is None:
+            request = self.REQUEST
+        return utils.createBreadCrumbs(context, request)
 
     security.declarePublic('good_id')
     def good_id(self, id):
@@ -732,12 +594,14 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     security.declarePublic('getInheritedLocalRoles')
     def getInheritedLocalRoles(self, here):
         """Returns a tuple with the acquired local roles."""
-        portal = here.portal_url.getPortalObject()
+        portal = getToolByName(here, 'portal_url').getPortalObject()
         result = []
         cont = 1
         if portal != here:
             parent = here.aq_parent
             while cont:
+                if not getattr(parent, 'acl_users', False):
+                    break
                 userroles = parent.acl_users._getLocalRolesForDisplay(parent)
                 for user, roles, role_type, name in userroles:
                     # Find user in result
@@ -782,25 +646,23 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     #
 
     security.declarePublic('isDefaultPage')
-    def isDefaultPage(self, obj):
+    def isDefaultPage(self, obj, request=None):
         """Finds out if the given obj is the default page in its parent folder.
 
         Only considers explicitly contained objects, either set as index_html,
         with the default_page property, or using IBrowserDefault.
         """
-
-        parent = aq_parent(aq_inner(obj))
-        if parent is None:
-            return False
-
-        parentDefaultPage = self.getDefaultPage(parent)
-        if parentDefaultPage is None or '/' in parentDefaultPage:
-            return False
-        else:
-            return (parentDefaultPage == obj.getId())
+        #XXX: Does this deserve deprecation?
+        # utils.log_deprecated("plone_utils.isDefaultPage is deprecated and "
+        #                      "will be removed in plone 3.5, please use the "
+        #                      "isDefaultPage method of the IDefaultPage view "
+        #                      "on the container.")
+        if request is None:
+            request = self.REQUEST
+        return utils.isDefaultPage(obj, request, context=self)
 
     security.declarePublic('getDefaultPage')
-    def getDefaultPage(self, obj):
+    def getDefaultPage(self, obj, request=None):
         """Given a folderish item, find out if it has a default-page using
         the following lookup rules:
 
@@ -817,67 +679,66 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         and if found, its id is returned. If no default page is set, None is
         returned. If a non-folderish item is passed in, return None always.
         """
+        #XXX: Does this deserve deprecation?
+        # utils.log_deprecated("plone_utils.getDefaultPage is deprecated and "
+        #                      "will be removed in plone 3.5, please use the "
+        #                      "getDefaultPage method of the IDefaultPage view "
+        #                      "on the container.")
+        if request is None:
+            request = self.REQUEST
+        return utils.getDefaultPage(obj, request, context=self)
 
-        def lookupTranslationId(obj, page):
-            implemented = ITranslatable.isImplementedBy(obj)
-            if not implemented or implemented and not obj.isTranslation():
-                pageobj = getattr(obj, page, None)
-                if pageobj is not None and ITranslatable.isImplementedBy(pageobj):
-                    translation = pageobj.getTranslation()
-                    if translation is not None and \
-                       ids.has_key(translation.getId()):
-                        page = translation.getId()
-            return page
+    security.declarePublic('addPortalMessage')
+    def addPortalMessage(self, message, type='info', request=None):
+        """\
+        Call this once or more to add messages to be displayed at the
+        top of the web page.
 
-        # Short circuit if we are not looking at a Folder
-        if not obj.isPrincipiaFolderish:
-            return None
+        Examples:
 
-        # The list of ids where we look for default
-        ids = {}
+        >>> ptool = self.portal.plone_utils
 
-        portal = getToolByName(self, 'portal_url').getPortalObject()
-        wftool = getToolByName(self, 'portal_workflow')
+        >>> ptool.addPortalMessage(u'A random warning message', 'warn')
 
-        # For BTreeFolders we just use has_key, otherwise build a dict
-        if base_hasattr(obj, 'has_key'):
-            ids = obj
-        else:
-            for id in obj.objectIds():
-                ids[id] = 1
+        If no type is given it defaults to 'info'
+        >>> ptool.addPortalMessage(u'A random info message')
 
-        # 1. test for contentish index_html
-        if ids.has_key('index_html'):
-            return lookupTranslationId(obj, 'index_html')
+        The arguments are:
+            message:   a string, with the text message you want to show,
+                       or a HTML fragment (see type='structure' below)
+            type:      optional, defaults to 'info'. The type determines how
+                       the message will be rendered, as it is used to select
+                       the CSS class for the message. Predefined types are:
+                       'info' - for informational messages
+                       'warn' - for warning messages
+                       'stop' - for messages about restricted access or errors.
 
-        # 2. Test for IBrowserDefault
-        if IBrowserDefault.isImplementedBy(obj):
-            fti = obj.getTypeInfo()
-            if fti is not None:
-                # Also check that the fti is really IDynamicViewTypeInformation
-                if IDynamicViewTypeInformation.isImplementedBy(fti):
-                    page = fti.getDefaultPage(obj, check_exists=True)
-                    if page is not None:
-                        return lookupTranslationId(obj, page)
+        Portal messages are by default rendered by the global_statusmessage.pt
+        page template.
 
-        # 3. Test for default_page property in folder, then skins
-        pages = getattr(aq_base(obj), 'default_page', [])
-        if type(pages) in (StringType, UnicodeType):
-            pages = [pages]
-        for page in pages:
-            if page and ids.has_key(page):
-                return lookupTranslationId(obj, page)
-        for page in pages:
-            if portal.unrestrictedTraverse(page, None) is not None:
-                return lookupTranslationId(obj, page)
+        It is also possible to add messages from page templates, as
+        long as they are processed before the portal_message macro is
+        called by the main template. Example:
 
-        # 4. Test for default sitewide default_page setting
-        site_properties = portal.portal_properties.site_properties
-        for page in site_properties.getProperty('default_page', []):
-            if ids.has_key(page):
-                return lookupTranslationId(obj, page)
+          <tal:block tal:define="temp python:putils.addPortalMessage('A random info message')" />
+        """
+        if request is None:
+            request = self.REQUEST
+        IStatusMessage(request).addStatusMessage(message, type=type)
 
-        return None
+    security.declarePublic('showPortalMessages')
+    def showPortalMessages(self, request=None):
+        """\
+        Return portal status messages that will be displayed when the
+        response web page is rendered. Portal status messages are by default
+        rendered by the global_statusmessage.pt page template. They will be
+        removed after they have been shown.
+        
+        See addPortalMessages for examples.
+        """
+        if request is None:
+            request = self.REQUEST
+        return IStatusMessage(request).showStatusMessages()
 
     security.declarePublic('browserDefault')
     def browserDefault(self, obj):
@@ -959,8 +820,8 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
 
         # If we are not dealing with a folder, then leave this empty
         if obj.isPrincipiaFolderish:
-            # For BTreeFolders we just use the has_key, otherwise build a dict
-            if safe_hasattr(aq_base(obj), 'has_key'):
+            # For BTreeFolders we just use has_key, otherwise build a dict
+            if base_hasattr(obj, 'has_key'):
                 ids = obj
             else:
                 for id in obj.objectIds():
@@ -1007,8 +868,14 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
 
         # 5. If there is no default page, try IBrowserDefault.getLayout()
 
-        if IBrowserDefault.isImplementedBy(obj):
-            return obj, [obj.getLayout()]
+        browserDefault = IBrowserDefault(obj, None)
+        if browserDefault is not None:
+            layout = browserDefault.getLayout()
+            if layout is None:
+                raise AttributeError(
+                    "%s has no assigned layout, perhaps it needs an FTI"%obj)
+            else:
+                return obj, [layout]
 
         #
         # 6. If the object has a 'folderlisting' action, use this
@@ -1021,9 +888,10 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         # managed explicitly above)
 
         try:
-            act = obj.getTypeInfo().getActionById('folderlisting')
-            if act.startswith('/'):
-                act = act[1:]
+            # XXX: This isn't quite right since it assumes the action
+            # starts with ${object_url}.  Should we raise an error if
+            # it doesn't?
+            act = obj.getTypeInfo().getActionInfo('folder/folderlisting')['url'].split('/')[-1]
             return obj, [act]
         except ValueError:
             pass
@@ -1033,9 +901,10 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         #
 
         try:
-            act = obj.getTypeInfo().getActionById('view')
-            if act.startswith('/'):
-                act = act[1:]
+            # XXX: This isn't quite right since it assumes the action
+            # starts with ${object_url}.  Should we raise an error if
+            # it doesn't?
+            act = obj.getTypeInfo().getActionInfo('object/view')['url'].split('/')[-1]
             return obj, [act]
         except ValueError:
             pass
@@ -1066,17 +935,17 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         """
         if not obj.isPrincipiaFolderish:
             return False
-        elif INonStructuralFolder.isImplementedBy(obj):
+        elif INonStructuralFolder.providedBy(obj):
             return False
         else:
             return True
 
     security.declarePublic('acquireLocalRoles')
-    def acquireLocalRoles(self, obj, status = 1):
+    def acquireLocalRoles(self, obj, status = 1, REQUEST=None):
         """If status is 1, allow acquisition of local roles (regular behaviour).
 
-        If it's 0, prohibit it (it will allow some kind of local role blacklisting).
-        GRUF IS REQUIRED FOR THIS TO WORK.
+        If it's 0, prohibit it (it will allow some kind of local role
+        blacklisting).
         """
         mt = getToolByName(self, 'portal_membership')
         if not mt.checkPermission(ModifyPortalContent, obj):
@@ -1087,6 +956,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         gruf._acquireLocalRoles(obj, status)
         # Reindex the whole stuff.
         obj.reindexObjectSecurity()
+    acquireLocalRoles = postonly(acquireLocalRoles)
 
     security.declarePublic('isLocalRoleAcquired')
     def isLocalRoleAcquired(self, obj):
@@ -1103,7 +973,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         """ Returns the userid of the owner of an object.
 
         >>> ptool = self.portal.plone_utils
-        >>> from Products.CMFPlone.tests.PloneTestCase import default_user
+        >>> from Products.PloneTestCase.PloneTestCase import default_user
 
         >>> ptool.getOwnerName(self.folder) == default_user
         True
@@ -1134,6 +1004,9 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         >>> ptool.normalizeString("Some!_are allowed, others&?:are not")
         'some-_are-allowed-others-are-not'
 
+        >>> ptool.normalizeString("Some!_are allowed, others&?:are not")
+        'some-_are-allowed-others-are-not'
+
         all punctuation and spacing is removed and replaced with a '-':
 
         >>> ptool.normalizeString("a string with spaces")
@@ -1154,7 +1027,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         'a-string'
 
         >>> ptool.normalizeString(">here's another!")
-        'here-s-another'
+        'heres-another'
 
         >>> ptool.normalizeString("one with !@#$!@#$ stuff in the middle")
         'one-with-stuff-in-the-middle'
@@ -1184,39 +1057,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         >>> ptool.normalizeString(u"\uc774\ubbf8\uc9f1 Korean")
         'c774bbf8c9f1-korean'
         """
-        # Make sure we are dealing with a stringish type
-        if not isinstance(text, basestring):
-            # This most surely ends up in something the user does not expect
-            # to see. But at least it does not break.
-            text = repr(text)
-
-        # Make sure we are dealing with a unicode string
-        if not isinstance(text, unicode):
-            text = unicode(text, self.getSiteEncoding())
-
-        text = text.strip()
-        if not relaxed:
-            text = text.lower()
-        text = normalizeUnicode(text)
-
-        base = text
-        ext  = ""
-
-        m = FILENAME_REGEX.match(text)
-        if m is not None:
-            base = m.groups()[0]
-            ext  = m.groups()[1]
-
-        if not relaxed:
-            base = NON_WORD_REGEX.sub("-", base)
-        else:
-            base = DANGEROUS_CHARS_REGEX.sub("-", base)
-            
-        base = EXTRA_DASHES_REGEX.sub("", base)
-
-        if ext != "":
-            base = base + "." + ext
-        return base
+        return utils.normalizeString(text, context=self, relaxed=relaxed)
 
     security.declarePublic('listMetaTags')
     def listMetaTags(self, context):
@@ -1357,28 +1198,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     security.declarePublic('isIDAutoGenerated')
     def isIDAutoGenerated(self, id):
         """Determine if an id is autogenerated"""
-        autogenerated = False
-
-        # In 2.1 non-autogenerated is the common case, caught exceptions are
-        # expensive, so let's make a cheap check first
-        if id.count('.') != 2:
-            return autogenerated
-
-        try:
-            pt = getToolByName(self, 'portal_types')
-            obj_type, date_created, random_number = id.split('.')
-            type = ' '.join(obj_type.split('_'))
-            portaltypes = pt.objectIds()
-            # New autogenerated ids may have a lower case portal type
-            if (type in portaltypes or \
-               type in [pt.lower() for pt in portaltypes]) \
-               and DateTime(date_created) \
-               and float(random_number):
-                autogenerated = True
-        except (ValueError, AttributeError, IndexError, DateTime.DateTimeError):
-            pass
-
-        return autogenerated
+        return utils.isIDAutoGenerated(self, id)
 
     security.declarePublic('getEmptyTitle')
     def getEmptyTitle(self, translated=True):
@@ -1386,16 +1206,10 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
 
         >>> ptool = self.portal.plone_utils
 
-        >>> ptool.getEmptyTitle() == '[\xc2\xb7\xc2\xb7\xc2\xb7]'
+        >>> ptool.getEmptyTitle(translated=False) == u'[\xb7\xb7\xb7]'
         True
         """
-        empty = self.utf8_portal('\x5b\xc2\xb7\xc2\xb7\xc2\xb7\x5d', 'ignore')
-        if translated:
-            trans = getToolByName(self, 'translation_service', None)
-            if trans is not None:
-                empty = trans.utranslate(domain='plone', msgid='title_unset',
-                                         default=empty)
-        return empty
+        return utils.getEmptyTitle(self, translated)
 
     security.declarePublic('pretty_title_or_id')
     def pretty_title_or_id(self, obj, empty_value=_marker):
@@ -1403,21 +1217,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         of whether obj is a catalog brain or an object, but returning an
         empty title marker if the id is not set (i.e. it's auto-generated).
         """
-        title = None
-        if base_hasattr(obj, 'Title'):
-            title = getattr(obj, 'Title', None)
-        if safe_callable(title):
-            title = title()
-        if title:
-            return title
-        item_id = getattr(obj, 'getId', None)
-        if safe_callable(item_id):
-            item_id = item_id()
-        if item_id and not self.isIDAutoGenerated(item_id):
-            return item_id
-        if empty_value is _marker:
-            empty_value = self.getEmptyTitle()
-        return empty_value
+        return utils.pretty_title_or_id(self, obj, empty_value=empty_value)
 
     security.declarePublic('getMethodAliases')
     def getMethodAliases(self, typeInfo):
@@ -1425,7 +1225,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         FTI. If there are no method aliases (i.e. this FTI doesn't support it),
         return None"""
         getMethodAliases = getattr(typeInfo, 'getMethodAliases', None)
-        if getMethodAliases is not None and safe_callable(getMethodAliases):
+        if getMethodAliases is not None and utils.safe_callable(getMethodAliases):
             return getMethodAliases()
         else:
             return None
