@@ -1,21 +1,20 @@
-from ComputedAttribute import ComputedAttribute
 from Acquisition import aq_parent, aq_inner
 from Products.CMFCore.ActionProviderBase import ActionProviderBase
-from Products.CMFCore.ActionInformation import ActionInformation
-from Products.CMFCore.Expression import Expression
-from Products.CMFCore.CMFCorePermissions import ManagePortal
+from Products.CMFCore.permissions import ManagePortal
 from Products.CMFDefault.PropertiesTool import PropertiesTool as BaseTool
 from Products.CMFPlone import ToolNames
 
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from OFS.Folder import Folder
 from Globals import InitializeClass
+from zope.interface import implements
 
 from OFS.PropertyManager import PropertyManager
 from OFS.SimpleItem import SimpleItem
 from AccessControl import ClassSecurityInfo
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
-from Products.CMFPlone.interfaces.PropertiesTool import IPropertiesTool
+from Products.CMFPlone.interfaces import IPropertiesTool, ISimpleItemWithProperties
+from Products.CMFPlone.interfaces.PropertiesTool import IPropertiesTool as z2IPropertiesTool
 
 class PropertiesTool(PloneBaseTool, Folder, BaseTool):
 
@@ -23,15 +22,15 @@ class PropertiesTool(PloneBaseTool, Folder, BaseTool):
     toolicon = 'skins/plone_images/topic_icon.gif'
 
     meta_type = ToolNames.PropertiesTool
-    meta_types = all_meta_types =  ((
+    meta_types = ((
         {'name' : 'Plone Property Sheet',
          'action' : 'manage_addPropertySheetForm'
          },
         ))
 
-    __implements__ = ((IPropertiesTool,) +
-                      (PloneBaseTool.__implements__,
-                      ActionProviderBase.__implements__,
+    implements(IPropertiesTool)
+    __implements__ = ((z2IPropertiesTool,) +
+                      (ActionProviderBase.__implements__,
                       Folder.__implements__, ))
 
     manage_options = ((Folder.manage_options[0],) +
@@ -42,13 +41,14 @@ class PropertiesTool(PloneBaseTool, Folder, BaseTool):
 
     security = ClassSecurityInfo()
 
+    def all_meta_types(self, interfaces=None):
+        return self.meta_types
+
     def title(self):
         """ Return BaseTool title
         """
         return BaseTool.title(self)
 
-    title = ComputedAttribute(title, 1)
-
     def addPropertySheet(self, id, title='', propertysheet=None):
         """ Add a new PropertySheet
         """
@@ -87,9 +87,6 @@ class PropertiesTool(PloneBaseTool, Folder, BaseTool):
         """Change portal settings
         """
         aq_parent(aq_inner(self)).manage_changeProperties(props)
-        # keep this bit of hackery for backwards compatibility
-        if props.has_key('smtp_server'):
-            self.MailHost.smtp_host = props['smtp_server']
         if hasattr(self, 'propertysheets'):
             ps = self.propertysheets
             if hasattr(ps, 'props'):
@@ -107,6 +104,8 @@ class SimpleItemWithProperties (PropertyManager, SimpleItem):
     properties in a fixed schema.
     """
 
+    implements(ISimpleItemWithProperties)
+
     def __init__(self, id, title=''):
         self.id = id
         self.title = title
