@@ -1,34 +1,38 @@
 # This module contains a function to help build navigation-tree-like structures
-# from catalog queries. It also contains a standard implementation of the 
+# from catalog queries. It also contains a standard implementation of the
 # strategy/filtering method that uses Plone's navtree_properties to construct
 # navtrees.
 
+from zope.interface import implements
+
+from Acquisition import aq_base
+
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone.utils import safe_callable, safe_hasattr
+from Products.CMFPlone import utils
+from Products.CMFPlone.browser.interfaces import INavtreeStrategy
+from Products.CMFPlone.browser.interfaces import INavigationRoot
+from Products.CMFPlone.browser.interfaces import INavigationQueryBuilder
+
 from types import StringType
 
 class NavtreeStrategyBase:
-    """Base class for navtree strategies.
+    """Basic navigation tree strategy that does nothing.
     """
-    
+
+    implements(INavtreeStrategy)
+
     __allow_access_to_unprotected_subobjects__ = 1
     
     rootPath = None
-    """The path to the root of the navtree (None means use portal root)"""
-    
     showAllParents = False
-    """Whether or not to show all parents of the current context always"""
-    
+
     def nodeFilter(self, node):
-        """Determine whether to include the given node in the tree"""
         return True
-        
+
     def subtreeFilter(self, node):
-        """Determine whether to expand the given (folderish) node"""
         return True
-        
+
     def decoratorFactory(self, node):
-        """Inject any additional keys in the node that are needed"""
         return node
 
 def buildFolderTree(context, obj=None, query={}, strategy=NavtreeStrategyBase()):
@@ -37,52 +41,52 @@ def buildFolderTree(context, obj=None, query={}, strategy=NavtreeStrategyBase())
     by explicit folder order. If the 'query' parameter contains a 'path'
     key, this can be used to override this. To create a navtree rooted
     at the portal root, set query['path'] to:
-    
-        {'query' : '/'.join(obj.getPhysicalPath()),
+
+        {'query' : '/'.join(context.getPhysicalPath()),
          'navtree' : 1}
-    
+
     to start this 1 level below the portal root, set query['path'] to:
-    
+
         {'query' : '/'.join(obj.getPhysicalPath()),
          'navtree' : 1,
          'navtree_start' : 1}
-    
+
     to create a sitemap with depth limit 3, rooted in the portal:
-    
-        {'query' : '/'.join(portal.getPhysicalPath()),
+
+        {'query' : '/'.join(obj.getPhysicalPath()),
          'depth' : 3}
-    
+
     The parameters:
-    
+
     - 'context' is the acquisition context, from which tools will be acquired
     - 'obj' is the current object being displayed.
     - 'query' is a catalog query to apply to find nodes in the tree.
     - 'strategy' is an object that can affect how the generation works. It
         should be derived from NavtreeStrategyBase, if given, and contain:
-        
+
             rootPath -- a string property; the physical path to the root node.
-            
+
             If not given, it will default to any path set in the query, or the
-            portal root. Note that in a navtree query, the root path will 
+            portal root. Note that in a navtree query, the root path will
             default to the portal only, possibly adjusted for any navtree_start
             set. If rootPath points to something not returned by the query by
-            the query, a dummy node containing only an empty 'children' list 
+            the query, a dummy node containing only an empty 'children' list
             will be returned.
-        
+
             showAllParents -- a boolean property; if true and obj is given,
                 ensure that all parents of the object, including any that would
                 normally be filtered out are included in the tree.
-        
+
             nodeFilter(node) -- a method returning a boolean; if this returns
                 False, the given node will not be inserted in the tree
-            
+
             subtreeFilter(node) -- a method returning a boolean; if this returns
-                False, the given (folderish) node will not be expanded (its 
+                False, the given (folderish) node will not be expanded (its
                 children will be pruned off)
-            
+
             decoratorFactory(node) -- a method returning a dict; this can inject
                 additional keys in a node being inserted.
-                
+
     Returns tree where each node is represented by a dict:
 
         item            -   A catalog brain of this item
@@ -90,38 +94,39 @@ def buildFolderTree(context, obj=None, query={}, strategy=NavtreeStrategyBase())
         currentItem     -   True if this is the current item
         currentParent   -   True if this is a direct parent of the current item
         children        -   A list of children nodes of this node
-        
+
     Note: Any 'decoratorFactory' specified may modify this list, but
-    the 'children' property is guaranteed to be there. 
-    
-    Note: If the query does not return the root node itself, the root 
+    the 'children' property is guaranteed to be there.
+
+    Note: If the query does not return the root node itself, the root
     element of the tree may contain *only* the 'children' list.
-    
-    Note: Folder default-pages are not included in the returned result. 
+
+    Note: Folder default-pages are not included in the returned result.
     If the 'obj' passed in is a default-page, its parent folder will be
     used for the purposes of selecting the 'currentItem'.
     """
-    
+
     portal_url = getToolByName(context, 'portal_url')
-    plone_utils = getToolByName(context, 'plone_utils')
     portal_catalog = getToolByName(context, 'portal_catalog')
-    
+
     showAllParents = strategy.showAllParents
     rootPath = strategy.rootPath
+
+    request = getattr(context, 'REQUEST', {})
     
     # Find the object's path. Use parent folder if context is a default-page
-    
+
     objPath = None
     if obj is not None:
-        if plone_utils.isDefaultPage(obj):
+        if utils.isDefaultPage(obj, request):
             objPath = '/'.join(obj.getPhysicalPath()[:-1])
         else:
             objPath = '/'.join(obj.getPhysicalPath())
-    
+
     portalPath = portal_url.getPortalPath()
-    
-    # Calculate rootPath from the path query if not set. 
-    
+
+    # Calculate rootPath from the path query if not set.
+
     if 'path' not in query:
         if rootPath is None:
             rootPath = portalPath
@@ -146,32 +151,32 @@ def buildFolderTree(context, obj=None, query={}, strategy=NavtreeStrategyBase())
                     rootPath = portalPath
             else:
                 rootPath = pathQuery['query']
-    
+
     rootDepth = len(rootPath.split('/'))
-    
+
     # Default sorting and threatment of default-pages
-    
+
     if 'sort_on' not in query:
         query['sort_on'] = 'getObjPositionInParent'
-    
+
     if 'is_default_page' not in query:
         query['is_default_page'] = False
-    
-    results = portal_catalog.searchResults(query)
-    
+
+    results = portal_catalog.searchResults(**query)
+
     # We keep track of a dict of item path -> node, so that we can easily
-    # find parents and attach children. If a child appears before its 
-    # parent, we stub the parent node. 
-    
-    # This is necessary because whilst the sort_on parameter will ensure 
+    # find parents and attach children. If a child appears before its
+    # parent, we stub the parent node.
+
+    # This is necessary because whilst the sort_on parameter will ensure
     # that the objects in a folder are returned in the right order relative
-    # to each other, we don't know the relative order of objects from 
+    # to each other, we don't know the relative order of objects from
     # different folders. So, if /foo comes before /bar, and /foo/a comes
     # before /foo/b, we may get a list like (/bar/x, /foo/a, /foo/b, /foo,
     # /bar,).
-    
+
     itemPaths = {}
-    
+
     def insertElement(itemPaths, item, forceInsert=False):
         """Insert the given 'item' brain into the tree, which is kept in
         'itemPaths'. If 'forceInsert' is True, ignore node- and subtree-
@@ -180,54 +185,54 @@ def buildFolderTree(context, obj=None, query={}, strategy=NavtreeStrategyBase())
         """
         itemPath = item.getPath()
         itemInserted = (itemPaths.get(itemPath, {}).get('item', None) is not None)
-        
+
         # Short-circuit if we already added this item. Don't short-circuit
         # if we're forcing the insert, because we may have inserted but
         # later pruned off the node
         if not forceInsert and itemInserted:
             return
-        
+
         itemPhysicalPath = itemPath.split('/')
         parentPath = '/'.join(itemPhysicalPath[:-1])
         parentPruned = (itemPaths.get(parentPath, {}).get('_pruneSubtree', False))
-        
+
         # Short-circuit if we know we're pruning this item's parent
-        
+
         # XXX: We could do this recursively, in case of parent of the
         # parent was being pruned, but this may not be a great trade-off
-        
-        # There is scope for more efficiency improvement here: If we knew we 
-        # were going to prune the subtree, we would short-circuit here each time. 
+
+        # There is scope for more efficiency improvement here: If we knew we
+        # were going to prune the subtree, we would short-circuit here each time.
         # In order to know that, we'd have to make sure we inserted each parent
         # before its children, by sorting the catalog result set (probably
         # manually) to get a breadth-first search.
-        
+
         if not forceInsert and parentPruned:
             return
-        
+
         isCurrent = isCurrentParent = False
         if objPath is not None:
             if objPath == itemPath:
                 isCurrent = True
             elif objPath.startswith(itemPath):
                 isCurrentParent = True
-            
+
         relativeDepth = len(itemPhysicalPath) - rootDepth
-        
+
         newNode = {'item'          : item,
                    'depth'         : relativeDepth,
                    'currentItem'   : isCurrent,
                    'currentParent' : isCurrentParent,}
-            
+
         insert = True
         if not forceInsert and strategy is not None:
             insert = strategy.nodeFilter(newNode)
         if insert:
-            
+
             if strategy is not None:
                 newNode = strategy.decoratorFactory(newNode)
-            
-            # Tell parent about this item, unless an earlier subtree filter 
+
+            # Tell parent about this item, unless an earlier subtree filter
             # told us not to. If we're forcing the insert, ignore the
             # pruning, but avoid inserting the node twice
             if itemPaths.has_key(parentPath):
@@ -244,7 +249,7 @@ def buildFolderTree(context, obj=None, query={}, strategy=NavtreeStrategyBase())
                     itemParent['children'].append(newNode)
             else:
                 itemPaths[parentPath] = {'children': [newNode]}
-            
+
             # Ask the subtree filter (if any), if we should be expanding this node
             if strategy.showAllParents and isCurrentParent:
                 # If we will be expanding this later, we can't prune off children now
@@ -252,41 +257,39 @@ def buildFolderTree(context, obj=None, query={}, strategy=NavtreeStrategyBase())
             else:
                 expand = getattr(item, 'is_folderish', True)
             if expand and (not forceInsert and strategy is not None):
-                expand = strategy.subtreeFilter(newNode)  
-            
+                expand = strategy.subtreeFilter(newNode)
+
+            children = newNode.setdefault('children',[])
             if expand:
                 # If we had some orphaned children for this node, attach
                 # them
                 if itemPaths.has_key(itemPath):
-                    newNode['children'] = itemPaths[itemPath]['children']
-                else:
-                    newNode['children'] = []
+                    children.extend(itemPaths[itemPath]['children'])
             else:
-                newNode['children'] = []
                 newNode['_pruneSubtree'] = True
-            
+
             itemPaths[itemPath] = newNode
 
     # Add the results of running the query
     for r in results:
         insertElement(itemPaths, r)
-    
-    # If needed, inject additional nodes for the direct parents of the 
+
+    # If needed, inject additional nodes for the direct parents of the
     # context. Note that we use an unrestricted query: things we don't normally
     # have permission to see will be included in the tree.
     if strategy.showAllParents and objPath is not None:
         objSubPathElements = objPath[len(rootPath)+1:].split('/')
         parentPaths = []
-        
+
         haveNode = (itemPaths.get(rootPath, {}).get('item', None) is None)
         if not haveNode:
             parentPaths.append(rootPath)
-        
+
         parentPath = rootPath
         for i in range(len(objSubPathElements)):
             nodePath = rootPath + '/' + '/'.join(objSubPathElements[:i+1])
             node = itemPaths.get(nodePath, None)
-            
+
             # If we don't have this node, we'll have to get it, if we have it
             # but it wasn't connected, re-connect it
             if node is None or 'item' not in node:
@@ -301,35 +304,46 @@ def buildFolderTree(context, obj=None, query={}, strategy=NavtreeStrategyBase())
                             break
                     if not nodeAlreadyInserted:
                         nodeParent['children'].append(node)
-                    
+
             parentPath = nodePath
-            
+
         # If we were outright missing some nodes, find them again
         if len(parentPaths) > 0:
             query = {'path' : {'query' : parentPaths, 'depth' : 0}}
             results = portal_catalog.unrestrictedSearchResults(query)
-        
+
             for r in results:
                 insertElement(itemPaths, r, forceInsert=True)
-    
+
     # Return the tree starting at rootPath as the root node. If the
     # root path does not exist, we return a dummy parent node with no children.
     return itemPaths.get(rootPath, {'children' : []})
 
+
 def getNavigationRoot(context):
-    """Get the path to the root of the navigation tree. If an explicit root is 
-    set in navtree_properties, use this. If the property is not set or is set 
-    to '/', use the portal root. 
+    """Get the path to the root of the navigation tree. If context or one of
+    its parents until (but not including) the portal root implements
+    INavigationRoot, return this.
+
+    Otherwise, if an explicit root is set in navtree_properties, use this. If
+    the property is not set or is set to '/', use the portal root.
     """
-        
+
     portal_url = getToolByName(context, 'portal_url')
     portal_properties = getToolByName(context, 'portal_properties')
     navtree_properties = getattr(portal_properties, 'navtree_properties')
-    
+
+    portal = portal_url.getPortalObject()
+    obj = context
+    while not INavigationRoot.providedBy(obj) and aq_base(obj) is not aq_base(portal):
+        obj = utils.parent(obj)
+    if INavigationRoot.providedBy(obj) and aq_base(obj) is not aq_base(portal):
+        return '/'.join(obj.getPhysicalPath())
+
     rootPath = navtree_properties.getProperty('root', None)
     portalPath = portal_url.getPortalPath()
     contextPath = '/'.join(context.getPhysicalPath())
-    
+
     if rootPath:
         if rootPath == '/':
             return portalPath
@@ -339,7 +353,7 @@ def getNavigationRoot(context):
             else:
                 return portalPath
 
-    # This code is stolen from Sprout, but it's unclear exactly how it 
+    # This code is stolen from Sprout, but it's unclear exactly how it
     # should work and the test from Sprout isn't directly transferable
     # to testNavTree.py, since it's testing something slightly different.
     # Hoping Sidnei or someone else with a real use case can do this.
@@ -361,7 +375,6 @@ def getNavigationRoot(context):
     if not rootPath:
         return portalPath
 
-
 # Strategy objects for the navtree creation code. You can subclass these
 # to expand the default navtree behaviour, and pass instances of your subclasses
 # to buildFolderTree().
@@ -369,32 +382,29 @@ def getNavigationRoot(context):
 class NavtreeQueryBuilder:
     """Build a navtree query based on the settings in navtree_properties
     """
-    
-    __allow_access_to_unprotected_subobjects__ = 1
-    
+    implements(INavigationQueryBuilder)
+
     def __init__(self, context):
         portal_properties = getToolByName(context, 'portal_properties')
         portal_url = getToolByName(context, 'portal_url')
-        plone_utils = getToolByName(context, 'plone_utils')
-        
         navtree_properties = getattr(portal_properties, 'navtree_properties')
-        
+
         # Acquire a custom nav query if available
         customQuery = getattr(context, 'getCustomNavQuery', None)
-        if customQuery is not None and safe_callable(customQuery):
+        if customQuery is not None and utils.safe_callable(customQuery):
             query = customQuery()
         else:
             query = {}
 
         # Construct the path query
-        
+
         rootPath = getNavigationRoot(context)
         currentPath = '/'.join(context.getPhysicalPath())
-        
+
         # If we are above the navigation root, a navtree query would return
         # nothing (since we explicitly start from the root always). Hence,
         # use a regular depth-1 query in this case.
-        
+
         if not currentPath.startswith(rootPath):
             query['path'] = {'query' : rootPath, 'depth' : 1}
         else:
@@ -408,7 +418,7 @@ class NavtreeQueryBuilder:
         # seem to work with EPI.
 
         # Only list the applicable types
-        query['portal_type'] = plone_utils.typesToList()
+        query['portal_type'] = utils.typesToList(context)
 
         # Apply the desired sort
         sortAttribute = navtree_properties.getProperty('sortAttribute', None)
@@ -421,16 +431,16 @@ class NavtreeQueryBuilder:
         # Filter on workflow states, if enabled
         if navtree_properties.getProperty('enable_wf_state_filtering', False):
             query['review_state'] = navtree_properties.getProperty('wf_states_to_show', ())
-        
+
         self.query = query
-        
+
     def __call__(self):
         return self.query
-    
+
 class SitemapQueryBuilder(NavtreeQueryBuilder):
     """Build a folder tree query suitable for a sitemap
     """
-    
+
     def __init__(self, context):
         NavtreeQueryBuilder.__init__(self, context)
         portal_url = getToolByName(context, 'portal_url')
@@ -439,13 +449,17 @@ class SitemapQueryBuilder(NavtreeQueryBuilder):
         sitemapDepth = navtree_properties.getProperty('sitemapDepth', 2)
         self.query['path'] = {'query' : portal_url.getPortalPath(),
                               'depth' : sitemapDepth}
-        
+
 class SitemapNavtreeStrategy(NavtreeStrategyBase):
-    """The navtree building strategy used by the sitemap, based on 
+    """The navtree building strategy used by the sitemap, based on
     navtree_properties
     """
-    
+    implements(INavtreeStrategy)
+    #adapts(*, ISiteMap)
+
     def __init__(self, context, view=None):
+        self.context = [context]
+        
         portal_url = getToolByName(context, 'portal_url')
         self.portal = portal_url.getPortalObject()
         portal_properties = getToolByName(context, 'portal_properties')
@@ -456,12 +470,11 @@ class SitemapNavtreeStrategy(NavtreeStrategyBase):
             self.excludedIds[id] = True
         self.parentTypesNQ = navtree_properties.getProperty('parentMetaTypesNotToQuery', ())
         self.viewActionTypes = site_properties.getProperty('typesUseViewActionInListings', ())
-        self.plone_utils = getToolByName(context, 'plone_utils')
-        
+
         self.showAllParents = navtree_properties.getProperty('showAllParents', True)
         self.rootPath = getNavigationRoot(context)
-        
-            
+
+
     def nodeFilter(self, node):
         item = node['item']
         if getattr(item, 'getId', None) in self.excludedIds:
@@ -470,29 +483,31 @@ class SitemapNavtreeStrategy(NavtreeStrategyBase):
             return False
         else:
             return True
-        
+
     def subtreeFilter(self, node):
         portalType = getattr(node['item'], 'portal_type', None)
         if portalType is not None and portalType in self.parentTypesNQ:
             return False
         else:
             return True
-    
+
     def decoratorFactory(self, node):
+        context = utils.context(self)
+        
         newNode = node.copy()
         item = node['item']
-        
+
         portalType = getattr(item, 'portal_type', None)
         itemUrl = item.getURL()
         if portalType is not None and portalType in self.viewActionTypes:
             itemUrl += '/view'
-        
+
         isFolderish = getattr(item, 'is_folderish', None)
         showChildren = False
         if isFolderish and (portalType is None or portalType not in self.parentTypesNQ):
             showChildren = True
-        
-        newNode['Title'] = self.plone_utils.pretty_title_or_id(item)
+
+        newNode['Title'] = utils.pretty_title_or_id(context, item)
         newNode['absolute_url'] = itemUrl
         newNode['getURL'] = itemUrl
         newNode['path'] = item.getPath()
@@ -505,42 +520,26 @@ class SitemapNavtreeStrategy(NavtreeStrategyBase):
         newNode['getRemoteUrl'] = getattr(item, 'getRemoteUrl', None)
         newNode['show_children'] = showChildren
         newNode['no_display'] = False # We sort this out with the nodeFilter
-        
+
         return newNode
 
 class DefaultNavtreeStrategy(SitemapNavtreeStrategy):
     """The navtree strategy used for the default navigation portlet
     """
-    
+    implements(INavtreeStrategy)
+    #adapts(*, INavigationTree)
+
     def __init__(self, context, view=None):
         SitemapNavtreeStrategy.__init__(self, context, view)
         portal_properties = getToolByName(context, 'portal_properties')
         navtree_properties = getattr(portal_properties, 'navtree_properties')
         # XXX: We can't do this with a 'depth' query to EPI...
         self.bottomLevel = navtree_properties.getProperty('bottomLevel', 0)
-        topLevel = navtree_properties.getProperty('topLevel', None)
-        
-        # Find root path, and adjust for top level if necessary
-        
-        currentFolderOnlyInNavtree = navtree_properties.getProperty('currentFolderOnlyInNavtree', False)
-        if currentFolderOnlyInNavtree:
-            if context.is_folderish():
-                rootPath = '/'.join(context.getPhysicalPath())
-            else:
-                rootPath = '/'.join(context.aq_inner.aq_parent.getPhysicalPath())
+        if view is not None:
+            self.rootPath = view.navigationTreeRootPath()
         else:
-            rootPath = getNavigationRoot(context)
-            if topLevel is not None and topLevel > 0:
-                contextPath = '/'.join(context.getPhysicalPath())
-                if not contextPath.startswith(rootPath):
-                    rootPath = None
-                contextSubPathElements = contextPath[len(rootPath)+1:].split('/')
-                if len(contextSubPathElements) < topLevel:
-                    rootPath = None
-                if rootPath is not None:
-                    rootPath = rootPath + '/' + '/'.join(contextSubPathElements[:topLevel])
-        self.rootPath = rootPath
-        
+            self.rootPath = getNavigationRoot(context)
+
     def subtreeFilter(self, node):
         sitemapDecision = SitemapNavtreeStrategy.subtreeFilter(self, node)
         if sitemapDecision == False:
@@ -549,4 +548,4 @@ class DefaultNavtreeStrategy(SitemapNavtreeStrategy):
         if depth > 0 and self.bottomLevel > 0 and depth >= self.bottomLevel:
             return False
         else:
-            return True
\ No newline at end of file
+            return True
