@@ -1,5 +1,3 @@
-import os
-
 from Acquisition import aq_base
 from AccessControl.Permissions import copy_or_move
 from zExceptions import BadRequest
@@ -12,7 +10,7 @@ from Products.CMFPlone.utils import _createObjectByType, base_hasattr
 from Products.CMFPlone.migrations.migration_util import installOrReinstallProduct, \
      safeGetMemberDataTool
 from Products.CMFCore.Expression import Expression
-from Products.CMFPlone import transaction
+import transaction
 
 fti_meta_type = DynamicViewTypeInformation.meta_type
 
@@ -38,13 +36,10 @@ def two05_alpha1(portal):
 
     if not migrated and reindex:
         refreshSkinData(portal, out)
+        # XXX We shouldn't do a full recatalog here, but only reindex those
+        # indexes which we actually need for the ATCT migration. We do a full
+        # recatalog at the end of the migrations anyways...
         reindexCatalog(portal, out)
-    
-    # FIXME: Must get rid of this!
-    # ATCT is not installed when SUPPRESS_ATCT_INSTALLATION is set to YES
-    # It's required for some unit tests in ATCT [tiran]
-    suppress_atct = bool(os.environ.get('SUPPRESS_ATCT_INSTALLATION', None)
-                         == 'YES')
 
     # Install SecureMailHost
     replaceMailHost(portal, out)
@@ -61,15 +56,13 @@ def two05_alpha1(portal):
     installArchetypes(portal, out)
 
     # Install ATContentTypes
-    if not suppress_atct:
-        installATContentTypes(portal, out)
+    installATContentTypes(portal, out)
 
-        # Switch over to ATCT
-        #migrateToATCT(portal, out)
-        migrateToATCT10(portal, out)
+    # Switch over to ATCT
+    migrateToATCT10(portal, out)
 
     transaction.savepoint(optimistic=True)
-    
+
     return out
 
 def tweakPropertiesAndCSS(portal, out):
@@ -210,7 +203,8 @@ def alpha1_alpha2(portal):
     # Rebuild catalog
     if reindex:
         refreshSkinData(portal, out)
-        reindexCatalog(portal, out)
+        migtool = getToolByName(portal, 'portal_migration')
+        migtool._needRecatalog = True
     
     return out
 
@@ -786,11 +780,11 @@ def addEditContentActions(portal, out):
         actionsTool._actions = new_actions
         # then we add new actions
         for newaction in ACTIONS:
-            for action in actionsTool.listActions():
-                if action.getId() == newaction['id'] \
-                        and action.getCategory() == newaction.get('category', CATEGORY):
-                    break # We already have the action
-            else:
+            category = newaction.get('category', CATEGORY)
+            try:
+                actionsTool.unrestrictedTraverse('/'.join([category, newaction['id']]))
+            except (KeyError, AttributeError):
+                # This is a new action
                 actionsTool.addAction(newaction['id'],
                     name=newaction['name'],
                     action=newaction['action'],
@@ -1126,19 +1120,10 @@ def fixFolderButtonsActions(portal, out):
     actionsTool = getToolByName(portal, 'portal_actions', None)
     if actionsTool is not None:
         for newaction in ACTIONS:
-            current_actions = actionsTool._cloneActions()
-            exists = False
-            for action in current_actions:
-                if action.getId() == newaction['id'] and action.category == newaction['category']:
-                    exists = True
-                    if action.permissions != (
-                            copy_or_move,):
-                        action.permissions = (newaction['permission'],)
-                        action.condition = Expression(text=newaction['condition']) or ''
-                        out.append('Modified existing %s action'%newaction['id'])
-            if exists:
-                actionsTool._actions = current_actions
-            else:
+            category = newaction.get('category', CATEGORY)
+            action = actionsTool.getActionObject('/'.join([category, newaction['id']]))
+            if action is None:
+                # Action doesn't exist: add it
                 actionsTool.addAction(newaction['id'],
                     name=newaction['name'],
                     action=newaction['action'],
@@ -1147,6 +1132,11 @@ def fixFolderButtonsActions(portal, out):
                     category=newaction['category'],
                     visible=1)
                 out.append("Added missing %s action"%newaction['id'])
+            else:
+                if action.permissions != (copy_or_move,):
+                    action.permissions = (newaction['permission'],)
+                    action.condition = Expression(text=newaction['condition']) or ''
+                    out.append('Modified existing %s action'%newaction['id'])
 
 
 def addTypesUseViewActionInListingsProperty(portal, out):
@@ -1261,16 +1251,19 @@ def convertPloneFTIToCMFDynamicViewFTI(portal, out):
                                     if t[1].get('id','')=='Plone Root']
                 if name:
                     name = name[0]
-                    migrateFTI(portal, 'Plone Site', name, fti_meta_type)
-                    out.append("Converted Plone Site to CMFDynamicViewFTI")
+                else:
+                    name = None
 
-                    # limi says don't bother transferring old views
-                    # Transfer old default page
-                    old_default = getattr(portal, '_selected_default_page', ())
-                    if old_default is not ():
-                        del portal._selected_default_page
-                        portal.setDefaultPage(old_default)
-                        out.append("Transferred portal default page")
+                migrateFTI(portal, 'Plone Site', name, fti_meta_type)
+                out.append("Converted Plone Site to CMFDynamicViewFTI")
+
+                # limi says don't bother transferring old views
+                # Transfer old default page
+                old_default = getattr(portal, '_selected_default_page', ())
+                if old_default is not ():
+                    del portal._selected_default_page
+                    portal.setDefaultPage(old_default)
+                    out.append("Transferred portal default page")
             # add sensible default methods
             new_fti = portal.getTypeInfo()
             if 'folder_listing' not in portal.getAvailableLayouts():
