@@ -2,37 +2,37 @@
 #you should be able to define Product dependencies and error messages
 #in the config file
 
-import zLOG
-import os
+import logging
 import sys
 
-MINIMUM_PYTHON_VER = (2, 3, 4)
-PREFERRED_PYTHON_VER = "2.3.5 or newer"
+MINIMUM_PYTHON_VER = (2, 3, 5)
+PREFERRED_PYTHON_VER = "2.4.4 or newer"
 
-MINIMUM_ZOPE_VER = (2, 7, 5)
-PREFERRED_ZOPE_VER = "2.7.8 or newer"
+MINIMUM_ZOPE_VER = (2, 8, 7)
+PREFERRED_ZOPE_VER = "2.9.7 or newer"
 
-MINIMUM_CMF_VER = (1, 5, 5)
+MINIMUM_CMF_VER = (1, 6, 0)
 
 messages = []
 
-def log(message, summary='', severity=zLOG.ERROR, optional=0):
+def log(message, summary='', severity=logging.ERROR, optional=0):
     if optional:
         subsys = 'Plone Option'
     else:
         subsys = 'Plone Dependency'
     messages.append({'message' : message, 'summary' : summary,
                      'severity' : severity, 'optional' : optional
-		    })
-    zLOG.LOG(subsys, severity, summary, message + "\n")
+            })
+    logger = logging.getLogger(subsys)
+    logger.log(severity, '%s \n%s', summary, message)
 
 # test python version
 PYTHON_VER = sys.version_info[:3]
 if PYTHON_VER < MINIMUM_PYTHON_VER:
     log(("Python version %s found but Plone needs at least "
          "Python %s. Please download and install Python %s "
-	 "from http://python.org/" % (PYTHON_VER, 
-	 MINIMUM_PYTHON_VER, PREFERRED_PYTHON_VER) ))
+     "from http://python.org/" % (PYTHON_VER,
+     MINIMUM_PYTHON_VER, PREFERRED_PYTHON_VER) ))
 
 # test zope version
 ZOPE_VER = "unknown"
@@ -52,8 +52,8 @@ if ZOPE_VER in ('unknown', (-1, -1, -1)): # -1, -1, 1 is developer release
 elif ZOPE_VER < MINIMUM_ZOPE_VER:
     log(("Zope version %s found but Plone needs at least "
          "Zope %s Please download and install Zope %s "
-	 "from http://zope.org/" % 
-	 (ZOPE_VER, MINIMUM_ZOPE_VER, PREFERRED_ZOPE_VER) ))
+     "from http://zope.org/" %
+     (ZOPE_VER, MINIMUM_ZOPE_VER, PREFERRED_ZOPE_VER) ))
 
 # make sure CMF is installed
 cmfcore = 0
@@ -69,7 +69,7 @@ if cmfcore:
     from Products.CMFCore import cmfcore_globals
     from App.Common import package_home
     from os.path import join
-    
+
     x = []
     CMF_VERSION = 'Unknown'
     try:
@@ -105,10 +105,17 @@ try:
     # TODO: we might want to check if the user has jpeg and zlib support, too
     import PIL.Image
 except ImportError:
-    log(("PIL not found. Plone needs PIL 1.1.5 or newer to scale images. "
+    log(("PIL not found. Plone needs PIL 1.1.5 or newer. "
          "Please download it from http://www.pythonware.com/products/pil/ or "
-         "http://effbot.org/downloads/#Imaging"), 
-         severity=zLOG.INFO, optional=1)
+         "http://effbot.org/downloads/#Imaging"))
+
+try:
+    from elementtree import ElementTree
+except ImportError:
+    log(("Elementtree not found. Plone needs Elementtree for XML "
+         "transformation. Please download it from "
+         "http://effbot.org/downloads/#elementtree"),
+         severity=logging.INFO)
 
 try:
     import Products.ExternalEditor
@@ -117,7 +124,7 @@ except ImportError:
          "the external edit functionality, please "
          "download it from "
          "http://plope.com/software/ExternalEditor"),
-        severity=zLOG.INFO, optional=1)
+        severity=logging.INFO, optional=1)
 
 try:
     import Products.kupu
@@ -125,7 +132,7 @@ except ImportError:
     log(("Kupu not found. If you want WYSIWYG capabilities "
         "in Plone, you can download it from "
         "http://kupu.oscom.org/"),
-        severity=zLOG.INFO, optional=1)
+        severity=logging.INFO, optional=1)
 
 try:
     import Products.PlacelessTranslationService
@@ -134,40 +141,7 @@ except ImportError:
          "runs without this, but if you want multilingual "
          "interface or access keys, you must download it from "
          "http://plone.org/products/pts/"),
-        severity=zLOG.INFO, optional=1)
-
-try:
-    import Products.Localizer
-except ImportError:
-    pass
-else:
-    log(("Localizer found. Plone 2 is using the PlacelessTranslationService "
-         "for translation. Please deinstall the Localizer after you have saved "
-         "your po catalogs."),
-        severity=zLOG.WARNING, optional=1)
-
-try:
-    import Products.TranslationService
-except ImportError:
-    pass
-else:
-    log(("TranslationService found. Plone 2 is using the PlacelessTranslationService "
-         "for translation. Please deinstall the TranslationService."),
-        severity=zLOG.WARNING, optional=1)
-
-try:
-    import Products.CMFPlone
-    plonePath = Products.CMFPlone.__path__[0]
-except ImportError, AttributeError:
-    i18nPath = None
-else:
-    i18nPath = os.path.join(plonePath, 'i18n')
-
-if (i18nPath and os.path.isfile(os.path.join(i18nPath, 'plone-en.po')) ):
-    log(("Plone i18n files found at CMFPlone/i18/. Plone's "
-         "i18n files have been moved to the PloneTranslation product. "
-         "Please remove the CMFPlone/i18n/ folder to avoid conflicts."),
-        severity=zLOG.INFO, optional=1)
+        severity=logging.INFO, optional=1)
 
 try:
     import Products.PloneTranslations
@@ -176,7 +150,7 @@ except ImportError:
          "runs without this, but if you want multilingual "
          "interface or access keys, you must download it from "
          "http://plone.org/products/plonetranslations"),
-        severity=zLOG.INFO, optional=1)
+        severity=logging.INFO, optional=1)
 
 try:
     import Products.CMFFormController
@@ -190,25 +164,6 @@ except ImportError:
     log(("GroupUserFolder not found. Please "
          "http://plone.org/products/groupuserfolder"))
 
-try:
-    import Products.CallProfiler
-    try:
-        import Products.CMFFormControllerPatch
-    except ImportError:
-        log(("CMFFormControllerPatch not found. This is "
-             "only required for using Call Profiler with Plone, "
-             "you can download it from "
-             "http://sf.net/projects/collective"),
-            severity=zLOG.INFO, optional=1)
-except ImportError:
-    pass
-
-try:
-    import Products.BTreeFolder2
-except ImportError:
-    log(("BTreeFolder2 not found. Please download it "
-         "from http://hathawaymix.org/Software/BTreeFolder2"))
-
 try:
     import Products.SecureMailHost
 except ImportError:
@@ -257,3 +212,10 @@ try:
 except ImportError:
     log(("CMFDynamicViewFTI not found. "
          "Please download it from http://plone.org/products/cmfdynamicviewfti"))
+
+try:
+    import Products.PlonePAS
+except ImportError:
+    log(("PlonePAS not found."
+         "Please download it from http://plone.org/products/plonepas"))
+
