@@ -8,6 +8,7 @@
 ##title=set syndication prefs
 ##
 
+from Products.CMFPlone import PloneMessageFactory as _
 REQUEST=context.REQUEST
 
 ps = context.portal_syndication
@@ -19,7 +20,7 @@ ps.editProperties( updatePeriod=updatePeriod,
                    max_items=max_items,
                    )
 
-msg = 'Syndication properties updated'
-RESPONSE.redirect('prefs_syndication_form?portal_status_message=' + msg)
+context.plone_utils.addPortalMessage(_(u'Syndication properties updated'))
 
+RESPONSE.redirect('prefs_syndication_form')
 return
