@@ -6,17 +6,17 @@
 ##bind script=script
 ##bind subpath=traverse_subpath
 ##parameters=
+
 from Products.CMFPlone.utils import base_hasattr
+from Products.CMFPlone import PloneMessageFactory as _
 
 RESPONSE = context.REQUEST.RESPONSE
 homeFolder=context.portal_membership.getHomeFolder()
 view_url = '%s/%s' % (context.absolute_url(),
-                      context.getTypeInfo().getActionById('view')
-                     )
-
+                      context.getTypeInfo().getActionById('view'))
 if not homeFolder:
-    msg = "Can't access home folder. Favorite is not added"
-    return RESPONSE.redirect('%s?portal_status_message=%s' % (view_url, msg))
+    context.plone_utils.addPortalMessage(_(u'Can\'t access home folder. Favorite is not added.'))
+    return RESPONSE.redirect(view_url)
 
 if not base_hasattr(homeFolder, 'Favorites'):
     homeFolder.invokeFactory('Folder', id='Favorites', title='Favorites')
@@ -30,9 +30,19 @@ if not base_hasattr(homeFolder, 'Favorites'):
 targetFolder = homeFolder.Favorites
 new_id='fav_' + str(int( context.ZopeTime()))
 myPath=context.portal_url.getRelativeUrl(context)
-targetFolder.invokeFactory('Favorite', id=new_id, title=context.TitleOrId(), remote_url=myPath)
+fav_id = targetFolder.invokeFactory('Favorite', id=new_id, title=context.TitleOrId(), remote_url=myPath)
+if fav_id:
+    favorite = getattr(targetFolder, fav_id, None)
+else:
+    favorite = getattr(targetFolder, new_id, None)
 
-msg = context.translate("${title} has been added to your Favorites.",
-                        {'title': context.title_or_id()})
+if favorite:
+    favorite.reindexObject()
+    msg = _(u'${title} has been added to your Favorites.',
+            mapping={u'title' : context.title_or_id()})
+    context.plone_utils.addPortalMessage(msg)
+else:
+    msg = _(u'There was a problem adding ${title} to your Favorites.',
+            mapping={u'title' : context.title_or_id()})
 
-return RESPONSE.redirect('%s?portal_status_message=%s' % (view_url, msg))
+return RESPONSE.redirect(view_url)
