@@ -7,6 +7,8 @@
 ##parameters=
 ##title=Return a dict with all names
 
+from Products.CMFPlone import PloneMessageFactory as _
+
 value = [
     ('aa', 'Afar'),
     ('ab', 'Abkhazian'),
@@ -109,7 +111,7 @@ value = [
     ('rw', 'Kiyarwanda'),
     ('sa', 'Sanskrit'),
     ('sd', 'Sindhi'),
-    ('se', 'Northern S&aacute;mi'),
+    ('se', 'Northern Sami'),
     ('sg', 'Sangho'),
     ('sh', 'Serbo-Croatian'),
     ('si', 'Singhalese'),
@@ -143,7 +145,7 @@ value = [
     ('ur', 'Urdu'),
     ('uz', 'Uzbek'),
     ('vi', 'Vietnamese'),
-    ('vo', 'Volap&uuml;k'),
+    ('vo', 'Volapuk'),
     ('wo', 'Wolof'),
     ('xh', 'Xhosa'),
     ('yi', 'Yiddish'),
@@ -154,4 +156,6 @@ value = [
 ]
 
 value.sort(lambda x,y:cmp(x[1], y[1]))
+# Put language neutral at the top.
+value.insert(0,('',_(u'Language neutral (site default)')))
 return value
