@@ -6,13 +6,13 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
-from Testing import ZopeTestCase
+from AccessControl import Unauthorized
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
 
 AddPortalTopics = 'Add portal topics'
 from Products.CMFPlone import LargePloneFolder
-from Products.CMFPlone import transaction
+import transaction
 from OFS.CopySupport import CopyError
 
 #    NOTE
@@ -20,6 +20,7 @@ from OFS.CopySupport import CopyError
 #    so we must pass in fields that the validators need
 #    such as title on a favorite's link_edit
 
+
 class TestContentTypeScripts(PloneTestCase.PloneTestCase):
 
     def afterSetUp(self):
@@ -161,13 +162,13 @@ class TestContentTypeScripts(PloneTestCase.PloneTestCase):
     # Bug tests
 
     def testClearImageTitle(self):
-        # Test for http://plone.org/collector/3303
+        # Test for http://dev.plone.org/plone/ticket/3303
         # Should be able to clear Image title
         self.folder.invokeFactory('Image', id='image', title='Foo', file=dummy.Image())
         self.assertEqual(self.folder.image.Title(), 'Foo')
         self.folder.image.image_edit(title='')
         self.assertEqual(self.folder.image.Title(), '')
- 
+
     def testAddToFavorites(self):
         # Ugh, addFavorite traverses to remote_url, so make sure it can.
         self.setRoles(['Manager'])
@@ -195,9 +196,18 @@ class TestContentTypeScripts(PloneTestCase.PloneTestCase):
         metatypes = tool.listMetaTags(doc)
         # TODO: atm it checks only of the script can be called w/o an error
 
+    def testObjectDeleteFailsOnGET(self):
+        self.assertRaises(Unauthorized, self.folder.object_delete,)
+
+    def testObjectDelete(self):
+        self.folder.invokeFactory('Document', id='doc')
+        self.app.REQUEST.set('REQUEST_METHOD', 'POST')
+        self.folder.doc.object_delete()
+        self.failIf('doc' in self.folder.objectIds())
+
 
 class TestEditShortName(PloneTestCase.PloneTestCase):
-    # Test fix for http://plone.org/collector/2246
+    # Test fix for http://dev.plone.org/plone/ticket/2246
     # Short name should be editable without specifying a file.
 
     def afterSetUp(self):
@@ -252,7 +262,7 @@ class TestEditShortName(PloneTestCase.PloneTestCase):
 
 
 class TestEditFileKeepsMimeType(PloneTestCase.PloneTestCase):
-    # Tests covering http://plone.org/collector/2792
+    # Tests covering http://dev.plone.org/plone/ticket/2792
     # Editing a file should not change MIME type
 
     def afterSetUp(self):
@@ -303,7 +313,7 @@ class TestEditFileKeepsMimeType(PloneTestCase.PloneTestCase):
 
 
 class TestFileURL(PloneTestCase.PloneTestCase):
-    # Tests covering http://plone.org/collector/3296
+    # Tests covering http://dev.plone.org/plone/ticket/3296
     # file:// URLs should contain correct number of slashes
     # NOTABUG: This is how urlparse.urlparse() works.
 
@@ -371,7 +381,7 @@ class TestBadFileIds(PloneTestCase.PloneTestCase):
         transaction.savepoint(optimistic=True) # make rename work
 
     def testUploadBadFile(self):
-        # http://plone.org/collector/3416
+        # http://dev.plone.org/plone/ticket/3416
         try:
             self.folder[self.file_id].file_edit(file=dummy.File('fred%.txt'))
         except CopyError:
@@ -382,7 +392,7 @@ class TestBadFileIds(PloneTestCase.PloneTestCase):
         self.failIf('fred%.txt' in self.folder.objectIds())
 
     def testUploadBadImage(self):
-        # http://plone.org/collector/3518
+        # http://dev.plone.org/plone/ticket/3518
         try:
             self.folder[self.image_id].image_edit(file=dummy.File('fred%.gif'))
         except CopyError:
@@ -393,10 +403,11 @@ class TestBadFileIds(PloneTestCase.PloneTestCase):
     # TODO: Dang! No easy way to get at the validator state...
 
 
-class TestImagePatch(PloneTestCase.PloneTestCase):
+class TestImageProps(PloneTestCase.PloneTestCase):
 
-    def testImagePatchComputedProps(self):
-        from Products.CMFPlone.patches.imagePatch import tag
+    def testImageComputedProps(self):
+        from OFS.Image import Image
+        tag = Image.tag.im_func
         kw = {'_title':'some title',
               '_alt':'alt tag',
               'height':100,
@@ -419,9 +430,9 @@ class TestWorkflowHistory(PloneTestCase.PloneTestCase):
     def test_WorkflowHistory(self):
         # see if doc returns any history at this point
         history = self.doc.getWorkflowHistory()
-        self.failUnlessEqual(history, []) 
+        self.failUnlessEqual(history, [])
 
-        # do a transition 
+        # do a transition
         self.setRoles(['Reviewer']) # has no modify portal content permission
         self.wf.doActionFor(self.doc, 'publish')
         self.wf.doActionFor(self.doc, 'retract')
@@ -449,7 +460,7 @@ def test_suite():
     suite.addTest(makeSuite(TestFileURL))
     suite.addTest(makeSuite(TestFileExtensions))
     suite.addTest(makeSuite(TestBadFileIds))
-    suite.addTest(makeSuite(TestImagePatch))
+    suite.addTest(makeSuite(TestImageProps))
     suite.addTest(makeSuite(TestWorkflowHistory))
     return suite
 
