@@ -6,13 +6,12 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
-from Testing import ZopeTestCase
 from Products.CMFPlone.tests import PloneTestCase
 
 from AccessControl import Unauthorized
 from OFS.CopySupport import CopyError
 from Acquisition import aq_base
-from Products.CMFPlone import transaction
+import transaction
 
 
 class TestCutPasteSecurity(PloneTestCase.PloneTestCase):
@@ -99,7 +98,7 @@ class TestCutPasteSecurity(PloneTestCase.PloneTestCase):
         self.assertRaises(Unauthorized, src.restrictedTraverse, 'manage_cutObjects')
 
     def test_Bug2183_PastingIntoFolderFailsForNotAllowedContentTypes(self):
-        # Test fix for http://plone.org/collector/2183
+        # Test fix for http://dev.plone.org/plone/ticket/2183
         # The fix itself is in CMFCore.PortalFolder, not Plone
 
         # add the document to be copy and pasted later
@@ -122,7 +121,7 @@ class TestCutPasteSecurity(PloneTestCase.PloneTestCase):
         )
 
     def test_Bug2183_PastingIntoPortalFailsForNotAllowedContentTypes(self):
-        # Test fix for http://plone.org/collector/2183
+        # Test fix for http://dev.plone.org/plone/ticket/2183
         # The fix itself is in CMFCore.PortalFolder, not Plone
 
         # add the document to be copy and pasted later
