@@ -9,7 +9,6 @@ if __name__ == '__main__':
 from Testing import ZopeTestCase
 from Products.CMFPlone.tests import PloneTestCase
 
-
 from Products.CMFCore.interfaces.DublinCore import DublinCore
 from Products.CMFCore.interfaces.Contentish import Contentish
 from Products.CMFCore.PortalContent import PortalContent
@@ -19,6 +18,7 @@ from Products.CMFDefault.Document import Document
 from Products.CMFPlone.InterfaceTool import resolveInterface, getDottedName
 from Products.CMFPlone.InterfaceTool import InterfaceFinder
 from Products.CMFPlone.interfaces import PloneBaseTool
+from Products.CMFPlone.utils import classImplements
 
 
 class MyPortalContent(Contentish): pass
@@ -26,10 +26,12 @@ class MyPortalContent(Contentish): pass
 class A(PortalContent, DefaultDublinCoreImpl):
     __implements__ = PortalContent.__implements__, \
                      DefaultDublinCoreImpl.__implements__
+classImplements(A, A.__implements__)
 
 class B(PortalContent, DefaultDublinCoreImpl):
     __implements__ = MyPortalContent, \
                      DefaultDublinCoreImpl.__implements__
+classImplements(B, B.__implements__)
 
 
 class TestInterfaceResolution(ZopeTestCase.ZopeTestCase):
