@@ -6,12 +6,11 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
-from Testing import ZopeTestCase
-from Products.CMFPlone.tests import PloneTestCase
 from cStringIO import StringIO
 
 from OFS.Image import Image
 
+from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
 
 from AccessControl.User import nobody
@@ -21,16 +20,14 @@ from DateTime import DateTime
 from zExceptions import BadRequest
 
 default_user = PloneTestCase.default_user
+default_password = PloneTestCase.default_password
 
 
 class TestMembershipTool(PloneTestCase.PloneTestCase):
 
     def afterSetUp(self):
         self.membership = self.portal.portal_membership
-
-        # Nuke Administators and Reviewers groups added in 2.1a2 migrations
-        # (and any other migrated-in groups) to avoid test confusion
-        self.portal.portal_groups.removeGroups(self.portal.portal_groups.listGroupIds())
+        self.groups = self.portal.portal_groups
 
     def addMember(self, username, fullname, email, roles, last_login_time):
         self.membership.addMember(username, 'secret', roles, [])
@@ -41,7 +38,7 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         import Products.CMFPlone as plone
         plone_path = os.path.dirname(plone.__file__)
         path = os.path.join(plone_path, 'tests', 'images', 'test.jpg')
-        image = open(path)
+        image = open(path, 'rb')
         image_upload = dummy.FileUpload(dummy.FieldStorage(image))
         return image_upload
 
@@ -93,8 +90,9 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
     def testListMembersSkipsGroups(self):
         # Should only return real members, not groups
         uf = self.portal.acl_users
-        uf.changeOrCreateGroups(new_groups=['Foo', 'Bar'])
-        self.assertEqual(len(uf.getUserNames()), 3)
+        self.groups.addGroup('Foo')
+        self.groups.addGroup('Bar')
+        self.assertEqual(len(uf.getUserNames()), 1)
         members = self.membership.listMembers()
         self.assertEqual(len(members), 1)
         self.assertEqual(members[0].getId(), default_user)
@@ -108,8 +106,9 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
     def testListMemberIdsSkipsGroups(self):
         # Should only return real members, not groups
         uf = self.portal.acl_users
-        uf.changeOrCreateGroups(new_groups=['Foo', 'Bar'])
-        self.assertEqual(len(uf.getUserNames()), 3)
+        self.groups.addGroup('Foo')
+        self.groups.addGroup('Bar')
+        self.assertEqual(len(uf.getUserNames()), 1)
         memberids = self.membership.listMemberIds()
         self.assertEqual(len(memberids), 1)
         self.assertEqual(memberids[0], default_user)
@@ -139,10 +138,10 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
     def testSetPasswordAndKeepGroups(self):
         # Password should be changed and user must not change group membership
         group2 = 'g2'
-        groups = self.portal.portal_groups
+        groups = self.groups
         groups.addGroup(group2, None, [], [])
         group = groups.getGroupById(group2)
-        self.loginPortalOwner() # GRUF 3.52
+        self.loginAsPortalOwner() # GRUF 3.52
         group.addMember(default_user)
         self.login(default_user) # Back to normal
         ugroups = self.portal.acl_users.getUserById(default_user).getGroups()
@@ -163,7 +162,7 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         member = self.membership.getMemberById(default_user)
         self.failIfEqual(member, None)
         self.assertEqual(member.__class__.__name__, 'MemberData')
-        self.assertEqual(member.aq_parent.__class__.__name__, 'GRUFUser')
+        self.assertEqual(member.aq_parent.__class__.__name__, 'PloneUser')
 
     def testGetAuthenticatedMember(self):
         member = self.membership.getAuthenticatedMember()
@@ -173,7 +172,7 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         member = self.membership.getAuthenticatedMember()
         self.assertEqual(member.getUserName(), default_user)
         self.assertEqual(member.__class__.__name__, 'MemberData')
-        self.assertEqual(member.aq_parent.__class__.__name__, 'GRUFUser')
+        self.assertEqual(member.aq_parent.__class__.__name__, 'PloneUser')
 
     def testGetAuthenticatedMemberIfAnonymous(self):
         self.logout()
@@ -181,7 +180,7 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         self.assertEqual(member.getUserName(), 'Anonymous User')
 
     def testAnonymousMemberIsNotWrapped(self):
-        # Also see http://plone.org/collector/1851
+        # Also see http://dev.plone.org/plone/ticket/1851
         self.logout()
         member = self.membership.getAuthenticatedMember()
         self.failIfEqual(member.__class__.__name__, 'MemberData')
@@ -199,8 +198,8 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         user = aq_base(user)
         user = self.membership.wrapUser(user)
         self.assertEqual(user.__class__.__name__, 'MemberData')
-        self.assertEqual(user.aq_parent.__class__.__name__, 'GRUFUser')
-        self.assertEqual(user.aq_parent.aq_parent.__class__.__name__, 'GroupUserFolder')
+        self.assertEqual(user.aq_parent.__class__.__name__, 'PloneUser')
+        self.assertEqual(user.aq_parent.aq_parent.__class__.__name__, 'PluggableAuthService')
 
     def testWrapUserWrapsWrappedUser(self):
         user = self.portal.acl_users.getUserById(default_user)
@@ -208,14 +207,14 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         self.failUnless(hasattr(user, 'aq_base'))
         user = self.membership.wrapUser(user)
         self.assertEqual(user.__class__.__name__, 'MemberData')
-        self.assertEqual(user.aq_parent.__class__.__name__, 'GRUFUser')
-        self.assertEqual(user.aq_parent.aq_parent.__class__.__name__, 'GroupUserFolder')
+        self.assertEqual(user.aq_parent.__class__.__name__, 'PloneUser')
+        self.assertEqual(user.aq_parent.aq_parent.__class__.__name__, 'PluggableAuthService')
 
     def testWrapUserDoesntWrapMemberData(self):
         user = self.portal.acl_users.getUserById(default_user)
         user.getMemberId = lambda x: 1
         user = self.membership.wrapUser(user)
-        self.assertEqual(user.__class__.__name__, 'GRUFUser')
+        self.assertEqual(user.__class__.__name__, 'PloneUser')
 
     def testWrapUserDoesntWrapAnonymous(self):
         user = self.membership.wrapUser(nobody)
@@ -226,7 +225,7 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         user = self.membership.wrapUser(nobody, wrap_anon=1)
         self.assertEqual(user.__class__.__name__, 'MemberData')
         self.assertEqual(user.aq_parent.__class__.__name__, 'SpecialUser')
-        self.assertEqual(user.aq_parent.aq_parent.__class__.__name__, 'GroupUserFolder')
+        self.assertEqual(user.aq_parent.aq_parent.__class__.__name__, 'PluggableAuthService')
 
     def testGetCandidateLocalRoles(self):
         self.assertEqual(self.membership.getCandidateLocalRoles(self.folder), ('Owner',))
@@ -310,7 +309,7 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         self.setRoles(['Manager'])
         self.addMember('barney', 'Barney Rubble', 'barney@bedrock.com', ['Member'], '2002-01-01')
         barney = self.membership.getMemberById('barney')
-        self.failUnlessEqual(barney.email, 'barney@bedrock.com')
+        self.failUnlessEqual(barney.getProperty('email'), 'barney@bedrock.com')
         del barney
 
         self.membership.deleteMembers(['barney'])
@@ -324,10 +323,10 @@ class TestMembershipTool(PloneTestCase.PloneTestCase):
         # using the tool.
         memberdata._v_temps = None
 
-        self.membership.addMember('barney', 'secret', ['Members'], [])
+        self.membership.addMember('barney', 'secret', ['Member'], [])
         barney = self.membership.getMemberById('barney')
-        self.failIfEqual(barney.fullname, 'Barney Rubble')
-        self.failIfEqual(barney.email, 'barney@bedrock.com')
+        self.failIfEqual(barney.getProperty('fullname'), 'Barney Rubble')
+        self.failIfEqual(barney.getProperty('email'), 'barney@bedrock.com')
 
     def testBogusMemberPortrait(self):
         # Should change the portrait image
@@ -370,17 +369,6 @@ class TestCreateMemberarea(PloneTestCase.PloneTestCase):
         # member area creation should be on by default
         self.failUnless(self.membership.getMemberareaCreationFlag())
 
-##     def testWrapUserCreatesMemberarea(self):
-##         # This test serves to trip us up should this ever change
-##         # Also see http://plone.org/collector/1697
-##         members = self.membership.getMembersFolder()
-##         user = self.portal.acl_users.getUserById('user2')
-##         self.membership.memberareaCreationFlag = 1
-##         import pdb; pdb.set_trace()
-##         self.membership.wrapUser(user)
-##         memberfolder = self.membership.getHomeFolder('user2')
-##         self.failUnless(memberfolder, 'wrapUser failed to create memberarea')
-
     def testCreatMemberareaUsesCurrentUser(self):
         # Should create a memberarea for user2
         self.login('user2')
@@ -428,7 +416,6 @@ class TestCreateMemberarea(PloneTestCase.PloneTestCase):
         memberfolder = self.membership.getHomeFolder('user2')
         self.failIf(memberfolder, 'createMemberarea created memberarea despite flag')
 
-
 class TestMemberareaSetup(PloneTestCase.PloneTestCase):
 
     def afterSetUp(self):
@@ -600,6 +587,19 @@ class TestSearchForMembers(PloneTestCase.PloneTestCase):
                                     before_specified_time=True)), 1)
 
 
+class TestDefaultUserAndPasswordNotChanged(PloneTestCase.PloneTestCase):
+    # A test for a silly transaction/persistency bug in PlonePAS
+
+    def afterSetUp(self):
+        self.membership = self.portal.portal_membership
+
+    def testDefaultUserAndPasswordUnchanged(self):
+        member = self.membership.getAuthenticatedMember()
+        self.assertEqual(member.getUserName(), default_user)
+        self.failUnless(self.membership.testCurrentPassword(default_password))
+        self.failIf(self.membership.testCurrentPassword('geheim'))
+
+
 class TestMethodProtection(PloneTestCase.PloneTestCase):
     # MembershipTool is missing security declarations
     # http://dev.plone.org/plone/ticket/5432
@@ -636,6 +636,7 @@ def test_suite():
     suite.addTest(makeSuite(TestCreateMemberarea))
     suite.addTest(makeSuite(TestMemberareaSetup))
     suite.addTest(makeSuite(TestSearchForMembers))
+    suite.addTest(makeSuite(TestDefaultUserAndPasswordNotChanged))
     suite.addTest(makeSuite(TestMethodProtection))
     return suite
 
