@@ -6,14 +6,14 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
-from Testing import ZopeTestCase
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
+
 from Products.CMFCore.utils import getToolByName
 from Acquisition import Implicit
 
 default_user = PloneTestCase.default_user
-
+portal_name = PloneTestCase.portal_name
 
 class DummyTitle(Implicit):
     def Title(self):
@@ -65,7 +65,7 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
             self.failUnless(val(address), '%s should validate' % address)
         for address in invalidInputs:
             self.failIf(val(address), '%s should fail' % address)
-    
+
     def testvalidateEmailAddresses(self):
         # Any RFC 822 email address allowed and address list allowed
         val = self.utils.validateEmailAddresses
@@ -93,7 +93,7 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
             self.failIf(val(address), '%s should fail' % address)
 
     def testEditFormatMetadataOfFile(self):
-        # Test fix for http://plone.org/collector/1323
+        # Test fix for http://dev.plone.org/plone/ticket/1323
         # Fixed in CMFDefault.File, not Plone.
         self.folder.invokeFactory('File', id='file')
         self.folder.file.edit(file=dummy.File('foo.zip'))
@@ -105,7 +105,7 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
         self.assertEqual(self.folder.file.getFile().content_type, 'image/gif')
 
     def testEditFormatMetadataOfImage(self):
-        # Test fix for http://plone.org/collector/1323
+        # Test fix for http://dev.plone.org/plone/ticket/1323
         # Fixed in CMFDefault.Image, not Plone.
         self.folder.invokeFactory('Image', id='image')
         self.folder.image.edit(file=dummy.Image('foo.zip'))
@@ -131,10 +131,11 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
         # Punctuation and spaces are trimmed, multiples reduced to 1
         self.assertEqual(self.utils.normalizeString(" a string    "),
                          'a-string')
-        self.assertEqual(self.utils.normalizeString(">here's another!"),
-                         'here-s-another')
-        self.assertEqual(self.utils.normalizeString("one with !@#$!@#$ stuff in the middle"),
-                         'one-with-stuff-in-the-middle')
+        self.assertEqual(self.utils.normalizeString(">here is another!"),
+                         'here-is-another')
+        self.assertEqual(
+            self.utils.normalizeString("one with !@#$!@#$ stuff in the middle"),
+            'one-with-stuff-in-the-middle')
 
     def testNormalizeStringFileExtensions(self):
         # If there is something that looks like a file extensions
@@ -145,7 +146,8 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
                          'this-is-also-a-file.html')
 
     def testNormalizeStringAccents(self):
-        # European accented chars will be transliterated to rough ASCII equivalents
+        # European accented chars will be transliterated to rough
+        # ASCII equivalents
         input = u"Eksempel \xe6\xf8\xe5 norsk \xc6\xd8\xc5"
         self.assertEqual(self.utils.normalizeString(input),
                          'eksempel-eoa-norsk-eoa')
@@ -158,20 +160,28 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
 
     def testNormalizeGreek(self):
         # Greek letters (not supported by UnicodeData)
-        input = u'\u039d\u03af\u03ba\u03bf\u03c2 \u03a4\u03b6\u03ac\u03bd\u03bf\u03c2'
+        input = (u'\u039d\u03af\u03ba\u03bf\u03c2 '
+                 u'\u03a4\u03b6\u03ac\u03bd\u03bf\u03c2')
         self.assertEqual(self.utils.normalizeString(input), 'nikos-tzanos')
- 
+
     def testNormalizeGreekUTF8(self):
         # Greek letters (not supported by UnicodeData)
-        input = u'\u039d\u03af\u03ba\u03bf\u03c2 \u03a4\u03b6\u03ac\u03bd\u03bf\u03c2'.encode('utf-8')
+        input = (u'\u039d\u03af\u03ba\u03bf\u03c2 '
+                 u'\u03a4\u03b6\u03ac\u03bd\u03bf\u03c2').encode('utf-8')
         self.assertEqual(self.utils.normalizeString(input), 'nikos-tzanos')
- 
+
     def testNormalizeStringHex(self):
         # Everything that can't be transliterated will be hex'd
-        self.assertEqual(self.utils.normalizeString(u"\u9ad8\u8054\u5408 Chinese"),
-                         '9ad880545408-chinese')
-        self.assertEqual(self.utils.normalizeString(u"\uc774\ubbf8\uc9f1 Korean"),
-                         'c774bbf8c9f1-korean')
+        self.assertEqual(
+            self.utils.normalizeString(u"\u9ad8\u8054\u5408 Chinese"),
+            '9ad880545408-chinese')
+        self.assertEqual(
+            self.utils.normalizeString(u"\uc774\ubbf8\uc9f1 Korean"),
+            'c774bbf8c9f1-korean')
+
+    def testNormalizeStringIgnoredCharacters(self):
+        # Some characters should be ignored
+        self.assertEqual(self.utils.normalizeString("test'test"), 'testtest')
 
     def testNormalizeStringObject(self):
         # Objects should be converted to strings using repr()
@@ -198,7 +208,16 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
         # Punctuation and spacing is removed and replaced by '-'
         self.assertEqual(self.utils.normalizeString("A ?String&/\\.foo_!$#xx", relaxed=True),
                          'A -String-.foo_!$-xx')
-        
+
+    def testTypesToList(self):
+        # Make sure typesToList() returns the expected types
+        wl = self.utils.typesToList()
+        self.failUnless('Folder' in wl)
+        self.failUnless('Large Plone Folder' in wl)
+        self.failUnless('Topic' in wl)
+        self.failIf('ATReferenceCriterion' in wl)
+
+
 class TestOwnershipStuff(PloneTestCase.PloneTestCase):
 
     def afterSetUp(self):
@@ -223,11 +242,13 @@ class TestOwnershipStuff(PloneTestCase.PloneTestCase):
     def testChangeOwnershipOf(self):
         # Should take ownership
         self.assertEqual(self.folder1.getOwnerTuple()[1], default_user)
-        self.assertList(self.folder1.get_local_roles_for_userid(default_user), ['Owner'])
+        self.assertList(self.folder1.get_local_roles_for_userid(default_user),
+                        ['Owner'])
 
         self.utils.changeOwnershipOf(self.folder1, 'new_owner')
         self.assertEqual(self.folder1.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'), ['Owner'])
+        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'),
+                        ['Owner'])
 
         # Initial creator no longer has Owner role.
         self.assertList(self.folder1.get_local_roles_for_userid(default_user), [])
@@ -235,23 +256,28 @@ class TestOwnershipStuff(PloneTestCase.PloneTestCase):
     def testChangeOwnershipOfKeepsOtherRoles(self):
         # Should preserve roles other than Owner
         self.folder1.manage_addLocalRoles('new_owner', ('Reviewer',))
-        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'), ['Reviewer'])
+        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'),
+                        ['Reviewer'])
         self.utils.changeOwnershipOf(self.folder1, 'new_owner')
         self.assertEqual(self.folder1.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'), ['Owner', 'Reviewer'])
+        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'),
+                        ['Owner', 'Reviewer'])
         self.assertList(self.folder1.get_local_roles_for_userid(default_user), [])
 
     def testChangeOwnershipOfRecursive(self):
         # Should take ownership of subobjects as well
         self.utils.changeOwnershipOf(self.folder1, 'new_owner', recursive=1)
         self.assertEqual(self.folder1.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'), ['Owner'])
+        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'),
+                        ['Owner'])
         self.assertList(self.folder1.get_local_roles_for_userid(default_user), [])
         self.assertEqual(self.folder2.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder2.get_local_roles_for_userid('new_owner'), ['Owner'])
+        self.assertList(self.folder2.get_local_roles_for_userid('new_owner'),
+                        ['Owner'])
         self.assertList(self.folder2.get_local_roles_for_userid(default_user), [])
         self.assertEqual(self.folder3.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder3.get_local_roles_for_userid('new_owner'), ['Owner'])
+        self.assertList(self.folder3.get_local_roles_for_userid('new_owner'),
+                        ['Owner'])
         self.assertList(self.folder3.get_local_roles_for_userid(default_user), [])
 
     def testGetOwnerName(self):
@@ -272,7 +298,7 @@ class TestOwnershipStuff(PloneTestCase.PloneTestCase):
         self.assertList(filtered_roles[1], ['Reviewer'])
 
     def testGetInheritedLocalRolesMultiLevel(self):
-        # Test for http://members.plone.org/collector/3901
+        # Test for http://dev.plone.org/plone/ticket/3901
         # make sure local roles are picked up from all folders in tree.
         gILR = self.utils.getInheritedLocalRoles
         self.folder1.manage_addLocalRoles('new_owner', ('Reviewer',))
@@ -380,11 +406,11 @@ class TestEditMetadata(PloneTestCase.PloneTestCase):
     def testSetEffectiveDate(self):
         self.assertEqual(self.doc.EffectiveDate(), 'None')
         self.utils.editMetadata(self.doc, effective_date='2001-01-01')
-        self.assertEqual(self.doc.EffectiveDate(), '2001-01-01 00:00:00')
+        self.assertEqual(self.doc.EffectiveDate(zone='UTC'), '2001-01-01 00:00:00')
 
     def testClearEffectiveDate(self):
         self.utils.editMetadata(self.doc, effective_date='2001-01-01')
-        self.assertEqual(self.doc.EffectiveDate(), '2001-01-01 00:00:00')
+        self.assertEqual(self.doc.EffectiveDate(zone='UTC'), '2001-01-01 00:00:00')
         self.utils.editMetadata(self.doc, effective_date='None')
         self.assertEqual(self.doc.EffectiveDate(), 'None')
         self.assertEqual(self.doc.effective_date, None)
@@ -392,11 +418,11 @@ class TestEditMetadata(PloneTestCase.PloneTestCase):
     def testSetExpirationDate(self):
         self.assertEqual(self.doc.ExpirationDate(), 'None')
         self.utils.editMetadata(self.doc, expiration_date='2001-01-01')
-        self.assertEqual(self.doc.ExpirationDate(), '2001-01-01 00:00:00')
+        self.assertEqual(self.doc.ExpirationDate(zone='UTC'), '2001-01-01 00:00:00')
 
     def testClearExpirationDate(self):
         self.utils.editMetadata(self.doc, expiration_date='2001-01-01')
-        self.assertEqual(self.doc.ExpirationDate(), '2001-01-01 00:00:00')
+        self.assertEqual(self.doc.ExpirationDate(zone='UTC'), '2001-01-01 00:00:00')
         self.utils.editMetadata(self.doc, expiration_date='None')
         self.assertEqual(self.doc.ExpirationDate(), 'None')
         self.assertEqual(self.doc.expiration_date, None)
@@ -406,7 +432,7 @@ class TestEditMetadata(PloneTestCase.PloneTestCase):
     def testTuplifySubject_1(self):
         self.utils.editMetadata(self.doc, subject=['Foo', 'Bar', 'Baz'])
         self.assertEqual(self.doc.Subject(), ('Foo', 'Bar', 'Baz'))
-        
+
     def testTuplifySubject_2(self):
         self.utils.editMetadata(self.doc, subject=['Foo', '', 'Bar', 'Baz'])
         # Note that empty entries are filtered
@@ -416,11 +442,11 @@ class TestEditMetadata(PloneTestCase.PloneTestCase):
         self.utils.editMetadata(self.doc, subject='Foo, Bar, Baz')
         # TODO: Wishful thinking
         self.assertEqual(self.doc.Subject(), ('Foo', 'Bar', 'Baz'))
-        
+
     def testTuplifyContributors_1(self):
         self.utils.editMetadata(self.doc, contributors=['Foo', 'Bar', 'Baz'])
         self.assertEqual(self.doc.Contributors(), ('Foo', 'Bar', 'Baz'))
-        
+
     def testTuplifyContributors_2(self):
         self.utils.editMetadata(self.doc, contributors=['Foo', '', 'Bar', 'Baz'])
         # Note that empty entries are filtered
@@ -430,7 +456,7 @@ class TestEditMetadata(PloneTestCase.PloneTestCase):
         self.utils.editMetadata(self.doc, contributors='Foo; Bar; Baz')
         # TODO: Wishful thinking
         self.assertEqual(self.doc.Contributors(), ('Foo', 'Bar', 'Baz'))
-        
+
 
 class TestEditMetadataIndependence(PloneTestCase.PloneTestCase):
 
@@ -438,7 +464,7 @@ class TestEditMetadataIndependence(PloneTestCase.PloneTestCase):
         self.utils = self.portal.plone_utils
         self.folder.invokeFactory('Document', id='doc')
         self.doc = self.folder.doc
-        self.utils.editMetadata(self.doc, 
+        self.utils.editMetadata(self.doc,
                                 title='Foo',
                                 subject=('Bar',),
                                 description='Baz',
@@ -457,8 +483,8 @@ class TestEditMetadataIndependence(PloneTestCase.PloneTestCase):
         self.assertEqual(self.doc.Subject(), ('Bar',))
         self.assertEqual(self.doc.Description(), 'Baz')
         self.assertEqual(self.doc.Contributors(), ('Fred',))
-        self.assertEqual(self.doc.EffectiveDate(), '2001-01-01 00:00:00')
-        self.assertEqual(self.doc.ExpirationDate(), '2003-01-01 00:00:00')
+        self.assertEqual(self.doc.EffectiveDate(zone='UTC'), '2001-01-01 00:00:00')
+        self.assertEqual(self.doc.ExpirationDate(zone='UTC'), '2003-01-01 00:00:00')
         self.assertEqual(self.doc.Format(), 'text/html')
         self.assertEqual(self.doc.Language(), 'de')
         self.assertEqual(self.doc.Rights(), 'Copyleft')
@@ -470,21 +496,21 @@ class TestEditMetadataIndependence(PloneTestCase.PloneTestCase):
         self.assertEqual(self.doc.Title(), 'Foo')
         self.assertEqual(self.doc.Description(), 'Baz')
         self.assertEqual(self.doc.Contributors(), ('Fred',))
-        self.assertEqual(self.doc.EffectiveDate(), '2001-01-01 00:00:00')
-        self.assertEqual(self.doc.ExpirationDate(), '2003-01-01 00:00:00')
+        self.assertEqual(self.doc.EffectiveDate(zone='UTC'), '2001-01-01 00:00:00')
+        self.assertEqual(self.doc.ExpirationDate(zone='UTC'), '2003-01-01 00:00:00')
         self.assertEqual(self.doc.Format(), 'text/html')
         self.assertEqual(self.doc.Language(), 'de')
         self.assertEqual(self.doc.Rights(), 'Copyleft')
 
     def testEditEffectiveDateOnly(self):
         self.utils.editMetadata(self.doc, effective_date='2001-12-31')
-        self.assertEqual(self.doc.EffectiveDate(), '2001-12-31 00:00:00')
+        self.assertEqual(self.doc.EffectiveDate(zone='UTC'), '2001-12-31 00:00:00')
         # Other elements must not change
         self.assertEqual(self.doc.Title(), 'Foo')
         self.assertEqual(self.doc.Subject(), ('Bar',))
         self.assertEqual(self.doc.Description(), 'Baz')
         self.assertEqual(self.doc.Contributors(), ('Fred',))
-        self.assertEqual(self.doc.ExpirationDate(), '2003-01-01 00:00:00')
+        self.assertEqual(self.doc.ExpirationDate(zone='UTC'), '2003-01-01 00:00:00')
         self.assertEqual(self.doc.Format(), 'text/html')
         self.assertEqual(self.doc.Language(), 'de')
         self.assertEqual(self.doc.Rights(), 'Copyleft')
@@ -497,14 +523,15 @@ class TestEditMetadataIndependence(PloneTestCase.PloneTestCase):
         self.assertEqual(self.doc.Subject(), ('Bar',))
         self.assertEqual(self.doc.Description(), 'Baz')
         self.assertEqual(self.doc.Contributors(), ('Fred',))
-        self.assertEqual(self.doc.EffectiveDate(), '2001-01-01 00:00:00')
-        self.assertEqual(self.doc.ExpirationDate(), '2003-01-01 00:00:00')
+        self.assertEqual(self.doc.EffectiveDate(zone='UTC'), '2001-01-01 00:00:00')
+        self.assertEqual(self.doc.ExpirationDate(zone='UTC'), '2003-01-01 00:00:00')
         self.assertEqual(self.doc.Format(), 'text/html')
         self.assertEqual(self.doc.Rights(), 'Copyleft')
 
 
 class TestFormulatorFields(PloneTestCase.PloneTestCase):
-    '''This feature should probably go away entirely.'''
+    """This feature should probably go away entirely.
+    """
 
     def afterSetUp(self):
         self.utils = self.portal.plone_utils
@@ -529,7 +556,7 @@ class TestFormulatorFields(PloneTestCase.PloneTestCase):
     def testEffectiveDateField(self):
         self.setField('effective_date', '2001-01-01')
         self.utils.editMetadata(self.doc)
-        self.assertEqual(self.doc.EffectiveDate(), '2001-01-01 00:00:00')
+        self.assertEqual(self.doc.EffectiveDate(zone='UTC'), '2001-01-01 00:00:00')
 
     def testLanguageField(self):
         self.setField('language', 'de')
@@ -736,7 +763,8 @@ class TestBreadCrumbs(PloneTestCase.PloneTestCase):
 
 
 class TestIDGenerationMethods(PloneTestCase.PloneTestCase):
-    '''Tests the isIDAutoGenerated method and pretty_title_or_id'''
+    """Tests the isIDAutoGenerated method and pretty_title_or_id
+    """
 
     def afterSetUp(self):
         self.utils = self.portal.plone_utils
@@ -758,11 +786,13 @@ class TestIDGenerationMethods(PloneTestCase.PloneTestCase):
 
     def test_pretty_title_or_id_returns_title(self):
         self.folder.setTitle('My pretty title')
-        self.assertEqual(self.utils.pretty_title_or_id(self.folder), 'My pretty title')
+        self.assertEqual(self.utils.pretty_title_or_id(self.folder),
+                         'My pretty title')
 
     def test_pretty_title_or_id_returns_id(self):
         self.folder.setTitle('')
-        self.assertEqual(self.utils.pretty_title_or_id(self.folder), self.folder.getId())
+        self.assertEqual(self.utils.pretty_title_or_id(self.folder),
+                         self.folder.getId())
 
     def test_pretty_title_or_id_when_autogenerated(self):
         self.setRoles(['Manager','Member'])
@@ -805,8 +835,8 @@ class TestIDGenerationMethods(PloneTestCase.PloneTestCase):
     def test_pretty_title_or_id_on_catalog_brain_autogenerated(self):
         cat = self.portal.portal_catalog
         self.setRoles(['Manager','Member'])
-        self.folder.edit(id='folder.2004-11-09.0123456789', title='',
-                                                            subject='foobar')
+        self.folder.edit(id='folder.2004-11-09.0123456789',
+                         title='', subject='foobar')
         results = cat(Subject='foobar')
         self.assertEqual(len(results), 1)
         self.assertEqual(self.utils.pretty_title_or_id(results[0], 'Marker'),
@@ -835,6 +865,38 @@ class TestIDGenerationMethods(PloneTestCase.PloneTestCase):
         for k, v in aliases.items():
             self.assertEqual(expectedAliases[k], v)
 
+class TestPortalStatusMessages(PloneTestCase.PloneTestCase):
+    '''Tests the portal status messages methods'''
+
+    def afterSetUp(self):
+        self.utils = self.portal.plone_utils
+
+    # XXX these don't work anymore as the cookie handling needs a real
+    # request/response to take effect
+    def DISABLED_testPortalMessages(self):
+        # make sure there's no stored message
+        self.assertEqual(len(self.utils.showPortalMessages()), 0)
+        # add one message
+        self.utils.addPortalMessage(u'message', type=u'info')
+        msgs = self.utils.showPortalMessages()
+        self.assertEqual(len(msgs), 1)
+        self.assertEqual(msgs[0].message, u'message')
+        self.assertEqual(msgs[0].type, u'info')
+        # make sure messages are removed
+        msgs = self.utils.showPortalMessages()
+        self.assertEqual(len(msgs), 0)
+        # add two messages
+        self.utils.addPortalMessage(u'message1', type=u'info')
+        self.utils.addPortalMessage(u'message2', type=u'warn')
+        msgs = self.utils.showPortalMessages()
+        self.assertEqual(len(msgs), 2)
+        self.assertEqual(msgs[0].message, u'message1')
+        self.assertEqual(msgs[0].type, u'info')
+        self.assertEqual(msgs[1].message, u'message2')
+        self.assertEqual(msgs[1].type, u'warn')
+        # make sure there's no stored message
+        self.assertEqual(len(self.utils.showPortalMessages()), 0)
+
 
 def test_suite():
     from unittest import TestSuite, makeSuite
@@ -847,6 +909,7 @@ def test_suite():
     suite.addTest(makeSuite(TestPortalTabs))
     suite.addTest(makeSuite(TestBreadCrumbs))
     suite.addTest(makeSuite(TestIDGenerationMethods))
+    suite.addTest(makeSuite(TestPortalStatusMessages))
     return suite
 
 if __name__ == '__main__':
