@@ -2,11 +2,12 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
-from Testing import ZopeTestCase
 from Products.CMFPlone.tests import PloneTestCase
+
 from Products.CMFPlone.tests import dummy
 from Products.CMFPlone.tests.PloneTestCase import default_user
 from Products.CMFPlone.tests.PloneTestCase import default_password
+
 from Products.CMFCore.utils import getToolByName
 
 from StringIO import StringIO
@@ -18,28 +19,21 @@ html = """\
 </html>
 """
 
-def mkdict(items):
-    '''Constructs a dict from a sequence of (key, value) pairs.'''
-    d = {}
-    for k, v in items:
-        d[k] = v
-    return d
-
 
 class TestDAVProperties(PloneTestCase.PloneTestCase):
 
     def testPropertiesToolTitle(self):
         ptool = getToolByName(self.portal, 'portal_properties')
-        psets = mkdict(ptool.propertysheets.items())
-        self.failUnless('default' in psets.keys())
-        default = psets['default']
-        items = mkdict(default.propertyItems())
-        self.failUnless('title' in items.keys())
-        self.assertEquals(items['title'], self.portal.title)
+        psets = dict(ptool.propertysheets.items())
+        self.failUnless('webdav' in psets.keys())
+        default = psets['webdav']
+        items = dict(default.propertyItems())
+        self.failUnless('displayname' in items.keys())
+        self.assertEquals(items['displayname'], self.portal.title)
 
 
 class TestDAVMetadata(PloneTestCase.FunctionalTestCase):
-    # Confirms fix for http://plone.org/collector/3217
+    # Confirms fix for http://dev.plone.org/plone/ticket/3217
     # The fix itself is in CMFDefault.Document, not Plone.
 
     def afterSetUp(self):
@@ -69,7 +63,7 @@ class TestDAVMetadata(PloneTestCase.FunctionalTestCase):
 
 class TestPUTObjects(PloneTestCase.FunctionalTestCase):
     # PUT objects into Plone including special cases like index_html.
-    # Confirms fix for http://plone.org/collector/1375
+    # Confirms fix for http://dev.plone.org/plone/ticket/1375
 
     def afterSetUp(self):
         self.basic_auth = '%s:%s' % (default_user, default_password)
@@ -293,8 +287,8 @@ class TestPUTObjects(PloneTestCase.FunctionalTestCase):
 class TestDAVOperations(PloneTestCase.FunctionalTestCase):
 
     def afterSetUp(self):
-        self.loginPortalOwner()
-        self.basic_auth = '%s:%s' % (PloneTestCase.portal_owner, '')
+        self.loginAsPortalOwner()
+        self.basic_auth = '%s:%s' % (PloneTestCase.portal_owner, PloneTestCase.default_password)
         self.portal_path = self.portal.absolute_url(1)
         self.folder_path = self.folder.absolute_url(1)
 
