@@ -10,17 +10,34 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
+# Suppress DeprecationWarnings, we really don't want any in these tests
+import warnings
+warnings.simplefilter('ignore', DeprecationWarning, append=1)
+
 from Testing import ZopeTestCase
+from Testing.ZopeTestCase import _print
+
+ZopeTestCase.installProduct('PlacelessTranslationService')
+ZopeTestCase.installProduct('ZChecker')
+
 from Products.CMFPlone.tests import PloneTestCase
 
-ZopeTestCase.installProduct('ZChecker')
-from Testing.ZopeTestCase import _print
+from Products.PloneTestCase import setup
+from Products.PloneTestCase import layer
+
+if setup.USELAYER:
+    # Set up the Plone site "layer"
+    layer.ZCML.setUp()
+    layer.PloneSite.setUp()
 
 ignoredObjectIds = ['rssBody', 'RSS', 'rss_template', 'search_rss',
                     'test_ecmascripts',
                     # There is no DTD for the pdf topic stuff
                     'atct_topic_pdf', 'atct_topic_pdf_template']
 
+ignoredSkinLayers = ['portal_skins/kupu_plone', 'portal_skins/kupu_tests']
+
+
 class TestSkins(PloneTestCase.PloneTestCase):
     # Note: This looks like a unit test but isn't
 
@@ -34,9 +51,11 @@ class TestSkins(PloneTestCase.PloneTestCase):
         '''Runs the ZChecker on skins'''
         dirs = self.portal.portal_skins.objectValues()
         for dir in dirs:
-            results = self.portal.zchecker.checkObjects(dir.objectValues())
-            for result in results:
-                self._report(result)
+            # filter out certain skin layers
+            if self._skinpath(dir) not in ignoredSkinLayers:
+                results = self.portal.zchecker.checkObjects(dir.objectValues())
+                for result in results:
+                    self._report(result)
         if self.verbose:
             _print('\n')
 
@@ -58,5 +77,6 @@ class TestSkins(PloneTestCase.PloneTestCase):
         path = path.split('/')
         return '/'.join(path[1:])
 
+
 if __name__ == '__main__':
     TestRunner(verbosity=0).run(test_suite())
