@@ -5,7 +5,7 @@
 # Author:      Philipp Auersperg
 #
 # Created:     2003/10/01
-# RCS-ID:      $Id: QuickInstallerTool.py 21300 2006-03-26 06:41:43Z pupq $
+# RCS-ID:      $Id: QuickInstallerTool.py 41248 2007-04-28 10:49:16Z hannosch $
 # Copyright:   (c) 2003 BlueDynamics
 # Licence:     GPL
 #-----------------------------------------------------------------------------
@@ -65,6 +65,17 @@ try:
 except ImportError:
     def not_installed(s): return []
 
+# postonly decorator is only available in Zope 2.8.9, 2.9.7, 2.10.3 and 2.11,
+# or in Hotfix_20070320.
+try:
+    from AccessControl.requestmethod import postonly
+except ImportError:
+    try:
+        from Products.Hotfix_20070320 import postonly
+    except ImportError:
+        def postonly(callable):
+            return callable
+
 class AlreadyInstalled(Exception):
     """ Would be nice to say what Product was trying to be installed """
     pass
@@ -511,6 +522,7 @@ class QuickInstallerTool(UniqueObject, ObjectManager, SimpleItem):
 
         if REQUEST:
             return REQUEST.RESPONSE.redirect(REQUEST['HTTP_REFERER'])
+    uninstallProducts = postonly(uninstallProducts)
 
     security.declareProtected(ManagePortal, 'reinstallProducts')
     def reinstallProducts(self, products, REQUEST=None):
@@ -529,6 +541,8 @@ class QuickInstallerTool(UniqueObject, ObjectManager, SimpleItem):
 
         if REQUEST:
             return REQUEST.RESPONSE.redirect(REQUEST['HTTP_REFERER'])
+    # XXX: Should be enabled once the Plone control panel supports this.
+    # reinstallProducts = postonly(reinstallProducts)
 
     def getQIElements(self):
         res = ['types', 'skins', 'actions', 'portalobjects', 'workflows', 
