@@ -24,7 +24,7 @@ Basic group data tool.
 """
 __version__ = "$Revision:  $"
 # $Source:  $
-# $Id: GroupDataTool.py 30098 2006-09-08 12:35:01Z encolpe $
+# $Id: GroupDataTool.py 40124 2007-04-01 19:58:12Z alecm $
 __docformat__ = 'restructuredtext'
 
 from Products.CMFCore.utils import UniqueObject, getToolByName
@@ -49,6 +49,7 @@ from Products.CMFCore.MemberDataTool import CleanupTemp
 
 from interfaces.portal_groupdata import portal_groupdata as IGroupDataTool
 from interfaces.portal_groupdata import GroupData as IGroupData
+from Products.GroupUserFolder import postonly
 
 _marker = []  # Create a new marker object.
 
@@ -269,7 +270,7 @@ class GroupData (SimpleItem):
         return False
 
     security.declarePublic('addMember')
-    def addMember(self, id):
+    def addMember(self, id, REQUEST=None):
         """ Add the existing member with the given id to the group"""
         # We check if the current user can directly or indirectly administrate this group
         if not self.canAdministrateGroup():
@@ -281,9 +282,10 @@ class GroupData (SimpleItem):
         member = mtool.getMemberById(id)
         if member:
             member.notifyModified()
+    addMember = postonly(addMember)
 
     security.declarePublic('removeMember')
-    def removeMember(self, id):
+    def removeMember(self, id, REQUEST=None):
         """Remove the member with the provided id from the group.
         """
         # We check if the current user can directly or indirectly administrate this group
@@ -296,6 +298,7 @@ class GroupData (SimpleItem):
         member = mtool.getMemberById(id)
         if member:
             member.notifyModified()
+    removeMember = postonly(removeMember)
 
     security.declareProtected(Permissions.manage_users, 'setProperties')
     def setProperties(self, properties=None, **kw):
