@@ -22,9 +22,9 @@
 """
 Basic usergroup tool.
 """
-__version__ = "$Revision:  $"
+__version__ = "$Revision$"
 # $Source:  $
-# $Id: GroupsTool.py 30098 2006-09-08 12:35:01Z encolpe $
+# $Id: GroupsTool.py 40111 2007-04-01 09:12:57Z alecm $
 __docformat__ = 'restructuredtext'
 
 from Products.CMFCore.utils import UniqueObject
@@ -35,6 +35,7 @@ from Globals import InitializeClass, DTMLFile, MessageDialog
 from Acquisition import aq_base
 from AccessControl.User import nobody
 from AccessControl import ClassSecurityInfo
+from ZODB.POSException import ConflictError
 # BBB CMF < 1.5
 try:
     from Products.CMFCore.permissions import ManagePortal
@@ -45,6 +46,7 @@ except ImportError:
     from Products.CMFCore.CMFCorePermissions import View
     from Products.CMFCore.CMFCorePermissions import ViewManagementScreens
 
+from Products.GroupUserFolder import postonly
 from GroupsToolPermissions import AddGroups
 from GroupsToolPermissions import ManageGroups
 from GroupsToolPermissions import DeleteGroups
@@ -57,7 +59,6 @@ from global_symbols import *
 # Optional feature-preview support
 import PloneFeaturePreview
 
-
 class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
     """ This tool accesses group data through a GRUF acl_users object.
 
@@ -237,7 +238,7 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
         return res
 
     security.declareProtected(AddGroups, 'addGroup')
-    def addGroup(self, id, roles = [], groups = [], *args, **kw):
+    def addGroup(self, id, roles = [], groups = [], REQUEST=None, *args, **kw):
         """Create a group, and a group workspace if the toggle is on, with the supplied id, roles, and domains.
 
         Underlying user folder must support adding users via the usual Zope API.
@@ -247,18 +248,20 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
         self.acl_users.userFolderAddGroup(id, roles = roles, groups = groups )
         self.createGrouparea(id)
         self.getGroupById(id).setProperties(**kw)
+    addGroup = postonly(addGroup)
 
     security.declareProtected(ManageGroups, 'editGroup')
-    def editGroup(self, id, roles = None, groups = None, *args, **kw):
+    def editGroup(self, id, roles = None, groups = None, REQUEST=None, *args, **kw):
         """Edit the given group with the supplied password, roles, and domains.
 
         Underlying user folder must support editing users via the usual Zope API.
         Passwords for groups seem to be currently irrelevant in GRUF."""
         self.acl_users.userFolderEditGroup(id, roles = roles, groups = groups, )
         self.getGroupById(id).setProperties(**kw)
+    editGroup = postonly(editGroup)
 
     security.declareProtected(DeleteGroups, 'removeGroups')
-    def removeGroups(self, ids, keep_workspaces=0):
+    def removeGroups(self, ids, keep_workspaces=0, REQUEST=None):
         """Remove the group in the provided list (if possible).
 
         Will by default remove this group's GroupWorkspace if it exists. You may
@@ -278,9 +281,10 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
             for id in ids:
                 if hasattr(aq_base(gwf), id):
                     gwf._delObject(id)
+    removeGroups = postonly(removeGroups)
 
     security.declareProtected(SetGroupOwnership, 'setGroupOwnership')
-    def setGroupOwnership(self, group, object):
+    def setGroupOwnership(self, group, object, REQUEST=None):
         """Make the object 'object' owned by group 'group' (a portal_groupdata-ish object).
 
         For GRUF this is easy. Others may have to re-implement."""
@@ -289,6 +293,7 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
             raise ValueError, "Invalid group: '%s'." % (group, )
         object.changeOwnership(user)
         object.manage_setLocalRoles(user.getId(), ['Owner'])
+    setGroupOwnership = postonly(setGroupOwnership)
 
     security.declareProtected(ManagePortal, 'setGroupWorkspacesFolder')
     def setGroupWorkspacesFolder(self, id="", title=""):
@@ -478,16 +483,12 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
                 #log("wrapping group %s" % g)
                 portal_group = gd.wrapGroup(g)
                 return portal_group
-
+            except ConflictError:
+                raise
             except:
-                from zLOG import LOG, ERROR
-                import sys
-                type,value,tb = sys.exc_info()
-                try:
-                    LOG('GroupsTool', ERROR, 'Error during wrapGroup:', "\nType:%s\nValue:%s\n" % (type,value))
-                finally:
-                    tb = None       # Avoid leaking frame
-                pass
+                import logging
+                logger = logging.getLogger('GroupUserFolder.GroupsTool')
+                logger.exception('Error during wrapGroup')
         # Failed.
         return g
 
