@@ -20,7 +20,7 @@
 """
 __version__ = "$Revision:  $"
 # $Source:  $
-# $Id: testGroupUserFolderAPI.py 30098 2006-09-08 12:35:01Z encolpe $
+# $Id: testGroupUserFolderAPI.py 34723 2006-12-15 11:25:30Z encolpe $
 __docformat__ = 'restructuredtext'
 
 import os, sys
@@ -771,9 +771,6 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
             )
 
     # Groups support
-    def test_setMembers(self):
-        """Set the members of the group
-        """
 
     def test_getMemberIds(self,):
         should_be = [
@@ -829,13 +826,29 @@ class TestGroupUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterf
 
     def test_removeMember(self):
         """Remove a member from a group
-        """    
+        """
         self.failUnless("u1" not in self.gruf.getMemberIds("ng3"))
         self.gruf.addMember("ng3", "u1")
         self.failUnless("u1" in self.gruf.getMemberIds("ng3"))
         self.gruf.removeMember("ng3", "u1")
         self.failUnless("u1" not in self.gruf.getMemberIds("ng3"))
 
+    def test_setMembers(self):
+        """Set the members of the group
+        """
+        member_ids = self.gruf.getMemberIds("ng3")
+        self.gruf.addMember("ng3", "u1")
+        self.gruf.addMember("ng3", "u2")
+        self.failIf("u1" not in self.gruf.getMemberIds("ng3"))
+        self.failIf("u2" not in self.gruf.getMemberIds("ng3"))
+        self.failIf("u3" in self.gruf.getMemberIds("ng3"))
+
+        self.gruf.setMembers("ng3", (member_ids + ["u2", "u3"]))
+
+        self.failIf("u1" in self.gruf.getMemberIds("ng3"))
+        self.failIf("u2" not in self.gruf.getMemberIds("ng3"))
+        self.failIf("u3" not in self.gruf.getMemberIds("ng3"))
+
     def test_hasMember(self,):
         self.failUnless(not self.gruf.hasMember("ng3", "u1"))
         self.failUnless(not self.gruf.hasMember("group_ng3", "u1"))
