@@ -20,7 +20,7 @@
 """
 __version__ = "$Revision:  $"
 # $Source:  $
-# $Id: testUserAPI.py 30098 2006-09-08 12:35:01Z encolpe $
+# $Id: testUserAPI.py 35844 2007-01-17 10:45:00Z encolpe $
 __docformat__ = 'restructuredtext'
 
 
@@ -534,6 +534,23 @@ class TestUserFolderAPI(GRUFTestCase.GRUFTestCase, testInterface.TestInterface):
         g.removeMember("u1")
         self.failUnless("u1" not in g.getMemberIds())
 
+        ## remove a group in a group
+        # ng5 is in g2 and we add g3 in ng5
+        g2 = self.gruf.getGroup("g2")
+        ng5 = self.gruf.getGroup("ng5")
+
+        self.failUnless("group_ng1" not in ng5.getMemberIds())
+        self.failUnless("group_ng1" not in g2.getMemberIds())
+        ng5.addMember("ng1")
+
+        self.failUnless("group_ng1" in ng5.getMemberIds())
+        self.failUnless("group_ng1" in g2.getMemberIds())
+        ng5.removeMember("ng1")
+
+        self.failUnless("group_ng1" not in ng5.getMemberIds())
+        self.failUnless("group_ng1" not in g2.getMemberIds())
+
+
     def test_getProperty(self,):
         """Will raise for regular user folders
         """
