@@ -16,6 +16,7 @@ from Products.CMFCore.utils import UniqueObject, getToolByName
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from ZPublisher import BeforeTraverse
 from ZPublisher.HTTPRequest import HTTPRequest
+from tldmap import tld_to_language
 
 try:
     from Products.CMFPlone.interfaces.Translatable import ITranslatable
@@ -28,8 +29,12 @@ try:
 except ImportError:
     _hasPTS = 0
 
+import logging
+logger = logging.getLogger('PloneLanguageTool')
+
 import availablelanguages
 
+
 class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
     """Language Administration Tool For Plone."""
 
@@ -46,6 +51,7 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
     use_path_negotiation = 1
     use_cookie_negotiation = 1
     use_request_negotiation = 1
+    use_cctld_negotiation = 0
     use_combined_language_codes = 0
     display_flags = 1
     start_neutral = 1
@@ -75,6 +81,7 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
         self.use_path_negotiation = 1
         self.use_cookie_negotiation  = 1
         self.use_request_negotiation = 1
+        self.use_cctld_negotiation = 0
         self.force_language_urls = 1
         self.allow_content_language_fallback = 0
         self.display_flags = 1
@@ -98,6 +105,7 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
                                    setAllowContentLanguageFallback=None,
                                    setUseCombinedLanguageCodes=None,
                                    displayFlags=None, startNeutral=None,
+                                   setCcTLDN=None,
                                    REQUEST=None):
         """Stores the tool settings."""
         if supportedLanguages and type(supportedLanguages) == type([]):
@@ -123,6 +131,11 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
         else:
             self.use_path_negotiation = 0
 
+        if setCcTLDN:
+            self.use_cctld_negotiation = 1
+        else:
+            self.use_cctld_negotiation = 0
+
         if setForcelanguageUrls:
             self.force_language_urls = 1
         else:
@@ -253,12 +266,16 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
 
         This can override predefined ones.
         """
+        logger.log(logging.WARNING, 'Deprecation Warning: The addLanguage '
+            'method is deprecated and will be removed in PLT 2.0.')
         self.local_available_langs[langCode] = langDescription
         self._p_changed = 1
 
     security.declareProtected(ManagePortal, 'removeLanguage')
     def removeLanguage(self, langCode):
         """Removes a custom language from the tool."""
+        logger.log(logging.WARNING, 'Deprecation Warning: The removeLanguage '
+            'method is deprecated and will be removed in PLT 2.0.')
         if langCode in self.local_available_langs:
             del self.local_available_langs[langCode]
             self._p_changed = 1
@@ -320,6 +337,10 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
         """Gets the preferred site language."""
         l = self.getLanguageBindings()
         if l[0]:
+            if not self.use_combined_language_codes:
+                return l[0].split('-')[0]
+            else:
+                return l[0]
             return l[0]
         # this is the default language
         return l[1]
@@ -352,12 +373,25 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
             pass
         return None
 
+    security.declareProtected(View, 'getCcTLDLanguages')
+    def getCcTLDLanguages(self):
+        if not hasattr(self, 'REQUEST'):
+            return None
+        request = self.REQUEST
+        if not "HTTP_HOST" in request:
+            return None
+        host=request["HTTP_HOST"].split(":")[0].lower()
+        tld=host.split(".")[-1]
+        wanted = tld_to_language.get(tld, [])
+        allowed = self.getSupportedLanguages()
+        return [lang for lang in wanted if lang in allowed]
+
     security.declareProtected(View, 'getRequestLanguages')
     def getRequestLanguages(self):
         """Parses the request and return language list."""
 
         if not hasattr(self, 'REQUEST'):
-            return []
+            return None
 
         # Get browser accept languages
         browser_pref_langs = self.REQUEST.get('HTTP_ACCEPT_LANGUAGE', '')
@@ -399,8 +433,9 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
                     # if we only use simply language codes, we should recognize
                     # combined codes as their base code. So 'de-de' is treated
                     # as 'de'.
-                    if language.split('-')[0] in self.getSupportedLanguages():
-                        langs.append((quality, language))
+                    baselanguage = language.split('-')[0]
+                    if baselanguage in self.getSupportedLanguages():
+                        langs.append((quality, baselanguage))
                 i = i + 1
 
         # Sort and reverse it
@@ -415,6 +450,7 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
     security.declareProtected(View, 'setLanguageBindings')
     def setLanguageBindings(self):
         """Setups the current language stuff."""
+        useCcTLD = self.use_cctld_negotiation
         usePath = self.use_path_negotiation
         useCookie = self.use_cookie_negotiation
         useRequest = self.use_request_negotiation
@@ -426,7 +462,7 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
             # Create new binding instance
             binding = LanguageBinding(self)
         # Bind languages
-        lang = binding.setLanguageBindings(usePath, useCookie, useRequest, useDefault)
+        lang = binding.setLanguageBindings(usePath, useCookie, useRequest, useDefault, useCcTLD)
         # Set LANGUAGE to request
         self.REQUEST['LANGUAGE'] = lang
         # Set bindings instance to request
@@ -480,12 +516,16 @@ class LanguageTool(UniqueObject, ActionProviderBase, SimpleItem):
 
         This can override predefined ones.
         """
+        logger.log(logging.WARNING, 'Deprecation Warning: The addCountry '
+            'method is deprecated and will be removed in PLT 2.0.')
         self.local_available_countries[countryCode] = countryDescription
         self._p_changed = 1
 
     security.declareProtected(ManagePortal, 'removeCountry')
     def removeCountry(self, countryCode):
         """Removes a custom country from the tool."""
+        logger.log(logging.WARNING, 'Deprecation Warning: The removeCountry '
+            'method is deprecated and will be removed in PLT 2.0.')
         if countryCode in self.local_available_countries:
             del self.local_available_countries[countryCode]
             self._p_changed = 1
@@ -504,14 +544,15 @@ class LanguageBinding:
         self.tool = tool
 
     security.declarePrivate('setLanguageBindings')
-    def setLanguageBindings(self, usePath=1, useCookie=1, useRequest=1, useDefault=1):
+    def setLanguageBindings(self, usePath=1, useCookie=1, useRequest=1, useDefault=1, useCcTLD=0):
         """Setup the current language stuff."""
         langs = []
 
         if usePath:
             # This one is set if there is an allowed language in the current path
             langsPath = [self.tool.getPathLanguage()]
-        else:langsPath = []
+        else:
+            langsPath = []
 
         if useCookie:
             # If we are using the cookie stuff we provide the setter here
@@ -521,7 +562,13 @@ class LanguageBinding:
             else:
                 # Get from cookie
                 langsCookie = [self.tool.getLanguageCookie()]
-        else: langsCookie = []
+        else:
+            langsCookie = []
+
+        if useCcTLD:
+            langsCcTLD = self.tool.getCcTLDLanguages()
+        else:
+            langsCcTLD = []
 
         # Get langs from request
         if useRequest:
@@ -536,10 +583,10 @@ class LanguageBinding:
             langsDefault = []
 
         # Build list
-        langs = langsPath + langsCookie + langsRequest + langsDefault
+        langs = langsPath+langsCookie+langsCcTLD+langsRequest+langsDefault
 
         # Filter None languages
-        langs = filter(lambda x: x is not None, langs)
+        langs = [lang for lang in langs if lang is not None]
 
         self.DEFAULT_LANGUAGE = langs[-1]
         self.LANGUAGE = langs[0]
