@@ -48,6 +48,10 @@ def getCountries():
 # This is a dictionary of dictonaries:
 #
 # 'langcode-variation' : {native : 'Native name', english : 'English name', flag : 'flag-*.gif'}
+#
+# The current structure is to have language codes following ISO639-1 and to
+# have flags which are named according to country codes following ISO3166-1.
+#
 
 languages = {
 'aa' : {'native' : 'магIарул мацI', 'english' : 'Afar', 'flag' : 'flag-dj.gif'},
@@ -62,12 +66,13 @@ languages = {
 'be' : {'native' : 'Беларускі', 'english' : 'Belarussian', 'flag' : 'flag-by.gif'},
 'bg' : {'native' : 'Български', 'english' : 'Bulgarian', 'flag' : 'flag-bg.gif'},
 'bh' : {'native' : 'Bihari', 'english' : 'Bihari'},
-'bi' : {'native' : 'Bislama', 'english' : 'Bislama'},
+'bi' : {'native' : 'Bislama', 'english' : 'Bislama', 'flag' : 'flag-vu.gif'},
 'bn' : {'native' : 'বাংলা', 'english' : 'Bengali'},
 'bo' : {'native' : 'བོད་སྐད་', 'english' : 'Tibetan'},
 'bs' : {'native' : 'Bosanski', 'english' : 'Bosnian', 'flag' : 'flag-ba.gif'},
 'br' : {'native' : 'Brezhoneg', 'english' : 'Breton'},
 'ca' : {'native' : 'Català', 'english' : 'Catalan', 'flag' : 'flag-cat.gif'},
+'ch' : {'native' : 'Chamoru', 'english' : 'Chamorro'},
 'co' : {'native' : 'Corsu', 'english' : 'Corsican'},
 'cs' : {'native' : 'Čeština', 'english' : 'Czech', 'flag' : 'flag-cz.gif'},
 'cy' : {'native' : 'Cymraeg', 'english' : 'Welsh', 'flag' : 'flag-cym.gif'},
@@ -148,7 +153,7 @@ languages = {
 'ps' : {'native' : 'پښتو', 'english' : 'Pashto'},
 'pt' : {'native' : 'Português', 'english' : 'Portuguese', 'flag' : 'flag-pt.gif'},
 'qu' : {'native' : 'Quechua', 'english' : 'Quechua'},
-'rm' : {'native' : 'Rhaeto-Romance', 'english' : ''},
+'rm' : {'native' : 'Rumantsch', 'english' : 'Rhaeto-Romance'},
 'rn' : {'native' : 'Kirundi', 'english' : 'Kirundi'},
 'ro' : {'native' : 'Română', 'english' : 'Romanian', 'flag' : 'flag-ro.gif'},
 'ru' : {'native' : 'Русский', 'english' : 'Russian', 'flag' : 'flag-ru.gif'},
