@@ -15,19 +15,11 @@ from OFS.SimpleItem import Item
 
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 
-# BBB CMF < 1.5
-try:
-    from Products.CMFCore.permissions import ManagePortal, View
-except ImportError:
-    from Products.CMFCore.CMFCorePermissions import ManagePortal, View
-
 from Products.CMFCore.ActionProviderBase import ActionProviderBase
+from Products.CMFCore.permissions import ManagePortal, View
 from Products.CMFCore.utils import UniqueObject
 from Products.CMFCore.utils import getToolByName
 
-from Products.PortalTransforms.utils import log
-from Products.PortalTransforms.utils import _www
-from Products.PortalTransforms.utils import TransformException
 from Products.PortalTransforms.libtransforms.utils import MissingBinary
 from Products.PortalTransforms import transforms
 from Products.PortalTransforms.interfaces import iengine
@@ -41,20 +33,11 @@ from Products.PortalTransforms.Transform import Transform
 from Products.PortalTransforms.utils import log
 from Products.PortalTransforms.utils import TransformException
 from Products.PortalTransforms.utils import BadRequest
+from Products.PortalTransforms.utils import _www
 
+__revision__ = '$Id: TransformEngine.py 7305 2006-12-29 22:08:43Z tomster $'
 
-__revision__ = '$Id: TransformEngine.py 5329 2005-12-23 14:07:10Z raphael_ritz $'
-
-# Some LOG levels
-BLATHER=-100
-DEBUG=-200
-TRACE=-300
-
-try:
-    True
-except:
-    True=1
-    False=0
+from logging import DEBUG
 
 class TransformTool(UniqueObject, ActionProviderBase, Folder):
 
@@ -151,7 +134,7 @@ class TransformTool(UniqueObject, ActionProviderBase, Folder):
         orig_mt = str(orig_mt)
         if not orig_mt:
             log('Unable to guess input mime type (filename=%s, mimetype=%s)' %(
-                kwargs.get('mimetype'), kwargs.get('filename')), severity=BLATHER)
+                kwargs.get('mimetype'), kwargs.get('filename')), severity=DEBUG)
             return None
 
         target_mt = registry.lookup(target_mimetype)
@@ -159,7 +142,7 @@ class TransformTool(UniqueObject, ActionProviderBase, Folder):
             target_mt = target_mt[0]
         else:
             log('Unable to match target mime type %s'% str(target_mimetype),
-                severity=BLATHER)
+                severity=DEBUG)
             return None
 
         ## fastpath
@@ -181,7 +164,7 @@ class TransformTool(UniqueObject, ActionProviderBase, Folder):
         path = self._findPath(orig_mt, target_mt, list(requirements))
         if not path and requirements:
             log('Unable to satisfy requirements %s' % ', '.join(requirements),
-                severity=BLATHER)
+                severity=DEBUG)
             path = self._findPath(orig_mt, target_mt)
 
         if not path:
@@ -189,23 +172,6 @@ class TransformTool(UniqueObject, ActionProviderBase, Folder):
                 severity=DEBUG)
             return None #XXX raise TransformError
 
-##        if len(path) > 1 and filter_only:
-##            log('NO FILTER FOR %s' % (orig_mt,), severity=DEBUG)
-##            # Found a path, but we have
-##            # orig_mt and target_mt the same, thus only
-##            # allow filtering (one-hop transforms where
-##            # source and target are the same).
-##            # Skip transform completely.
-##            data.setData(orig)
-##            md = data.getMetadata()
-##            md['mimetype'] = str(orig_mt)
-##            if object is not None:
-##                cache.setCache(str(target_mimetype), data)
-##                return data
-
-        log('PATH FROM %s TO %s : %s' % (orig_mt, target_mimetype, path),
-            severity=TRACE)
-
         if len(path) > 1:
             ## create a chain on the fly (sly)
             transform = chain()
@@ -346,7 +312,7 @@ class TransformTool(UniqueObject, ActionProviderBase, Folder):
                         else:
                             log('Can\'t find transform %s from %s to %s' % (
                                 transform.name(), mti, mt),
-                                severity=BLATHER)
+                                severity=DEBUG)
 
     def _findPath(self, orig, target, required_transforms=()):
         """return the shortest path for transformation from orig mimetype to
@@ -533,4 +499,17 @@ class TransformTool(UniqueObject, ActionProviderBase, Folder):
             log('objectItems: catched MissingBinary exception')
             return []
 
+    # available mimetypes ####################################################
+    def listAvailableTextInputs(self):
+        """ Returns a list of mimetypes that can be used as input for textfields
+            by building a list of the inputs beginning with "text/" of all transforms.
+        """
+        available_types = []
+        candidate_transforms = [object[1] for object in self.objectItems()]
+        for candidate in candidate_transforms:
+            for input in candidate.inputs:
+                if input.startswith("text/") and input not in available_types:
+                    available_types.append(input)
+        return available_types
+
 InitializeClass(TransformTool)
