@@ -30,7 +30,7 @@ def initialize(context):
     #registerDirectory(skins_dir, GLOBALS)
 
     from Products.CMFCore import utils
-    utils.ToolInit("%s Tool" % PKG_NAME, tools=tools,
-                   product_name=PKG_NAME,
+    utils.ToolInit("%s Tool" % PKG_NAME, 
+                   tools=tools,
                    icon="tool.gif",
                    ).initialize(context)
