@@ -1,5 +1,6 @@
 """some common utilities
 """
+import logging
 from time import time
 from types import UnicodeType, StringType
 
@@ -11,9 +12,10 @@ class TransformException(Exception):
 FB_REGISTRY = None
 
 # logging function
-from zLOG import LOG, INFO
-def log(msg, severity=INFO, id='PortalTransforms'):
-    LOG(id, severity, msg)
+logger = logging.getLogger('PortalTransforms')
+
+def log(message, severity=logging.INFO):
+    logger.log(severity, message)
 
 # directory where template for the ZMI are located
 import os.path
@@ -25,5 +27,13 @@ from zExceptions import BadRequest
 # directory where template for the ZMI are located
 import os.path
 _www = os.path.join(os.path.dirname(__file__), 'www')
-#skins_dir = os.path.join(os.path.dirname(__file__), 'skins')
 skins_dir = None
+
+def safeToInt(value):
+    """Convert value to integer or just return 0 if we can't"""
+    try:
+        return int(value)
+    except ValueError:
+        return 0
+    except TypeError:
+        return 0
