@@ -7,8 +7,6 @@ if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 from textwrap import dedent
 
-from Testing import ZopeTestCase
-
 from App.Common import rfc1123_date
 from DateTime import DateTime
 from zExceptions import NotFound
@@ -17,18 +15,15 @@ from Interface.Verify import verifyObject
 
 from Products.CMFCore.utils import getToolByName
 
-from Products.PloneTestCase.PloneTestCase import PLONE21
+from Products.PloneTestCase.PloneTestCase import PLONE21, portal_owner, default_password
 
 from Products.ResourceRegistries.config import JSTOOLNAME
 from Products.ResourceRegistries.interfaces import IJSRegistry
-from Products.ResourceRegistries.tests import CSSRegistryTestCase
-try:
-    from Products.ResourceRegistries.tests.five_tests_base import FiveTestsBase
-except ImportError:
-    FiveTestsBase = None
+from Products.ResourceRegistries.tests.RegistryTestCase import RegistryTestCase
+from Products.ResourceRegistries.tests.RegistryTestCase import FunctionalRegistryTestCase
+from Products.ResourceRegistries.tools.packer import test_suite as packer_tests
 
-
-class TestJSImplementation(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestJSImplementation(RegistryTestCase):
 
     def test_interfaces(self):
         tool = getattr(self.portal, JSTOOLNAME)
@@ -36,7 +31,7 @@ class TestJSImplementation(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless(verifyObject(IJSRegistry, tool))
 
 
-class TestJSTool(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestJSTool(RegistryTestCase):
 
     def testToolExists(self):
         self.failUnless(JSTOOLNAME in self.portal.objectIds())
@@ -48,7 +43,7 @@ class TestJSTool(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless(tool.manage_jsComposition())
 
 
-class TestJSSkin(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestJSSkin(RegistryTestCase):
 
     def testSkins(self):
         skins = self.portal.portal_skins.objectIds()
@@ -58,7 +53,7 @@ class TestJSSkin(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless(getattr(self.portal, 'renderAllTheScripts'))
 
 
-class testJSZMIMethods(CSSRegistryTestCase.CSSRegistryTestCase):
+class testJSZMIMethods(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -70,7 +65,7 @@ class testJSZMIMethods(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless(self.tool.getResources())
 
 
-class TestJSScriptRegistration(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestJSScriptRegistration(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -97,7 +92,7 @@ class TestJSScriptRegistration(CSSRegistryTestCase.CSSRegistryTestCase):
         self.assertEqual(len(self.tool.getResources()), 0)
 
 
-class TestJSScriptRenaming(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestJSScriptRenaming(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -129,7 +124,7 @@ class TestJSScriptRenaming(CSSRegistryTestCase.CSSRegistryTestCase):
         self.assertRaises(ValueError, self.tool.renameResource, 'spam', 'bacon')
 
 
-class TestJSToolSecurity(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestJSToolSecurity(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -148,7 +143,7 @@ class TestJSToolSecurity(CSSRegistryTestCase.CSSRegistryTestCase):
             self.fail()
 
 
-class TestJSToolExpression(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestJSToolExpression(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -172,7 +167,7 @@ class TestJSToolExpression(CSSRegistryTestCase.CSSRegistryTestCase):
                         'python:"eggs" in object.objectIds()', context))
 
 
-class TestJSScriptCooking(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestJSScriptCooking(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -275,7 +270,7 @@ class TestJSScriptCooking(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless('background-color' in renderedpage)
 
 
-class TestScriptMoving(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestScriptMoving(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -385,7 +380,7 @@ class TestScriptMoving(CSSRegistryTestCase.CSSRegistryTestCase):
         self.assertEqual(self.tool.getResourceIds(),
                          ('bacon', 'spam', 'eggs', 'ham'))
 
-class TestJSTraversal(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestJSTraversal(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -422,17 +417,15 @@ class TestJSTraversal(CSSRegistryTestCase.CSSRegistryTestCase):
         content = str(self.portal.restrictedTraverse('portal_javascripts/%s' % magicId))
 
 
-class TestPublishing(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestPublishing(FunctionalRegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
         self.tool.clearResources()
         self.toolpath = '/' + self.tool.absolute_url(1)
-        self.portalpath = '/' + getToolByName(self.portal, 'portal_url')(1)
+        self.folderpath = '/' + self.folder.absolute_url(1)
         self.tool.registerScript('test_rr_1.js')
-        self.setRoles(['Manager'])
-        self.portal.invokeFactory('Document', 'index_html')
-        self.setRoles(['Member'])
+        self.folder.invokeFactory('Document', 'index_html')
 
     def testPublishJSThroughTool(self):
         response = self.publish(self.toolpath + '/test_rr_1.js')
@@ -442,7 +435,7 @@ class TestPublishing(CSSRegistryTestCase.CSSRegistryTestCase):
     def testPublishNonMagicJSThroughTool(self):
         self.setRoles(['Manager'])
         body = """<dtml-var "'joined' + 'string'">"""
-        self.portal.addDTMLMethod('testmethod', file=body)
+        self.folder.addDTMLMethod('testmethod', file=body)
         self.tool.registerScript('testmethod')
         response = self.publish(self.toolpath + '/testmethod')
         self.assertEqual(response.getStatus(), 200)
@@ -450,14 +443,14 @@ class TestPublishing(CSSRegistryTestCase.CSSRegistryTestCase):
 
     def testPublishPageWithInlineJS(self):
         # This one fails from string/utf-8 concatenation
-        response = self.publish(self.portalpath)
+        response = self.publish(self.folderpath)
         self.assertEqual(response.getStatus(), 200)
         self.assertEqual(response.getHeader('Content-Type'),
                          'text/html;charset=utf-8')
         self.tool.clearResources()
         self.tool.registerScript('test_rr_1.js', inline=True)
         # Test that the main page retains its content-type
-        response = self.publish(self.portalpath)
+        response = self.publish(self.folderpath)
         self.assertEqual(response.getHeader('Content-Type'),
                          'text/html;charset=utf-8')
         self.assertEqual(response.getStatus(), 200)
@@ -467,49 +460,37 @@ class TestPublishing(CSSRegistryTestCase.CSSRegistryTestCase):
         # Test that the main page retains its content-type
         self.setRoles(['Manager'])
         body = """<dtml-call "REQUEST.RESPONSE.setHeader('Content-Type', 'text/javascript')">/*and some js comments too*/ """
-        self.portal.addDTMLMethod('testmethod', file=body)
+        self.folder.addDTMLMethod('testmethod', file=body)
         self.tool.registerScript('testmethod', inline=True)
-        response = self.publish(self.portalpath)
+        response = self.publish(self.folderpath)
         self.assertEqual(response.getHeader('Content-Type'),
                          'text/html;charset=utf-8')
         self.assertEqual(response.getStatus(), 200)
 
+class TestFivePublishing(FunctionalRegistryTestCase):
+    'Publishing with Five'
 
-if FiveTestsBase is not None:
-    class TestFivePublishing(CSSRegistryTestCase.CSSRegistryTestCase, FiveTestsBase):
-        'Publishing with Five'
+    def afterSetUp(self):
+        # Define some resource
+        from Products.Five.zcml import load_config
+        import Products.ResourceRegistries.tests
+        load_config('test.zcml', Products.ResourceRegistries.tests)
+        self.tool = getattr(self.portal, JSTOOLNAME)
+        self.tool.clearResources()
+        self.tool.registerScript('++resource++test_rr_1.js')
+        self.toolpath = '/' + self.tool.absolute_url(1)
+        self.portalpath = '/' + getToolByName(self.portal, 'portal_url')(1)
+        self.setRoles(['Manager'])
+        self.portal.invokeFactory('Document', 'index_html')
+        self.setRoles(['Member'])
 
-        def afterSetUp(self):
-            FiveTestsBase.afterSetUp(self)
-            # Define some resource
-            from Products.Five.zcml import load_string, load_config
-            load_string(dedent('''\
-                        <configure xmlns="http://namespaces.zope.org/zope"
-                               xmlns:browser="http://namespaces.zope.org/browser"
-                               xmlns:five="http://namespaces.zope.org/five">
-                            <browser:resource
-                                       name="test_rr_1.js"
-                                       file="test_rr_1.js"
-                              />
-                        </configure>'''))
-            #
-            self.tool = getattr(self.portal, JSTOOLNAME)
-            self.tool.clearResources()
-            self.tool.registerScript('++resource++test_rr_1.js')
-            self.toolpath = '/' + self.tool.absolute_url(1)
-            self.portalpath = '/' + getToolByName(self.portal, 'portal_url')(1)
-            self.setRoles(['Manager'])
-            self.portal.invokeFactory('Document', 'index_html')
-            self.setRoles(['Member'])
+    def testPublishFiveResource(self):
+        response = self.publish(self.toolpath + '/++resource++test_rr_1.js')
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Content-Type')[:24], 'application/x-javascript')
+        self.assertEqual("window.alert('running')" in response.getBody(), True)
 
-        def testPublishFiveResource(self):
-            response = self.publish(self.toolpath + '/++resource++test_rr_1.js')
-            self.assertEqual(response.getStatus(), 200)
-            self.assertEqual(response.getHeader('Content-Type')[:24], 'application/x-javascript')
-            self.assertEqual("window.alert('running')" in response.getBody(), True)
-
-
-class TestDebugMode(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestDebugMode(FunctionalRegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -546,54 +527,7 @@ class TestDebugMode(CSSRegistryTestCase.CSSRegistryTestCase):
         self.assertEqual(response.getHeader('Cache-Control'), 'max-age=0')
 
 
-class TestJSDefaults(CSSRegistryTestCase.CSSRegistryTestCase):
-
-    # These do not run for plone 2.1 +
-
-    def afterSetUp(self):
-        self.tool = getattr(self.portal, JSTOOLNAME)
-
-    def testClearingScripts(self):
-        self.failUnless(self.tool.getResources())
-        self.tool.clearResources()
-        self.failIf(self.tool.getResources())
-
-    def testDefaultsInstall(self):
-        scriptids = self.tool.getResourceIds()
-        self.failUnless('plone_menu.js' in scriptids)
-        self.failUnless('plone_javascript_variables.js' in scriptids)
-        self.failUnless('test_rr_1.js' in scriptids)
-
-    def testTraverseToConcatenatedDefaults(self):
-        scripts = self.tool.getEvaluatedResources(self.portal)
-        for s in scripts:
-            try:
-                magic = s.getId()
-                self.portal.restrictedTraverse('portal_javascripts/%s' % magic)
-            except KeyError:
-                self.fail()
-
-    def testUserConditionOnMenuScript(self):
-        scripts1 = self.tool.getEvaluatedResources(self.portal)
-        self.logout()
-        scripts2 = self.tool.getEvaluatedResources(self.portal)
-        self.failUnless(len(scripts1) > len(scripts2))
-
-    def testCallingOfConcatenatedScripts(self):
-        stylesheets = self.tool.getEvaluatedResources(self.portal)
-        for s in stylesheets:
-            if 'ploneScripts' in s.getId():
-                output = self.portal.restrictedTraverse(
-                             'portal_javascripts/%s' % s.getId())
-                break
-        if not output:
-            self.fail()
-        o = str(output)[:]
-        self.failIf('&lt;dtml-call' in o)
-        self.failIf('&amp;dtml' in o)
-        self.failUnless('portal_url' in o)
-
-class TestZODBTraversal(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestZODBTraversal(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -668,7 +602,7 @@ class TestZODBTraversal(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless('purple' in content)
         self.failIf('pink' in content)
 
-class TestResourcePermissions(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestResourcePermissions(FunctionalRegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -760,13 +694,11 @@ class TestResourcePermissions(CSSRegistryTestCase.CSSRegistryTestCase):
             self.fail()
 
     def testAuthorizedOnPublish(self):
-        # FIXME - As a manager this should be accessible, but the test doesn't work
-        # when tested by hand in the browser, it does work as expected
-        self.setRoles(['Manager'])
-        response = self.publish(self.toolpath + '/testroot.js')
+        authstr = "%s:%s" % (portal_owner, default_password)
+        response = self.publish(self.toolpath + '/testroot.js', basic=authstr)
         self.failUnlessEqual(response.getStatus(), 200)
 
-class TestMergingDisabled(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestMergingDisabled(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
@@ -898,63 +830,104 @@ class TestMergingDisabled(CSSRegistryTestCase.CSSRegistryTestCase):
         content = str(self.portal.restrictedTraverse('portal_javascripts/simple2.js'))
         self.failUnless('blue' in content)
 
-class TestJSCompression(CSSRegistryTestCase.CSSRegistryTestCase):
+
+class TestCachingHeaders(FunctionalRegistryTestCase):
     def afterSetUp(self):
         self.tool = getattr(self.portal, JSTOOLNAME)
+        self.skins_tool = getToolByName(self.portal, 'portal_skins')
+        self.tool.clearResources()
+        self.portalpath = '/' + getToolByName(self.portal, 'portal_url')(1)
+        self.toolpath = '/' + self.tool.absolute_url(1)
 
-    def testCompression(self):
-        input = """
-/* a comment */
+    def testCachingHeadersFromTool(self):
+        self.tool.registerScript('ham')
+        # Publish
+        response = self.publish(self.toolpath+'/ham')
+        now = DateTime()
+        days = 7
+        soon = now + days
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Expires'), rfc1123_date(soon.timeTime()))
+        self.assertEqual(response.getHeader('Cache-Control'), 'max-age=%d' % int(days*24*3600))
 
-function dummy() {
+        # Publish again
+        response = self.publish(self.toolpath+'/ham')
+        now = DateTime()
+        days = 7
+        soon = now + days
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Expires'), rfc1123_date(soon.timeTime()))
+        self.assertEqual(response.getHeader('Cache-Control'), 'max-age=%d' % int(days*24*3600))
 
-    var localvar = 10 // one line comment
+    def testCachingHeadersFromSkin(self):
+        self.tool.registerScript('ham')
+        # Publish in normal mode
+        skinpath = self.skins_tool.getDefaultSkin()
+        url = '%s/%s/ham' % (self.toolpath, skinpath)
+        response = self.publish(url)
+        now = DateTime()
+        days = 7
+        soon = now + days
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Expires'), rfc1123_date(soon.timeTime()))
+        self.assertEqual(response.getHeader('Cache-Control'), 'max-age=%d' % int(days*24*3600))
 
-    document.write(localvar);
-    return 'bar'
-}
-"""
-        expected = """function dummy(){var localvar=10
-document.write(localvar);return 'bar'}
-"""
-        got = self.tool._compressJS(input, 'safe')
-        self.assertEqual(got, expected)
+        # Publish again
+        response = self.publish(url)
+        now = DateTime()
+        days = 7
+        soon = now + days
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Expires'), rfc1123_date(soon.timeTime()))
+        self.assertEqual(response.getHeader('Cache-Control'), 'max-age=%d' % int(days*24*3600))
 
-    def testStringProtection(self):
-        input = """
-var leafnode = this.shared.xmldata.selectSingleNode('//*[@selected]');
-var portal_url = 'http://127.0.0.1:9080/plone';
-"""
-        expected = """var leafnode=this.shared.xmldata.selectSingleNode('//*[@selected]');var portal_url='http://127.0.0.1:9080/plone';"""
-        got = self.tool._compressJS(input, 'safe')
-        self.assertEqual(got, expected)
+    def testCachingHeadersFromToolWithRAMCache(self):
+        ram_cache_id = 'RAMCache'
+        self.tool.ZCacheable_setManagerId(ram_cache_id)
+        self.tool.ZCacheable_setEnabled(1)
+        self.tool.registerScript('ham')
+        # Publish
+        response = self.publish(self.toolpath+'/ham')
+        now = DateTime()
+        days = 7
+        soon = now + days
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Expires'), rfc1123_date(soon.timeTime()))
+        self.assertEqual(response.getHeader('Cache-Control'), 'max-age=%d' % int(days*24*3600))
 
-    def testNewlinesInStrings(self):
-        input = r"""var message = "foo: " + foo + "\nbar: " + bar;"""
-        expected = r"""var message="foo: "+foo+"\nbar: "+bar;"""
-        got = self.tool._compressJS(input, 'safe')
-        self.assertEqual(got, expected)
+        # Publish again
+        response = self.publish(self.toolpath+'/ham')
+        now = DateTime()
+        days = 7
+        soon = now + days
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Expires'), rfc1123_date(soon.timeTime()))
+        self.assertEqual(response.getHeader('Cache-Control'), 'max-age=%d' % int(days*24*3600))
 
-    def testEscapedStrings(self):
-        input = r"""var message = "foo: \"something in quotes\"" + foo + "\nbar: " + bar;"""
-        expected = r"""var message="foo: \"something in quotes\""+foo+"\nbar: "+bar;"""
-        got = self.tool._compressJS(input, 'safe')
-        self.assertEqual(got, expected)
+    def testCachingHeadersFromSkinWithRAMCache(self):
+        ram_cache_id = 'RAMCache'
+        self.tool.ZCacheable_setManagerId(ram_cache_id)
+        self.tool.ZCacheable_setEnabled(1)
+        self.tool.registerScript('ham')
+        # Publish in normal mode
+        skinpath = self.skins_tool.getDefaultSkin()
+        url = '%s/%s/ham' % (self.toolpath, skinpath)
+        response = self.publish(url)
+        now = DateTime()
+        days = 7
+        soon = now + days
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Expires'), rfc1123_date(soon.timeTime()))
+        self.assertEqual(response.getHeader('Cache-Control'), 'max-age=%d' % int(days*24*3600))
 
-    def testWhitspaceAroundPlusMinus(self):
-        input = r"""var message = foo + bar;
-message = foo++ + bar;
-message = foo + ++bar;"""
-        expected = r"""var message=foo+bar;message=foo++ +bar;message=foo+ ++bar;"""
-        got = self.tool._compressJS(input, 'safe')
-        self.assertEqual(got, expected)
-
-        input = r"""var message = foo - bar;
-message = foo-- - bar;
-message = foo - --bar;"""
-        expected = r"""var message=foo-bar;message=foo-- -bar;message=foo- --bar;"""
-        got = self.tool._compressJS(input, 'safe')
-        self.assertEqual(got, expected)
+        # Publish again
+        response = self.publish(url)
+        now = DateTime()
+        days = 7
+        soon = now + days
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Expires'), rfc1123_date(soon.timeTime()))
+        self.assertEqual(response.getHeader('Cache-Control'), 'max-age=%d' % int(days*24*3600))
 
 
 def test_suite():
@@ -972,20 +945,12 @@ def test_suite():
     suite.addTest(makeSuite(TestScriptMoving))
     suite.addTest(makeSuite(TestJSTraversal))
     suite.addTest(makeSuite(TestPublishing))
-    if FiveTestsBase is not None:
-        suite.addTest(makeSuite(TestFivePublishing))
+    suite.addTest(makeSuite(TestFivePublishing))
     suite.addTest(makeSuite(TestDebugMode))
     suite.addTest(makeSuite(TestZODBTraversal))
     suite.addTest(makeSuite(TestMergingDisabled))
     suite.addTest(makeSuite(TestResourcePermissions))
-    suite.addTest(makeSuite(TestJSCompression))
-
-    if not PLONE21:
-        # We must not test for the defaults in Plone 2.1 because they are
-        # all different. Plone2.1 has tests in CMFPlone/tests for defaults
-        # and migrations
-        suite.addTest(makeSuite(TestJSDefaults))
-
+    suite.addTest(makeSuite(TestCachingHeaders))
 
     return suite
 
