@@ -10,6 +10,8 @@ from zExceptions import NotFound
 from Globals import InitializeClass, Persistent, PersistentMapping
 from AccessControl import ClassSecurityInfo, Unauthorized
 
+from zope.interface import implements
+
 from Acquisition import aq_base, aq_parent, aq_inner, ExplicitAcquisitionWrapper
 
 from OFS.Image import File
@@ -24,22 +26,18 @@ from Products.CMFCore.ActionProviderBase import ActionProviderBase
 
 from Products.ResourceRegistries import config
 from Products.ResourceRegistries import permissions
+from Products.ResourceRegistries.interfaces.ResourceRegistries import IResourceRegistry as z2IResourceRegistry
 from Products.ResourceRegistries.interfaces import IResourceRegistry
 
 import Acquisition
 from thread import get_ident
-from Products.CMFCore.Skinnable import SKINDATA
 
 # version agnostic import of z3_Resource
 try:
     import Products.Five
 except ImportError:
     __five__ = False
-    try:
-        from zope.app.publisher.browser.resource import Resource as z3_Resource
-    except ImportError:
-        # no Zope3
-        z3_Resource = None
+    from zope.app.publisher.browser.resource import Resource as z3_Resource
 else:
     __five__ = True
     try:
@@ -48,12 +46,8 @@ else:
         __five_pre_1_3_ = True
     except ImportError:
         # Zope 2.9 / Five 1.3
-        try:
-            from Products.Five.browser.resource import Resource as z3_Resource
-            __five_pre_1_3__ = False
-        except ImportError:
-            # no Five and no Zope3
-            z3_Resource = None
+        from Products.Five.browser.resource import Resource as z3_Resource
+        __five_pre_1_3__ = False
 
 
 
@@ -162,7 +156,8 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
     """Base class for a Plone registry managing resource files."""
 
     security = ClassSecurityInfo()
-    __implements__ = (SimpleItem.__implements__, IResourceRegistry)
+    implements(IResourceRegistry)
+    __implements__ = (SimpleItem.__implements__, z2IResourceRegistry)
     manage_options = SimpleItem.manage_options
 
     attributes_to_compare = ('getExpression', 'getCookable', 'getCacheable')
@@ -189,14 +184,6 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
         """Return a resource from the registry."""
         original = self.REQUEST.get('original', False)
         output = self.getResourceContent(item, self, original)
-        if self.getDebugMode() or not self.isCacheable(item):
-            duration = 0
-        else:
-            duration = self.cache_duration  # duration in seconds
-        seconds = float(duration)*24.0*3600.0
-        response = self.REQUEST.RESPONSE
-        response.setHeader('Expires',rfc1123_date((DateTime() + duration).timeTime()))
-        response.setHeader('Cache-Control', 'max-age=%d' % int(seconds))
         contenttype = self.getContentType()
         return (output, contenttype)
 
@@ -212,6 +199,7 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
         # stuff has taken place (e.g. authentication).
         kw = {'skin':skin,'name':name}
         data = None
+        duration = self.cache_duration  # duration in seconds
         if not self.getDebugMode() and self.isCacheable(name):
             if self.ZCacheable_isCachingEnabled():
                 data = self.ZCacheable_get(keywords=kw)
@@ -228,16 +216,22 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
                 self.ZCacheable_set(data, keywords=kw)
         else:
             data = self.__getitem__(name)
-        
+            duration = 0
+
         output, contenttype = data
-        
+
+        seconds = float(duration)*24.0*3600.0
+        response = self.REQUEST.RESPONSE
+        response.setHeader('Expires',rfc1123_date((DateTime() + duration).timeTime()))
+        response.setHeader('Cache-Control', 'max-age=%d' % int(seconds))
+
         if isinstance(output, unicode):
             portal_props = getToolByName(self, 'portal_properties')
             site_props = portal_props.site_properties
             charset = site_props.getProperty('default_charset', 'utf-8')
             output = output.encode(charset)
             contenttype += ';charset=' + charset
-        
+
         out = StringIO(output)
         out.headers = {'content-type': contenttype}
         # At this point we are ready to provide some content
@@ -362,6 +356,8 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
     security.declareProtected(permissions.ManagePortal, 'cookResources')
     def cookResources(self):
         """Cook the stored resources."""
+        if self.ZCacheable_isCachingEnabled():
+            self.ZCacheable_invalidate()
         resources = [r.copy() for r in self.getResources() if r.getEnabled()]
         self.concatenatedresources = {}
         self.cookedresources = ()
@@ -439,7 +435,10 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
         If any property of the resource is changed, then cookResources of the
         registry must be called."""
         resources = self.getResourcesDict()
-        return ExplicitAcquisitionWrapper(resources.get(id, None), self)
+        resource = resources.get(id, None)
+        if resource is not None:
+            return ExplicitAcquisitionWrapper(resource, self)
+        return None
 
     security.declarePrivate('getResourceContent')
     def getResourceContent(self, item, context, original=False):
@@ -483,7 +482,7 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
                     raise
 
             if obj is not None:
-                if z3_Resource is not None and isinstance(obj, z3_Resource):
+                if isinstance(obj, z3_Resource):
                     # z3 resources
                     # XXX this is a temporary solution, we wrap the five resources
                     # into our mechanism, where it should be the other way around.
@@ -531,7 +530,7 @@ class BaseRegistryTool(UniqueObject, SimpleItem, PropertyManager, Cacheable):
             # Add start/end notes to the resource for better
             # understanding and debugging
             if content:
-                output += '\n/* ----- %s ----- */\n' % (id,)
+                output += '\n/* - %s - */\n' % (id,)
                 if original:
                     output += content
                 else:
